function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } else { return Array.from(arr); } }

import * as React from 'react';

import { MenuLinkItem } from '../menu';
import EllipsisCrumb from './EllipsisCrumb';
import Crumb from './Crumb';

import './Breadcrumb.scss';

var constructChildren = function constructChildren(children, threshold) {
    var dotDotDotItems = children.slice(1, children.length + 1 - threshold);
    var menuCrumbsItems = React.createElement(
        EllipsisCrumb,
        null,
        dotDotDotItems.reverse().map(function (crumb, index) {
            return React.createElement(
                MenuLinkItem,
                { key: index },
                crumb
            );
        })
    );
    return [].concat(_toConsumableArray(children.slice(0, 1)), [menuCrumbsItems], _toConsumableArray(children.slice(1 - threshold)));
};

var renderBreadcrumbs = function renderBreadcrumbs(children, threshold) {
    var newChildren = children;
    var length = children.length;
    var hasEllipsis = false;

    if (length > threshold) {
        newChildren = constructChildren(children, threshold);
        length = newChildren.length;
        hasEllipsis = true;
    }

    return React.Children.map(newChildren, function (item, i) {
        var isLastCrumb = length === 0 || i === length - 1;
        return React.createElement(
            Crumb,
            {
                className: hasEllipsis && i === 1 ? 'no-shrink' : undefined,
                isLastCrumb: isLastCrumb
            },
            item
        );
    });
};

var Breadcrumb = function Breadcrumb(_ref) {
    var _ref$className = _ref.className,
        className = _ref$className === undefined ? '' : _ref$className,
        label = _ref.label,
        _ref$threshold = _ref.threshold,
        threshold = _ref$threshold === undefined ? 4 : _ref$threshold,
        children = _ref.children;
    return React.createElement(
        'nav',
        { 'aria-label': label, className: 'breadcrumbs ' + className },
        React.createElement(
            'ol',
            null,
            renderBreadcrumbs(React.Children.toArray(children), threshold)
        )
    );
};

Breadcrumb.propTypes = {
    /** Class name for Breadcrumb */
    className: PropTypes.string,

    /** Breadcrumb contents */
    children: PropTypes.node.isRequired,

    /** Aria label (should be a translation of "Breadcrumb") */
    label: PropTypes.string.isRequired,

    /** Number of crumbs to show before they collapse into an ellipsis */
    threshold: PropTypes.number
};
export default Breadcrumb;
import PropTypes from 'prop-types';