var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import * as React from 'react';
import TetherComponent from 'react-tether';
import uniqueId from 'lodash/uniqueId';

import './ContextMenu.scss';

var ContextMenu = function (_React$Component) {
    _inherits(ContextMenu, _React$Component);

    function ContextMenu() {
        var _ref;

        var _temp, _this, _ret;

        _classCallCheck(this, ContextMenu);

        for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
            args[_key] = arguments[_key];
        }

        return _ret = (_temp = (_this = _possibleConstructorReturn(this, (_ref = ContextMenu.__proto__ || Object.getPrototypeOf(ContextMenu)).call.apply(_ref, [this].concat(args))), _this), _this.state = {
            isOpen: false,
            targetOffset: ''
        }, _this.closeMenu = function () {
            var onMenuClose = _this.props.onMenuClose;


            _this.setState({ isOpen: false });
            if (onMenuClose) {
                onMenuClose();
            }
        }, _this.focusTarget = function () {
            // breaks encapsulation but the only alternative is passing a ref to an unknown child component
            var menuTargetEl = document.getElementById(_this.menuTargetID);
            if (menuTargetEl) {
                menuTargetEl.focus();
            }
        }, _this.handleMenuClose = function () {
            _this.closeMenu();
            _this.focusTarget();
        }, _this.handleDocumentClick = function (event) {
            var menuEl = document.getElementById(_this.menuID);
            if (menuEl && event.target instanceof Node && menuEl.contains(event.target)) {
                return;
            }
            _this.closeMenu();
        }, _this.handleContextMenu = function (event) {
            if (_this.props.isDisabled) {
                return;
            }

            var menuTargetEl = document.getElementById(_this.menuTargetID);
            var targetRect = menuTargetEl ? menuTargetEl.getBoundingClientRect() : { left: 0, top: 0 };
            var verticalOffset = event.clientY - targetRect.top;
            var horizontalOffset = event.clientX - targetRect.left;

            _this.setState({
                isOpen: true,
                targetOffset: verticalOffset + 'px ' + horizontalOffset + 'px'
            });

            var onMenuOpen = _this.props.onMenuOpen;

            if (onMenuOpen) {
                onMenuOpen();
            }

            event.preventDefault();
        }, _temp), _possibleConstructorReturn(_this, _ret);
    }

    _createClass(ContextMenu, [{
        key: 'componentWillMount',
        value: function componentWillMount() {
            this.menuID = uniqueId('contextmenu');
            this.menuTargetID = uniqueId('contextmenutarget');
        }
    }, {
        key: 'componentWillReceiveProps',
        value: function componentWillReceiveProps(nextProps) {
            // if the menu becomes disabled while it is open, we should close it
            if (!this.props.isDisabled && nextProps.isDisabled && this.state.isOpen) {
                this.handleMenuClose();
            }
        }
    }, {
        key: 'componentDidUpdate',
        value: function componentDidUpdate(prevProps, prevState) {
            if (!prevState.isOpen && this.state.isOpen) {
                // When menu is being opened
                document.addEventListener('click', this.handleDocumentClick, true);
                document.addEventListener('contextmenu', this.handleDocumentClick, true);
            } else if (prevState.isOpen && !this.state.isOpen) {
                // When menu is being closed
                document.removeEventListener('contextmenu', this.handleDocumentClick, true);
                document.removeEventListener('click', this.handleDocumentClick, true);
            }
        }
    }, {
        key: 'componentWillUnmount',
        value: function componentWillUnmount() {
            if (this.state.isOpen) {
                // Clean-up global click handlers
                document.removeEventListener('contextmenu', this.handleDocumentClick, true);
                document.removeEventListener('click', this.handleDocumentClick, true);
            }
        }
    }, {
        key: 'render',
        value: function render() {
            var _props = this.props,
                children = _props.children,
                constraints = _props.constraints;
            var _state = this.state,
                isOpen = _state.isOpen,
                targetOffset = _state.targetOffset;


            var elements = React.Children.toArray(children);

            if (elements.length !== 2) {
                throw new Error('ContextMenu must have exactly two children: A target component and a <Menu>');
            }

            var menuTarget = elements[0];
            var menu = elements[1];

            var menuTargetProps = {
                id: this.menuTargetID,
                key: this.menuTargetID,
                onContextMenu: this.handleContextMenu
            };

            var menuProps = {
                id: this.menuID,
                key: this.menuID,
                initialFocusIndex: null,
                onClose: this.handleMenuClose
            };

            return React.createElement(
                TetherComponent,
                {
                    attachment: 'top left',
                    classPrefix: 'context-menu',
                    constraints: constraints,
                    targetAttachment: 'top left',
                    targetOffset: targetOffset
                },
                React.cloneElement(menuTarget, menuTargetProps),
                isOpen && React.cloneElement(menu, menuProps)
            );
        }
    }]);

    return ContextMenu;
}(React.Component);

ContextMenu.defaultProps = {
    constraints: []
};
ContextMenu.propTypes = {
    /** A target component to attach to and a menu */
    children: PropTypes.node.isRequired,

    /**
     * An array of tether constraints
     *
     * @see See [Tether](http://tether.io) for possible constraints
     */
    constraints: PropTypes.arrayOf(PropTypes.any).isRequired,

    /** When disabled, native context menu behavior is applied, and the menu will close if it was open */
    isDisabled: PropTypes.bool,

    /** Called when menu is closed */
    onMenuClose: PropTypes.func,

    /** Called when menu is opened */
    onMenuOpen: PropTypes.func
};


export default ContextMenu;
import PropTypes from 'prop-types';