var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import * as React from 'react';
import { defineMessages, injectIntl, FormattedMessage } from 'react-intl';
import classNames from 'classnames';
// @NOTE(jtan): We need to find a replacement for pikaday. It's poorly supported and has a lot of undesirable blur() behavior.
import Pikaday from 'pikaday';
import range from 'lodash/range';

import IconAlert from '../../icons/general/IconAlert';
import IconCalendar from '../../icons/general/IconCalendar';
import IconClear from '../../icons/general/IconClear';

import Label from '../label';
import PlainButton from '../plain-button';
import Tooltip from '../tooltip';
import { RESIN_TAG_TARGET } from '../../common/variables';

import { convertDateToUnixMidnightTime } from '../../utils/datetime';

import './DatePicker.scss';

var messages = defineMessages({
    previousMonth: {
        'id': 'boxui.base.previousMonth',
        'defaultMessage': 'Previous Month'
    },
    nextMonth: {
        'id': 'boxui.base.nextMonth',
        'defaultMessage': 'Next Month'
    },
    iconAlertText: {
        'id': 'boxui.datePicker.iconAlertText',
        'defaultMessage': 'Invalid Date'
    },
    dateClearButton: {
        'id': 'boxui.datePicker.dateClearButton',
        'defaultMessage': 'Clear Date'
    },
    chooseDate: {
        'id': 'boxui.datePicker.chooseDate',
        'defaultMessage': 'Choose Date'
    }
});

var TOGGLE_DELAY_MS = 300;
var ISO_STRING_DATE_FORMAT = 'isoString';
var UTC_TIME_DATE_FORMAT = 'utcTime';
var UNIX_TIME_DATE_FORMAT = 'unixTime';
var UTC_ISO_STRING_DATE_FORMAT = 'utcISOString';
var ENTER_KEY = 'Enter';
var ESCAPE_KEY = 'Escape';
var TAB_KEY = 'Tab';

var stub = function stub() {};

/**
 * Converts date from being relative to GMT, to being relative to browser
 * timezone. E.g., Thu Jun 29 2017 00:00:00 GMT =>
 * Thu Jun 29 2017 00:00:00 GMT-0700 (PDT)
 * @param {Date} date UTC date
 * @returns {Date} date Local date
 */
function convertUTCToLocal(date) {
    var dateString = date.toUTCString();
    // Remove ` GMT` from the timestamp string
    var dateStringWithoutTimeZone = dateString.slice(0, -4);
    return new Date(dateStringWithoutTimeZone);
}

function getFormattedDate(date, format) {
    if (!date) {
        return '';
    }

    var utcDate = void 0;

    switch (format) {
        case ISO_STRING_DATE_FORMAT:
            return date.toISOString();
        case UTC_TIME_DATE_FORMAT:
            return convertDateToUnixMidnightTime(date);
        case UTC_ISO_STRING_DATE_FORMAT:
            utcDate = new Date(convertDateToUnixMidnightTime(date));
            return utcDate.toISOString();
        default:
            return date.getTime();
    }
}

var DatePicker = function (_React$Component) {
    _inherits(DatePicker, _React$Component);

    function DatePicker() {
        var _ref;

        var _temp, _this, _ret;

        _classCallCheck(this, DatePicker);

        for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
            args[_key] = arguments[_key];
        }

        return _ret = (_temp = (_this = _possibleConstructorReturn(this, (_ref = DatePicker.__proto__ || Object.getPrototypeOf(DatePicker)).call.apply(_ref, [this].concat(args))), _this), _this.onSelectHandler = function (date) {
            var onChange = _this.props.onChange;

            if (onChange) {
                var formattedDate = _this.formatValue(date);
                onChange(date, formattedDate);
            }
        }, _this.shouldStayClosed = false, _this.focusDatePicker = function () {
            // By default, this will open the datepicker too
            if (_this.dateInputEl) {
                _this.dateInputEl.focus();
            }
        }, _this.handleInputKeyDown = function (event) {
            var isTextInputAllowed = _this.props.isTextInputAllowed;


            if (_this.datePicker.isVisible()) {
                event.stopPropagation();
            }

            // Stops up/down arrow & spacebar from moving page scroll position since pikaday does not preventDefault correctly
            if (!isTextInputAllowed && event.key !== TAB_KEY) {
                event.preventDefault();
            }

            if (isTextInputAllowed && event.key === ENTER_KEY) {
                event.preventDefault();
            }

            if (event.key === ENTER_KEY || event.key === ESCAPE_KEY || event.key === ' ') {
                // Since pikaday auto-selects when you move the select box, enter/space don't do anything but close the date picker
                if (_this.datePicker.isVisible()) {
                    _this.datePicker.hide();
                }
            }
        }, _this.handleInputBlur = function (event) {
            var _this$props = _this.props,
                onBlur = _this$props.onBlur,
                isTextInputAllowed = _this$props.isTextInputAllowed;


            var nextActiveElement = event.relatedTarget || document.activeElement;

            // This is mostly here to cancel out the pikaday hide() on blur
            if (_this.datePicker.isVisible() && nextActiveElement && nextActiveElement === _this.datePickerButtonEl) {
                _this.shouldStayClosed = true;
                setTimeout(function () {
                    _this.shouldStayClosed = false;
                }, TOGGLE_DELAY_MS);
            }

            if (onBlur) {
                onBlur(event);
            }

            // Since we Fire parent onChange event if isTextInputAllowed
            // fire it on blur if the user typed a correct date format
            var inputDate = null;

            if (_this.dateInputEl) {
                inputDate = new Date(_this.dateInputEl.value);
            }

            if (isTextInputAllowed && inputDate && inputDate.getDate()) {
                _this.onSelectHandler(inputDate);
            }
        }, _this.handleButtonClick = function (event) {
            event.preventDefault();

            if (!_this.shouldStayClosed) {
                _this.focusDatePicker();
            }
        }, _this.formatDisplay = function (date) {
            var _this$props2 = _this.props,
                displayFormat = _this$props2.displayFormat,
                intl = _this$props2.intl;

            return date ? intl.formatDate(date, displayFormat) : '';
        }, _this.formatValue = function (date) {
            var dateFormat = _this.props.dateFormat;

            return getFormattedDate(date, dateFormat);
        }, _this.clearDate = function (event) {
            event.preventDefault(); // so datepicker doesn't open after clearing
            _this.datePicker.setDate(null);
            _this.onSelectHandler(null);
        }, _temp), _possibleConstructorReturn(_this, _ret);
    }

    _createClass(DatePicker, [{
        key: 'componentDidMount',
        value: function componentDidMount() {
            var _props = this.props,
                dateFormat = _props.dateFormat,
                intl = _props.intl,
                maxDate = _props.maxDate,
                minDate = _props.minDate,
                value = _props.value,
                yearRange = _props.yearRange,
                isTextInputAllowed = _props.isTextInputAllowed;
            var formatDate = intl.formatDate,
                formatMessage = intl.formatMessage;
            var nextMonth = messages.nextMonth,
                previousMonth = messages.previousMonth;

            var defaultValue = value;
            // When date format is utcTime, initial date needs to be converted from being relative to GMT to being
            // relative to browser timezone
            if (dateFormat === UTC_TIME_DATE_FORMAT && typeof value !== 'undefined') {
                defaultValue = convertUTCToLocal(value);
            }
            // Make sure the DST detection algorithm in browsers is up-to-date
            var year = new Date().getFullYear();

            var i18n = {
                previousMonth: formatMessage(previousMonth),
                nextMonth: formatMessage(nextMonth),
                months: range(12).map(function (month) {
                    return formatDate(new Date(year, month, 15), { month: 'long' });
                }),
                // weekdays must start with Sunday, so array of dates below is May 1st-8th, 2016
                weekdays: range(1, 8).map(function (date) {
                    return formatDate(new Date(2016, 4, date), { weekday: 'long' });
                }),
                weekdaysShort: range(1, 8).map(function (date) {
                    return formatDate(new Date(2016, 4, date), { weekday: 'narrow' });
                })
            };

            this.datePicker = new Pikaday({
                blurFieldOnSelect: false, // Available in pikaday > 1.5.1
                setDefaultDate: true,
                defaultDate: defaultValue,
                field: this.dateInputEl,
                maxDate: maxDate,
                minDate: minDate,
                position: 'bottom left',
                i18n: i18n,
                showDaysInNextAndPreviousMonths: true,
                onSelect: this.onSelectHandler,
                yearRange: yearRange,
                toString: this.formatDisplay
            });

            if (isTextInputAllowed) {
                this.updateDateInputValue(this.formatDisplay(defaultValue));
            }
        }
    }, {
        key: 'componentWillReceiveProps',
        value: function componentWillReceiveProps(nextProps) {
            var nextValue = nextProps.value,
                nextMinDate = nextProps.minDate,
                nextMaxDate = nextProps.maxDate;
            var _props2 = this.props,
                value = _props2.value,
                minDate = _props2.minDate,
                maxDate = _props2.maxDate,
                isTextInputAllowed = _props2.isTextInputAllowed;

            // only set date when props change

            if (nextValue && !value || !nextValue && value || nextValue && value && nextValue.getTime() !== value.getTime()) {
                this.datePicker.setDate(nextValue);
            }
            // If text input is allowed the dateInputEl will act as an uncontrolled input and
            // we need to set formatted value manually.
            if (isTextInputAllowed) {
                this.updateDateInputValue(this.formatDisplay(nextValue));
            }
            if (nextMinDate && !minDate || !nextMinDate && minDate || nextMinDate && minDate && nextMinDate.getTime() !== minDate.getTime()) {
                this.datePicker.setMinDate(nextMinDate);

                if (this.datePicker.getDate() < nextMinDate) {
                    this.datePicker.gotoDate(nextMinDate);
                }
            }
            if (nextMaxDate && !maxDate || !nextMaxDate && maxDate || nextMaxDate && maxDate && nextMaxDate.getTime() !== maxDate.getTime()) {
                this.datePicker.setMaxDate(nextMaxDate);

                if (this.datePicker.getDate() > nextMaxDate) {
                    this.datePicker.gotoDate(nextMaxDate);
                }
            }
        }
    }, {
        key: 'componentWillUnmount',
        value: function componentWillUnmount() {
            this.datePicker.destroy();
        }
    }, {
        key: 'updateDateInputValue',
        value: function updateDateInputValue(value) {
            if (this.dateInputEl) {
                this.dateInputEl.value = value;
            }
        }

        // Used to prevent bad sequences of hide/show when toggling the datepicker button

    }, {
        key: 'render',
        value: function render() {
            var _this2 = this;

            var _props3 = this.props,
                className = _props3.className,
                description = _props3.description,
                error = _props3.error,
                errorTooltipPosition = _props3.errorTooltipPosition,
                hideLabel = _props3.hideLabel,
                hideOptionalLabel = _props3.hideOptionalLabel,
                inputProps = _props3.inputProps,
                intl = _props3.intl,
                isClearable = _props3.isClearable,
                isDisabled = _props3.isDisabled,
                isRequired = _props3.isRequired,
                isTextInputAllowed = _props3.isTextInputAllowed,
                label = _props3.label,
                name = _props3.name,
                onFocus = _props3.onFocus,
                placeholder = _props3.placeholder,
                resinTarget = _props3.resinTarget,
                value = _props3.value;
            var formatMessage = intl.formatMessage;

            var classes = classNames(className, 'date-picker-wrapper', {
                'show-clear-btn': !!value,
                'show-error': !!error
            });

            var resinTargetAttr = resinTarget ? _defineProperty({}, RESIN_TAG_TARGET, resinTarget) : {};

            var valueAttr = isTextInputAllowed ? { defaultValue: this.formatDisplay(value) } : { value: this.formatDisplay(value) };

            var onChangeAttr = isTextInputAllowed ? {} : {
                onChange: stub
            }; /* fixes proptype error about readonly field (not adding readonly so constraint validation works) */

            return React.createElement(
                'div',
                { className: classes },
                React.createElement(
                    'span',
                    { className: 'date-picker-icon-holder' },
                    React.createElement(
                        Label,
                        {
                            hideLabel: hideLabel,
                            text: label,
                            showOptionalText: !hideOptionalLabel && !isRequired
                        },
                        !!description && React.createElement(
                            'i',
                            { className: 'date-picker-description' },
                            description
                        ),
                        React.createElement(
                            Tooltip,
                            {
                                className: 'date-picker-error-tooltip',
                                isShown: !!error,
                                position: errorTooltipPosition,
                                text: error || '',
                                theme: 'error'
                            },
                            React.createElement('input', _extends({
                                className: 'date-picker-input',
                                type: 'text',
                                ref: function ref(_ref3) {
                                    _this2.dateInputEl = _ref3;
                                },
                                disabled: isDisabled,
                                placeholder: placeholder || formatMessage(messages.chooseDate),
                                required: isRequired,
                                onBlur: this.handleInputBlur
                            }, onChangeAttr, {
                                onFocus: onFocus,
                                onKeyDown: this.handleInputKeyDown
                            }, resinTargetAttr, inputProps, valueAttr))
                        )
                    ),
                    isClearable && !!value && !isDisabled ? React.createElement(
                        PlainButton,
                        {
                            className: 'date-picker-clear-btn',
                            type: 'button',
                            onClick: this.clearDate,
                            'aria-label': formatMessage(messages.dateClearButton)
                        },
                        React.createElement(IconClear, { width: 12, height: 12 })
                    ) : null,
                    error ? React.createElement(IconAlert, {
                        className: 'date-picker-icon-alert',
                        width: 13,
                        height: 13,
                        title: React.createElement(FormattedMessage, messages.iconAlertText)
                    }) : null,
                    React.createElement(
                        PlainButton,
                        {
                            className: 'date-picker-open-btn',
                            disabled: isDisabled,
                            type: 'button',
                            onClick: this.handleButtonClick,
                            'aria-label': formatMessage(messages.chooseDate),
                            getDOMRef: function getDOMRef(ref) {
                                _this2.datePickerButtonEl = ref;
                            }
                        },
                        React.createElement(IconCalendar, { width: 16, height: 17 })
                    ),
                    React.createElement('input', {
                        type: 'hidden',
                        className: 'date-picker-unix-time-input',
                        name: name,
                        value: this.formatValue(value),
                        readOnly: true
                    })
                )
            );
        }
    }]);

    return DatePicker;
}(React.Component);

DatePicker.defaultProps = {
    className: '',
    dateFormat: UNIX_TIME_DATE_FORMAT,
    displayFormat: {},
    error: '',
    errorTooltipPosition: 'bottom-left',
    inputProps: {},
    isClearable: true,
    isTextInputAllowed: false,
    yearRange: 10
};
DatePicker.propTypes = {
    /** Add a css class to the component */
    className: PropTypes.string,

    /** The format of the date value for form submit */
    dateFormat: PropTypes.string,

    /** Some optional description */
    description: PropTypes.node,

    /** The format of the date displayed in the input field */
    displayFormat: PropTypes.object,

    /** Error message */
    error: PropTypes.node,

    /** Position of error message tooltip */
    errorTooltipPosition: PropTypes.oneOf(['bottom-left', 'bottom-center', 'bottom-right', 'middle-left', 'middle-right', 'top-center', 'top-left', 'top-right']),

    /** Whether to show or hide the field's label */
    hideLabel: PropTypes.bool,

    /** Whether show or hide the 'Optional' label */
    hideOptionalLabel: PropTypes.bool,

    /** Props that will be applied on the input element */
    inputProps: PropTypes.object,
    intl: PropTypes.object.isRequired,

    /** Is input clearable */
    isClearable: PropTypes.bool,

    /** Is input disabled */
    isDisabled: PropTypes.bool,

    /** Is input required */
    isRequired: PropTypes.bool,

    /** Is user allowed to manually input a value */
    isTextInputAllowed: PropTypes.bool,

    /** Label displayed for the text input */
    label: PropTypes.node.isRequired,

    /** The maximum date allowed to be selected */
    maxDate: function maxDate() {
        return (typeof Date === 'function' ? PropTypes.instanceOf(Date) : PropTypes.any).apply(this, arguments);
    },

    /** The minimum date allowed to be selected */
    minDate: function minDate() {
        return (typeof Date === 'function' ? PropTypes.instanceOf(Date) : PropTypes.any).apply(this, arguments);
    },

    /** Name of the text input */
    name: PropTypes.string,

    /** Called when input lose focus */
    onBlur: PropTypes.func,

    /** Called when input is changed, passed the selected Date */
    onChange: PropTypes.func,

    /** Called when input receives focus */
    onFocus: PropTypes.func,

    /** Placeholder for the text input */
    placeholder: PropTypes.string,

    /** Resin tag */
    resinTarget: PropTypes.string,

    /** Date to set the input */
    value: function value() {
        return (typeof Date === 'function' ? PropTypes.instanceOf(Date) : PropTypes.any).apply(this, arguments);
    },
    yearRange: PropTypes.oneOfType([PropTypes.number, PropTypes.arrayOf(PropTypes.number)])
};


export { DatePicker as DatePickerBase };
export default injectIntl(DatePicker);
import PropTypes from 'prop-types';