var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import PropTypes from 'prop-types';
import React, { Component } from 'react';
import serialize from 'form-serialize';

function getFormValidityState(form) {
    // Turn the form.elements HTMLCollection into Array before reducing
    return [].slice.call(form.elements).reduce(function (validityObj, inputEl) {
        // Only serialize inputs that have a name defined
        if (inputEl.name && !inputEl.validity.valid) {
            var validityState = inputEl.validity;

            if (inputEl.validity.customError) {
                // If the input is displaying a custom error,
                // we expose the errorCode stored in the validationMessage
                validityState.customErrorCode = inputEl.validationMessage;
            }

            validityObj[inputEl.name] = {
                validityState: validityState
            };
            return validityObj;
        }
        return validityObj;
    }, {});
}

var Form = function (_Component) {
    _inherits(Form, _Component);

    function Form(props) {
        _classCallCheck(this, Form);

        var _this = _possibleConstructorReturn(this, (Form.__proto__ || Object.getPrototypeOf(Form)).call(this, props));

        _this.onChange = function (_ref) {
            var currentTarget = _ref.currentTarget;

            if (_this.props.onChange) {
                var formData = serialize(currentTarget, {
                    hash: true,
                    empty: true
                });
                _this.props.onChange(formData);
            }
        };

        _this.onSubmit = function (event) {
            var form = event.target;
            event.preventDefault();
            var isValid = form.checkValidity();
            var _this$props = _this.props,
                onInvalidSubmit = _this$props.onInvalidSubmit,
                onValidSubmit = _this$props.onValidSubmit;
            var registeredInputs = _this.state.registeredInputs;


            if (isValid) {
                var formData = serialize(form, { hash: true, empty: true });
                onValidSubmit(formData);
            } else {
                var formValidityState = getFormValidityState(form);

                // Push form validity state to inputs so errors are shown on submit
                Object.keys(formValidityState).forEach(function (key) {
                    return registeredInputs[key] && registeredInputs[key](formValidityState[key].validityState);
                });

                if (onInvalidSubmit) {
                    onInvalidSubmit(formValidityState);
                }
            }
        };

        _this.registerInput = function (name, setValidityStateHandler) {
            var registeredInputs = _this.state.registeredInputs;


            if (registeredInputs[name]) {
                throw new Error('Input \'' + name + '\' is already registered.');
            }

            var nextState = _this.state;
            nextState.registeredInputs[name] = setValidityStateHandler;
            _this.setState(nextState);
        };

        _this.unregisterInput = function (name) {
            var nextState = _this.state;
            delete nextState.registeredInputs[name];
            _this.setState(nextState);
        };

        _this.state = {
            registeredInputs: {}
        };
        return _this;
    }

    _createClass(Form, [{
        key: 'getChildContext',
        value: function getChildContext() {
            return {
                form: {
                    registerInput: this.registerInput.bind(this),
                    unregisterInput: this.unregisterInput.bind(this)
                }
            };
        }
    }, {
        key: 'componentWillUpdate',
        value: function componentWillUpdate(nextProps, nextState) {
            if (nextProps.formValidityState) {
                Object.keys(nextProps.formValidityState).forEach(function (key) {
                    if (nextState.registeredInputs[key]) {
                        nextState.registeredInputs[key](nextProps.formValidityState[key]);
                    }
                });
            }
        }
    }, {
        key: 'render',
        value: function render() {
            var children = this.props.children;

            return React.createElement(
                'form',
                { noValidate: true, onChange: this.onChange, onSubmit: this.onSubmit },
                children
            );
        }
    }]);

    return Form;
}(Component);

Form.propTypes = {
    children: PropTypes.node,
    /** Called when an input in the form changes */
    onChange: PropTypes.func,
    /** Called when a valid submit is made */
    onValidSubmit: PropTypes.func.isRequired,
    /** Called when an invalid submit is made */
    onInvalidSubmit: PropTypes.func,
    /** An object mapping input names to error messages */
    formValidityState: PropTypes.object // eslint-disable-line react/no-unused-prop-types
};
Form.childContextTypes = {
    form: PropTypes.shape({
        registerInput: PropTypes.func.isRequired,
        unregisterInput: PropTypes.func.isRequired
    }).isRequired
};


export default Form;