var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } else { return Array.from(arr); } }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import { FormattedMessage } from 'react-intl';

import { ModalActions } from '../modal';
import Button from '../button';
import PlainButton from '../plain-button';
import DropdownMenu, { MenuToggle } from '../dropdown-menu';
import { Menu, MenuItem } from '../menu';

import HotkeyFriendlyModal from './HotkeyFriendlyModal';
import commonMessages from '../../common/messages';
import messages from './messages';

import './HotkeyHelpModal.scss';

var specialCharacters = {
    backspace: '\u232B',
    down: '\u2193',
    left: '\u2190',
    meta: '\u2318',
    right: '\u2192',
    up: '\u2191',
    enter: React.createElement(FormattedMessage, messages.enterKey),
    spacebar: React.createElement(FormattedMessage, messages.spacebarKey),
    shift: '\u21E7',
    ctrl: React.createElement(FormattedMessage, messages.ctrlKey),
    alt: React.createElement(FormattedMessage, messages.altKey),
    esc: React.createElement(FormattedMessage, messages.escKey)
};

var HotkeyHelpModal = function (_Component) {
    _inherits(HotkeyHelpModal, _Component);

    function HotkeyHelpModal(props, context) {
        _classCallCheck(this, HotkeyHelpModal);

        var _this = _possibleConstructorReturn(this, (HotkeyHelpModal.__proto__ || Object.getPrototypeOf(HotkeyHelpModal)).call(this, props));

        _this.prettyPrintHotkey = function (hotkeyConfig) {
            var hotkeys = Array.isArray(hotkeyConfig.key) ? hotkeyConfig.key : [hotkeyConfig.key];

            return hotkeys.map(function (hotkey) {
                return hotkey.split(' ').reduce(function (prettyHotkey, combo, i) {
                    // Convert a "raw" combo to a "pretty" combo:
                    // e.g. "shift+g" => [ <kbd>Shift</kbd>, '+', <kbd>G</kbd> ]
                    var prettyCombo = combo.split('+').map(function (key) {
                        // Convert special key characters into their respective icons or translated components:
                        // e.g. "shift" => "Shift", "meta" => "⌘"
                        if (key in specialCharacters) {
                            return specialCharacters[key];
                        }
                        // If it's not a special character, just return the uppercased key:
                        // e.g. "g" => "G"
                        return key.length === 1 ? key.toUpperCase() : key;
                    }).map(function (key, j) {
                        return React.createElement(
                            'kbd',
                            { key: j },
                            key
                        );
                    });
                    // If this hotkey is a sequence of keys, return a translated message to combine them:
                    // e.g. "Shift+G Shift+A" => "Shift+G then Shift+A"
                    return i === 0 ? prettyCombo : React.createElement(FormattedMessage, _extends({
                        values: {
                            key1: React.createElement(
                                'span',
                                null,
                                prettyHotkey
                            ),
                            key2: React.createElement(
                                'span',
                                null,
                                prettyCombo
                            )
                        }
                    }, messages.hotkeySequence));
                }, []);
            }).reduce(function (finalHotkey, hotkey, i) {
                return (
                    // For shortcuts with multiple hotkeys, separate each hotkey with a "/" joiner:
                    // e.g. "Cmd+S Ctrl+S" => "Cmd+S / Ctrl+S"
                    i === 0 ? [hotkey] : [].concat(_toConsumableArray(finalHotkey), [' / ', hotkey])
                );
            }, []).map(function (element, i) {
                return React.createElement(
                    'span',
                    { key: i },
                    element
                );
            });
        };

        _this.renderHotkey = function (hotkey, i) {
            return React.createElement(
                'li',
                { className: 'hotkey-item', key: i },
                React.createElement(
                    'div',
                    { className: 'hotkey-description' },
                    hotkey.description
                ),
                React.createElement(
                    'div',
                    { className: 'hotkey-key' },
                    _this.prettyPrintHotkey(hotkey)
                )
            );
        };

        _this.hotkeys = context.hotkeyLayer.getActiveHotkeys();
        _this.types = context.hotkeyLayer.getActiveTypes();
        _this.state = {
            currentType: _this.types.length ? _this.types[0] : null
        };
        return _this;
    }

    _createClass(HotkeyHelpModal, [{
        key: 'componentWillReceiveProps',
        value: function componentWillReceiveProps(nextProps) {
            if (!nextProps.isOpen) {
                return;
            }

            // modal is being opened; refresh hotkeys
            if (nextProps.isOpen && !this.props.isOpen) {
                this.hotkeys = this.context.hotkeyLayer.getActiveHotkeys();
                this.types = this.context.hotkeyLayer.getActiveTypes();
            }

            if (!this.state.currentType) {
                this.setState({
                    currentType: this.types.length ? this.types[0] : null
                });
            }
        }

        /**
         * Converts a "raw" hotkey to translated JSX version
         */

    }, {
        key: 'renderDropdownMenu',
        value: function renderDropdownMenu() {
            var _this2 = this;

            var currentType = this.state.currentType;


            if (!currentType) {
                return null;
            }

            return React.createElement(
                'div',
                { className: 'hotkey-dropdown' },
                React.createElement(
                    DropdownMenu,
                    null,
                    React.createElement(
                        PlainButton,
                        { className: 'lnk', type: 'button' },
                        React.createElement(
                            MenuToggle,
                            null,
                            currentType
                        )
                    ),
                    React.createElement(
                        Menu,
                        null,
                        this.types.map(function (hotkeyType, i) {
                            return React.createElement(
                                MenuItem,
                                {
                                    key: i,
                                    onClick: function onClick() {
                                        return _this2.setState({ currentType: hotkeyType });
                                    }
                                },
                                hotkeyType
                            );
                        })
                    )
                )
            );
        }
    }, {
        key: 'renderHotkeyList',
        value: function renderHotkeyList() {
            var currentType = this.state.currentType;


            if (!currentType) {
                return null;
            }

            var hotkeys = this.hotkeys[currentType];

            return React.createElement(
                'ul',
                { className: 'hotkey-list' },
                hotkeys.map(this.renderHotkey)
            );
        }
    }, {
        key: 'render',
        value: function render() {
            var _props = this.props,
                isOpen = _props.isOpen,
                onRequestClose = _props.onRequestClose;
            var currentType = this.state.currentType;


            if (!currentType) {
                return null;
            }

            return React.createElement(
                HotkeyFriendlyModal,
                {
                    className: 'hotkey-modal',
                    isOpen: isOpen,
                    onRequestClose: onRequestClose,
                    title: React.createElement(FormattedMessage, messages.hotkeyModalTitle)
                },
                this.renderDropdownMenu(),
                this.renderHotkeyList(),
                React.createElement(
                    ModalActions,
                    null,
                    React.createElement(
                        Button,
                        { onClick: onRequestClose },
                        React.createElement(FormattedMessage, commonMessages.cancel)
                    )
                )
            );
        }
    }]);

    return HotkeyHelpModal;
}(Component);

HotkeyHelpModal.propTypes = {
    isOpen: PropTypes.bool,
    onRequestClose: PropTypes.func.isRequired
};
HotkeyHelpModal.contextTypes = {
    hotkeyLayer: PropTypes.object
};


export default HotkeyHelpModal;