var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

/**
 * From https://github.com/jaredpalmer/react-simple-infinite-scroll
 * Updated to accept a scroll container React ref as the "window"
 */
import * as React from 'react';
import throttle from 'lodash/throttle';

var InfiniteScroll = function (_React$Component) {
    _inherits(InfiniteScroll, _React$Component);

    function InfiniteScroll(props) {
        _classCallCheck(this, InfiniteScroll);

        var _this = _possibleConstructorReturn(this, (InfiniteScroll.__proto__ || Object.getPrototypeOf(InfiniteScroll)).call(this, props));

        _this.sentinel = React.createRef();

        _this.addEventListeners = function () {
            var useWindow = _this.props.useWindow;

            if (useWindow) {
                window.addEventListener('scroll', _this.scrollHandler);
                window.addEventListener('resize', _this.resizeHandler);
                _this.setState({ activeListenerNode: window });
            } else {
                var _scrollContainerNode = _this.props.scrollContainerNode;

                if (_scrollContainerNode == null) return;
                _scrollContainerNode.addEventListener('scroll', _this.scrollHandler);
                _scrollContainerNode.addEventListener('resize', _this.resizeHandler);
                _this.setState({ activeListenerNode: _scrollContainerNode });
            }
        };

        _this.removeEventListeners = function () {
            var activeListenerNode = _this.state.activeListenerNode;

            if (activeListenerNode == null) return;
            activeListenerNode.removeEventListener('scroll', _this.scrollHandler);
            activeListenerNode.removeEventListener('resize', _this.resizeHandler);
        };

        _this.onContainerScroll = function () {
            var _this$props = _this.props,
                isLoading = _this$props.isLoading,
                hasMore = _this$props.hasMore,
                threshold = _this$props.threshold,
                useWindow = _this$props.useWindow,
                onLoadMore = _this$props.onLoadMore;


            if (isLoading || !hasMore) return;

            if (_this.sentinel.current == null) return;

            var _this$sentinel$curren = _this.sentinel.current.getBoundingClientRect(),
                sentinelTop = _this$sentinel$curren.top;

            if (useWindow) {
                if (sentinelTop - window.innerHeight < threshold) {
                    onLoadMore();
                }
            } else {
                var _scrollContainerNode2 = _this.props.scrollContainerNode;

                if (_scrollContainerNode2 == null) return;

                var _scrollContainerNode3 = _scrollContainerNode2.getBoundingClientRect(),
                    containerBottom = _scrollContainerNode3.bottom;

                if (sentinelTop - containerBottom < threshold) {
                    onLoadMore();
                }
            }
        };

        _this.scrollHandler = throttle(_this.onContainerScroll, props.throttle);
        _this.resizeHandler = throttle(_this.onContainerScroll, props.throttle);

        _this.state = {
            activeListenerNode: null
        };
        return _this;
    }

    _createClass(InfiniteScroll, [{
        key: 'componentDidMount',
        value: function componentDidMount() {
            this.addEventListeners();
        }
    }, {
        key: 'componentDidUpdate',
        value: function componentDidUpdate(prevProps) {
            var _props = this.props,
                useWindow = _props.useWindow,
                scrollContainerNode = _props.scrollContainerNode;

            if (useWindow !== prevProps.useWindow || scrollContainerNode !== prevProps.scrollContainerNode) {
                this.removeEventListeners();
                this.addEventListeners();
            }
        }
    }, {
        key: 'componentWillUnmount',
        value: function componentWillUnmount() {
            this.removeEventListeners();
        }
    }, {
        key: 'render',
        value: function render() {
            var sentinel = React.createElement('div', { ref: this.sentinel, 'data-testid': 'sentinel' });

            return React.createElement(
                'div',
                null,
                this.props.children,
                sentinel
            );
        }
    }]);

    return InfiniteScroll;
}(React.Component);

InfiniteScroll.defaultProps = {
    threshold: 100,
    throttle: 64,
    useWindow: false
};
InfiniteScroll.propTypes = {
    /** Does the resource have more entities */
    hasMore: PropTypes.bool.isRequired,

    /** Are more entities being loaded */
    isLoading: PropTypes.bool.isRequired,

    /** Callback to load more entities */
    onLoadMore: PropTypes.func.isRequired,

    /** Scroll threshold */
    threshold: PropTypes.number.isRequired,

    /** Throttle rate */
    throttle: PropTypes.number.isRequired,

    /** Components to render, should include entities/loading states/end message */
    children: PropTypes.node.isRequired,

    /** React ref of the scroll container
     * Used to listen to scroll events and calculate onLoadMore calls
     * Set useWindow to true to use the window as scroll container
     */
    scrollContainerNode: function scrollContainerNode() {
        return (typeof HTMLElement === 'function' ? PropTypes.instanceOf(HTMLElement) : PropTypes.any).apply(this, arguments);
    },
    useWindow: PropTypes.bool.isRequired
};


export default InfiniteScroll;
import PropTypes from 'prop-types';