var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import * as React from 'react';
import classNames from 'classnames';
import tabbable from 'tabbable';
import omit from 'lodash/omit';

import FocusTrap from '../focus-trap';
import LoadingIndicator from '../loading-indicator';
import Portal from '../portal';
import ModalDialog from './ModalDialog';

import './Modal.scss';

var Modal = function (_React$Component) {
    _inherits(Modal, _React$Component);

    function Modal() {
        var _ref;

        var _temp, _this, _ret;

        _classCallCheck(this, Modal);

        for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
            args[_key] = arguments[_key];
        }

        return _ret = (_temp = (_this = _possibleConstructorReturn(this, (_ref = Modal.__proto__ || Object.getPrototypeOf(Modal)).call.apply(_ref, [this].concat(args))), _this), _this.onKeyDown = function (event) {
            var _this$props = _this.props,
                isOpen = _this$props.isOpen,
                onRequestClose = _this$props.onRequestClose;

            if (isOpen && onRequestClose && event.key === 'Escape') {
                event.stopPropagation();
                onRequestClose(event);
            }
        }, _this.onBackdropClick = function (event) {
            var _this$props2 = _this.props,
                onRequestClose = _this$props2.onRequestClose,
                onBackdropClick = _this$props2.onBackdropClick;


            if (onBackdropClick) {
                onBackdropClick(event);
            } else if (onRequestClose) {
                onRequestClose(event);
            }
        }, _this.onModalOpen = function () {
            setTimeout(function () {
                var focusElementSelector = _this.props.focusElementSelector;

                var focusElementSelectorTrimmed = focusElementSelector && focusElementSelector.trim();
                if (focusElementSelectorTrimmed) {
                    _this.focusElement(focusElementSelectorTrimmed);
                } else {
                    _this.focusFirstUsefulElement();
                }
            }, 0);
        }, _this.focusFirstUsefulElement = function () {
            if (!_this.dialog) {
                return;
            }
            var tabbableEls = tabbable(_this.dialog);
            if (tabbableEls.length > 1) {
                tabbableEls[1].focus();
            } else if (tabbableEls.length > 0) {
                tabbableEls[0].focus();
            }
        }, _this.focusElement = function (elementSelector) {
            if (!_this.dialog) {
                return;
            }
            var el = _this.dialog.querySelector(elementSelector);
            if (el) {
                el.focus();
            } else {
                throw new Error('Could not find element matching selector ' + elementSelector + ' to focus on.');
            }
        }, _temp), _possibleConstructorReturn(_this, _ret);
    }

    _createClass(Modal, [{
        key: 'componentDidMount',
        value: function componentDidMount() {
            var isOpen = this.props.isOpen;


            if (isOpen) {
                this.onModalOpen();
            }
        }
    }, {
        key: 'componentDidUpdate',
        value: function componentDidUpdate(prevProps) {
            var _props = this.props,
                isLoading = _props.isLoading,
                isOpen = _props.isOpen;

            // Set focus if modal is transitioning from closed -> open and/or loading -> not loading

            if ((!prevProps.isOpen || prevProps.isLoading) && isOpen && !isLoading) {
                this.onModalOpen();
            }
        }

        /**
         * Call props.onRequestClose when escape is pressed
         * @param {SyntheticKeyboardEvent} event
         */


        /**
         * Call props.onRequestClose when backdrop is clicked
         * @param {SyntheticMouseEvent} event
         */


        /**
         * Focuses on the correct element in the popup when it opens
         */


        /**
         * Focus the first useful element in the modal (i.e. not the close button, unless it's the only thing)
         */


        /**
         * Focus the element that matches the selector in the modal
         * @throws {Error} When the elementSelector does not match any element
         */

    }, {
        key: 'render',
        value: function render() {
            var _this2 = this;

            var _props2 = this.props,
                className = _props2.className,
                isLoading = _props2.isLoading,
                isOpen = _props2.isOpen,
                onRequestClose = _props2.onRequestClose,
                shouldNotUsePortal = _props2.shouldNotUsePortal,
                style = _props2.style,
                rest = _objectWithoutProperties(_props2, ['className', 'isLoading', 'isOpen', 'onRequestClose', 'shouldNotUsePortal', 'style']);

            if (!isOpen) {
                return null;
            }

            var bodyOverrideStyle = '\n            body {\n                overflow:hidden;\n            }\n        ';

            // used `omit` here to prevent certain key/value pairs from going into the spread on `ModalDialog`
            var modalProps = omit(rest, ['onBackdropClick', 'focusElementSelector']);

            var WrapperComponent = shouldNotUsePortal ? 'div' : Portal;
            // Render a style tag to prevent body from scrolling as long as the Modal is open
            return React.createElement(
                WrapperComponent,
                {
                    className: classNames('modal', className),
                    onKeyDown: this.onKeyDown,
                    tabIndex: '-1'
                },
                React.createElement('div', {
                    className: 'modal-backdrop',
                    onClick: this.onBackdropClick,
                    style: style.backdrop
                }),
                React.createElement(
                    FocusTrap,
                    { className: 'modal-dialog-container' },
                    isLoading ? React.createElement(LoadingIndicator, { size: 'large' }) : React.createElement(ModalDialog, _extends({
                        onRequestClose: onRequestClose,
                        style: style.dialog,
                        modalRef: function modalRef(modalEl) {
                            // This callback gets passed through as a regular prop since
                            // ModalDialog is wrapped in a HOC
                            _this2.dialog = modalEl;
                        }
                    }, modalProps))
                ),
                React.createElement(
                    'style',
                    { type: 'text/css' },
                    bodyOverrideStyle
                )
            );
        }
    }]);

    return Modal;
}(React.Component);

Modal.defaultProps = {
    style: {
        backdrop: {},
        dialog: {}
    }
};
Modal.propTypes = {
    children: PropTypes.node.isRequired,

    /** Additional CSS classname of the `.modal` element */
    className: PropTypes.string,
    focusElementSelector: PropTypes.string,
    isLoading: PropTypes.bool,
    isOpen: PropTypes.bool,
    onBackdropClick: PropTypes.func,

    /** `(event) => {}`. `event` can be of type `SyntheticKeyboardEvent|SyntheticMouseEvent`. */
    onRequestClose: PropTypes.func,

    /** modal usually use Portal as Portal stays if parent is removed, but it cannot retain DOM tree's resin props */
    shouldNotUsePortal: PropTypes.bool,
    style: PropTypes.shape({
        backdrop: PropTypes.object,
        dialog: PropTypes.object
    }).isRequired,
    title: PropTypes.node
};


export default Modal;
import PropTypes from 'prop-types';