var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import * as React from 'react';
import classNames from 'classnames';
import omit from 'lodash/omit';
import uniqueId from 'lodash/uniqueId';
import { defineMessages, injectIntl } from 'react-intl';

import IconClose from '../../icons/general/IconClose';

var ALERT_TYPE = 'alert';
var DIALOG_TYPE = 'dialog';

var messages = defineMessages({
    closeModalText: {
        'id': 'boxui.modalDialog.closeModalText',
        'defaultMessage': 'Close Modal'
    }
});

var ModalDialog = function (_React$Component) {
    _inherits(ModalDialog, _React$Component);

    function ModalDialog() {
        var _ref;

        var _temp, _this, _ret;

        _classCallCheck(this, ModalDialog);

        for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
            args[_key] = arguments[_key];
        }

        return _ret = (_temp = (_this = _possibleConstructorReturn(this, (_ref = ModalDialog.__proto__ || Object.getPrototypeOf(ModalDialog)).call.apply(_ref, [this].concat(args))), _this), _this.onCloseButtonClick = function (event) {
            var onRequestClose = _this.props.onRequestClose;

            if (onRequestClose) {
                onRequestClose(event);
            }
        }, _temp), _possibleConstructorReturn(_this, _ret);
    }

    _createClass(ModalDialog, [{
        key: 'componentWillMount',
        value: function componentWillMount() {
            this.modalID = uniqueId('modal');
        }

        /**
         * Handles clicking on the close button
         * @param {SyntheticMouseEvent} event
         * @return {void}
         */

    }, {
        key: 'renderCloseButton',


        /**
         * Renders a button if onRequestClose is passed in
         * @return {ReactElement|null} - Returns the button, or null if the button shouldn't be rendered
         */
        value: function renderCloseButton() {
            var _props = this.props,
                closeButtonProps = _props.closeButtonProps,
                onRequestClose = _props.onRequestClose,
                intl = _props.intl;
            var formatMessage = intl.formatMessage;

            if (!onRequestClose) {
                return null;
            }

            return React.createElement(
                'button',
                _extends({}, closeButtonProps, {
                    className: 'modal-close-button',
                    onClick: this.onCloseButtonClick,
                    'aria-label': formatMessage(messages.closeModalText)
                }),
                React.createElement(IconClose, { width: 18, height: 18, color: '#999EA4' })
            );
        }
    }, {
        key: 'renderContent',
        value: function renderContent() {
            var _props2 = this.props,
                children = _props2.children,
                type = _props2.type;


            if (type !== ALERT_TYPE) {
                return React.createElement(
                    'div',
                    { className: 'modal-content' },
                    children
                );
            }

            var elements = React.Children.toArray(children);
            if (elements.length !== 2) {
                throw new Error('Alert modal must have exactly two children: A message and <ModalActions>');
            }

            return React.createElement(
                'div',
                { className: 'modal-content' },
                React.createElement(
                    'p',
                    { id: this.modalID + '-desc' },
                    elements[0]
                ),
                elements[1]
            );
        }
    }, {
        key: 'render',
        value: function render() {
            var _props3 = this.props,
                className = _props3.className,
                modalRef = _props3.modalRef,
                title = _props3.title,
                type = _props3.type,
                rest = _objectWithoutProperties(_props3, ['className', 'modalRef', 'title', 'type']);

            var isAlertType = type === ALERT_TYPE;
            var divProps = omit(rest, ['children', 'closeButtonProps', 'onRequestClose', 'intl']);

            divProps.role = isAlertType ? 'alertdialog' : 'dialog';
            divProps['aria-labelledby'] = this.modalID + '-label';
            if (isAlertType) {
                divProps['aria-describedby'] = this.modalID + '-desc';
            }

            return React.createElement(
                'div',
                _extends({
                    ref: modalRef,
                    className: classNames('modal-dialog', className)
                }, divProps),
                this.renderCloseButton(),
                React.createElement(
                    'div',
                    { className: 'modal-header' },
                    React.createElement(
                        'h2',
                        { className: 'modal-title', id: this.modalID + '-label' },
                        title
                    )
                ),
                this.renderContent()
            );
        }
    }]);

    return ModalDialog;
}(React.Component);

ModalDialog.defaultProps = {
    type: DIALOG_TYPE,
    closeButtonProps: {}
};
ModalDialog.propTypes = {
    children: PropTypes.node.isRequired,
    className: PropTypes.string,
    closeButtonProps: PropTypes.object.isRequired,
    intl: PropTypes.object.isRequired,
    modalRef: PropTypes.func,
    onRequestClose: PropTypes.func,
    title: PropTypes.node,
    type: PropTypes.oneOf(['alert', 'dialog'])
};


export { ModalDialog as ModalDialogBase };
export default injectIntl(ModalDialog);
import PropTypes from 'prop-types';