var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import * as React from 'react';
import classNames from 'classnames';
import noop from 'lodash/noop';
import throttle from 'lodash/throttle';

import './ScrollWrapper.scss';

var ScrollWrapper = function (_React$Component) {
    _inherits(ScrollWrapper, _React$Component);

    function ScrollWrapper(props) {
        _classCallCheck(this, ScrollWrapper);

        var _this = _possibleConstructorReturn(this, (ScrollWrapper.__proto__ || Object.getPrototypeOf(ScrollWrapper)).call(this, props));

        _this.state = {
            shouldShowTopScrollShadow: false,
            shouldShowBottomScrollShadow: false
        };

        _this.componentDidMount = function () {
            var newState = _this.getScrollShadowState();
            _this.setState(newState);

            if (_this.scrollRef) {
                _this.scrollRef.addEventListener('transitionend', _this.throttledOnContentScroll);

                // Apparently, flow only allows for one truthy check per command, so I have to either:
                // 1) duplicate this check per call, or
                // 2) nest if checks (_slightly more performant_)
                if (_this.scrollRef) {
                    _this.observer.observe(_this.scrollRef, {
                        attributes: true,
                        childlist: true,
                        subtree: true
                    });
                }
            }
        };

        _this.onContentScroll = function () {
            var newState = _this.getScrollShadowState();
            _this.setState(newState);
        };

        _this.getScrollShadowState = function () {
            var _ref = _this.scrollRef || {},
                scrollTop = _ref.scrollTop,
                scrollHeight = _ref.scrollHeight,
                clientHeight = _ref.clientHeight;

            var newState = {};

            if (scrollTop > 0 && scrollTop < scrollHeight - clientHeight) {
                newState.shouldShowTopScrollShadow = true;
                newState.shouldShowBottomScrollShadow = true;
            }

            if (scrollTop === 0) {
                newState.shouldShowTopScrollShadow = false;
            }

            if (scrollTop < scrollHeight - clientHeight) {
                newState.shouldShowBottomScrollShadow = true;
            }

            if (scrollTop === scrollHeight - clientHeight) {
                newState.shouldShowBottomScrollShadow = false;
            }

            return newState;
        };

        _this.scrollRef = null;
        _this.throttledOnContentScroll = throttle(_this.onContentScroll, 100);


        _this.observer = new MutationObserver(_this.throttledOnContentScroll);
        return _this;
    }

    _createClass(ScrollWrapper, [{
        key: 'componentWillUnmount',
        value: function componentWillUnmount() {
            this.observer.disconnect();

            if (this.scrollRef) {
                this.scrollRef.removeEventListener('transitionend', this.throttledOnContentScroll);
            }
        }

        // Throttle to 10 fps

    }, {
        key: 'render',
        value: function render() {
            var _this2 = this;

            var _props = this.props,
                children = _props.children,
                _props$className = _props.className,
                className = _props$className === undefined ? '' : _props$className,
                scrollRefFn = _props.scrollRefFn,
                shadowSize = _props.shadowSize,
                rest = _objectWithoutProperties(_props, ['children', 'className', 'scrollRefFn', 'shadowSize']);

            var _state = this.state,
                shouldShowTopScrollShadow = _state.shouldShowTopScrollShadow,
                shouldShowBottomScrollShadow = _state.shouldShowBottomScrollShadow;


            var classes = classNames('scroll-container', className, {
                'is-showing-top-shadow': shouldShowTopScrollShadow,
                'is-showing-bottom-shadow': shouldShowBottomScrollShadow
            });

            return React.createElement(
                'div',
                _extends({ className: classes }, rest),
                React.createElement(
                    'div',
                    {
                        className: classNames('scroll-wrap-container', 'style--' + shadowSize),
                        onScroll: this.throttledOnContentScroll,
                        ref: function ref(el) {
                            _this2.scrollRef = el;
                            scrollRefFn(el);
                        }
                    },
                    children
                )
            );
        }
    }]);

    return ScrollWrapper;
}(React.Component);

ScrollWrapper.defaultProps = {
    scrollRefFn: noop,
    shadowSize: 'cover'
};
ScrollWrapper.propTypes = {
    /** Contents for this element */
    children: PropTypes.node.isRequired,

    /** Optional class name(s) to pass thru to the component */
    className: PropTypes.string,

    /** Optional function to get the scrollRef in parent components */
    scrollRefFn: PropTypes.func.isRequired,

    /** Optional prop to set the shadow size, like background-size ('cover' or 'contain') */
    shadowSize: PropTypes.oneOf(['cover', 'contain']).isRequired
};


export default ScrollWrapper;
import PropTypes from 'prop-types';