var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import * as React from 'react';
import classNames from 'classnames';
import scrollIntoViewIfNeeded from 'scroll-into-view-if-needed';
import uniqueId from 'lodash/uniqueId';

import IconCheck from '../../icons/general/IconCheck';
import SelectButton from '../select-button';
import DatalistItem from '../datalist-item';


import './SelectField.scss';

function stopDefaultEvent(event) {
    event.preventDefault();
    event.stopPropagation();
}

function toggleOption(options, value) {
    var index = options.indexOf(value);

    if (index === -1) {
        options.push(value);
    } else {
        options.splice(index, 1);
    }
}

var BaseSelectField = function (_React$Component) {
    _inherits(BaseSelectField, _React$Component);

    function BaseSelectField(props) {
        _classCallCheck(this, BaseSelectField);

        var _this = _possibleConstructorReturn(this, (BaseSelectField.__proto__ || Object.getPrototypeOf(BaseSelectField)).call(this, props));

        _this.setActiveItem = function (index) {
            _this.setState({ activeItemIndex: index });
            if (index === -1) {
                _this.setActiveItemID(null);
            }
        };

        _this.setActiveItemID = function (id) {
            _this.setState({ activeItemID: id });
            _this.scrollItemIntoView(id);
        };

        _this.scrollItemIntoView = function (id) {
            // @NOTE(jackiechen): breaks encapsulation but alternative is unknown child ref
            var itemEl = id ? document.getElementById(id) : null;
            if (itemEl) {
                scrollIntoViewIfNeeded(itemEl, false);
            }
        };

        _this.handleChange = function (selectedItems) {
            var onChange = _this.props.onChange;


            if (onChange) {
                onChange(selectedItems);
            }
        };

        _this.handleOptionSelect = function (selectedItem) {
            var onOptionSelect = _this.props.onOptionSelect;


            if (onOptionSelect) {
                onOptionSelect(selectedItem);
            }
        };

        _this.handleButtonClick = function () {
            if (_this.state.isOpen) {
                _this.closeDropdown();
            } else {
                _this.openDropdown();
            }
        };

        _this.handleButtonKeyDown = function (event) {
            var activeItemIndex = _this.state.activeItemIndex;

            // If user is interacting with the select dropdown, don't close on space/enter (i.e. prevent click event)

            if ((event.key === ' ' || event.key === 'Enter') && activeItemIndex !== -1) {
                event.preventDefault();
            }
        };

        _this.handleBlur = function () {
            var isOpen = _this.state.isOpen;

            if (isOpen) {
                _this.closeDropdown();
            }
        };

        _this.handleKeyDown = function (event) {
            var options = _this.props.options;
            var _this$state = _this.state,
                activeItemIndex = _this$state.activeItemIndex,
                isOpen = _this$state.isOpen;

            var itemCount = options.length;

            switch (event.key) {
                case 'ArrowDown':
                    stopDefaultEvent(event);
                    if (isOpen) {
                        var nextIndex = activeItemIndex === itemCount - 1 ? -1 : activeItemIndex + 1;
                        _this.setActiveItem(nextIndex);
                    } else {
                        _this.openDropdown();
                    }
                    break;
                case 'ArrowUp':
                    stopDefaultEvent(event);
                    if (isOpen) {
                        var prevIndex = activeItemIndex === -1 ? itemCount - 1 : activeItemIndex - 1;
                        _this.setActiveItem(prevIndex);
                    } else {
                        _this.openDropdown();
                    }
                    break;
                case 'Enter':
                case ' ':
                    if (activeItemIndex !== -1 && isOpen) {
                        stopDefaultEvent(event);
                        _this.selectOption(activeItemIndex);
                        // Enter always closes dropdown (even for multiselect)
                        if (event.key === 'Enter') {
                            _this.closeDropdown();
                        }
                    }
                    break;
                case 'Escape':
                    if (isOpen) {
                        stopDefaultEvent(event);
                        _this.closeDropdown();
                    }
                    break;
                // no default
            }
        };

        _this.openDropdown = function () {
            if (!_this.state.isOpen) {
                _this.setState({ isOpen: true });
            }
        };

        _this.closeDropdown = function () {
            if (_this.state.isOpen) {
                _this.setState({
                    activeItemID: null,
                    activeItemIndex: -1,
                    isOpen: false
                });
            }
        };

        _this.selectOption = function (index) {
            var multiple = _this.props.multiple;


            if (multiple) {
                _this.selectMultiOption(index);
            } else {
                _this.selectSingleOption(index);
                _this.closeDropdown(); // Close dropdown for single select fields
            }
        };

        _this.selectMultiOption = function (index) {
            var _this$props = _this.props,
                defaultValue = _this$props.defaultValue,
                options = _this$props.options,
                selectedValues = _this$props.selectedValues;

            var hasDefaultValue = defaultValue != null; // Checks if not undefined or null
            var item = options[index];

            // If we are already using the default option, just return without firing onChange
            if (hasDefaultValue && defaultValue === item.value) {
                _this.selectSingleOption(index);
                return;
            }

            // Copy the array so we can freely modify it
            var newSelectedValues = selectedValues.slice(0);
            toggleOption(newSelectedValues, item.value);

            // Apply constraints if a defaultValue is specified
            if (hasDefaultValue) {
                var defaultOptionIndex = options.findIndex(function (option) {
                    return option.value === defaultValue;
                });

                if (defaultOptionIndex !== -1) {
                    if (newSelectedValues.length === 0) {
                        // If nothing is selected, we should select the default option
                        _this.selectSingleOption(defaultOptionIndex);
                        return;
                    } else if (newSelectedValues.length > 1 && newSelectedValues.includes(defaultValue)) {
                        // Remove the default option from the selected values when more than one thing is selected
                        newSelectedValues.splice(defaultOptionIndex, 1);
                    }
                }
            }

            // Fire onchange event with selected items
            _this.handleChange(options.filter(function (option) {
                return newSelectedValues.includes(option.value);
            }));

            _this.handleOptionSelect(item);
        };

        _this.renderButtonText = function () {
            var _this$props2 = _this.props,
                options = _this$props2.options,
                placeholder = _this$props2.placeholder,
                selectedValues = _this$props2.selectedValues,
                title = _this$props2.title;

            var selectedItemCount = selectedValues.length;

            // When there are no options selected, render placeholder
            if (selectedItemCount === 0 && placeholder) {
                return placeholder;
            }

            // User-specified title when options are selected
            if (title) {
                return title;
            }

            // Auto-generate button title based on selected options
            var selectedOptions = options.filter(function (option) {
                return selectedValues.includes(option.value);
            });
            return selectedOptions.map(function (option) {
                return option.displayText;
            }).join(', ');
        };

        _this.renderSelectButton = function () {
            var _this$state2 = _this.state,
                activeItemID = _this$state2.activeItemID,
                isOpen = _this$state2.isOpen;
            var _this$props3 = _this.props,
                buttonElProps = _this$props3.buttonProps,
                isDisabled = _this$props3.isDisabled,
                className = _this$props3.className;


            var buttonText = _this.renderButtonText();
            var buttonProps = _extends({}, buttonElProps, {
                'aria-activedescendant': activeItemID,
                'aria-autocomplete': 'list',
                'aria-expanded': isOpen,
                'aria-owns': _this.selectFieldID,
                className: className,
                isDisabled: isDisabled,
                onClick: _this.handleButtonClick,
                onKeyDown: _this.handleButtonKeyDown,
                // @NOTE: Technically, only text inputs should be combo-boxes but ARIA specs do not cover custom select dropdowns
                role: 'combobox',
                title: buttonText
            });

            return React.createElement(
                SelectButton,
                buttonProps,
                buttonText
            );
        };

        _this.renderSelectOptions = function () {
            var _this$props4 = _this.props,
                options = _this$props4.options,
                selectedValues = _this$props4.selectedValues,
                separatorIndices = _this$props4.separatorIndices;
            var activeItemIndex = _this.state.activeItemIndex;


            var selectOptions = options.map(function (item, index) {
                var displayText = item.displayText,
                    value = item.value;


                var isSelected = selectedValues.includes(value);

                var itemProps = {
                    className: 'select-option',
                    key: index,
                    /* preventDefault on click to prevent wrapping label from re-triggering the select button */
                    onClick: function onClick(event) {
                        event.preventDefault();

                        _this.selectOption(index);
                    },
                    /* preventDefault on mousedown so blur doesn't happen before click */
                    onMouseDown: function onMouseDown(event) {
                        event.preventDefault();
                    },
                    onMouseEnter: function onMouseEnter() {
                        _this.setActiveItem(index);
                    },
                    setActiveItemID: _this.setActiveItemID
                };

                if (index === activeItemIndex) {
                    itemProps.isActive = true;
                }

                // The below actually does have a key, but eslint can't catch that
                /* eslint-disable react/jsx-key */
                return React.createElement(
                    DatalistItem,
                    itemProps,
                    React.createElement(
                        'div',
                        { className: 'select-option-check-icon' },
                        isSelected ? React.createElement(IconCheck, { height: 16, width: 16 }) : null
                    ),
                    displayText
                );
                /* eslint-enable react/jsx-key */
            });

            separatorIndices.forEach(function (separatorIndex, index) {
                selectOptions.splice(separatorIndex + index, 0, React.createElement('li', { key: 'separator' + separatorIndex, role: 'separator' }));
            });

            return selectOptions;
        };

        _this.selectFieldID = uniqueId('selectfield');

        _this.state = {
            activeItemID: null,
            activeItemIndex: -1,
            isOpen: false
        };
        return _this;
    }

    BaseSelectField.propTypes = {
        /** Props to add to the button element */
        buttonProps: PropTypes.object,

        /** CSS class for the select container */
        className: PropTypes.string,

        /** The fallback option value when other options are all unselected. Default option cannot be selected at the same time as other options. `selectedValues` must not be empty when this option is used. */
        defaultValue: function defaultValue() {
            return (typeof bpfrpt_proptype_SelectOptionValueProp === 'function' ? bpfrpt_proptype_SelectOptionValueProp : PropTypes.shape(bpfrpt_proptype_SelectOptionValueProp)).apply(this, arguments);
        },

        /** The select button is disabled if true */
        isDisabled: PropTypes.bool,
        multiple: PropTypes.bool.isRequired,

        /** Function will be called with an array of all selected options after user selects a new option */
        onChange: PropTypes.func.isRequired,

        /** Function will be called with the user selected option (even on deselect or when the option was previously selected) */
        onOptionSelect: PropTypes.func,

        /** List of options (displayText, value) */
        options: PropTypes.arrayOf(function () {
            return (typeof bpfrpt_proptype_SelectOptionProp === 'function' ? bpfrpt_proptype_SelectOptionProp : PropTypes.shape(bpfrpt_proptype_SelectOptionProp)).apply(this, arguments);
        }).isRequired,

        /** The select button text shown when no options are selected. */
        placeholder: PropTypes.oneOfType([PropTypes.string, PropTypes.node]),

        /** The currently selected option values (can be empty) */
        selectedValues: PropTypes.arrayOf(function () {
            return (typeof bpfrpt_proptype_SelectOptionValueProp === 'function' ? bpfrpt_proptype_SelectOptionValueProp : PropTypes.shape(bpfrpt_proptype_SelectOptionValueProp)).apply(this, arguments);
        }).isRequired,

        /**  Array of ordered indices indicating where to insert separators (ex. index 2 means insert a separator after option 2) */
        separatorIndices: PropTypes.arrayOf(PropTypes.number).isRequired,

        /** The select button text (by default, component will use comma separated list of all selected option displayText) */
        title: PropTypes.oneOfType([PropTypes.string, PropTypes.node])
    };

    _createClass(BaseSelectField, [{
        key: 'selectSingleOption',
        value: function selectSingleOption(index) {
            var _props = this.props,
                options = _props.options,
                selectedValues = _props.selectedValues;

            var item = options[index];
            // If item not previously selected, fire change handler
            if (!selectedValues.includes(item.value)) {
                this.handleChange([item]);
            }
            this.handleOptionSelect(item);
        }
    }, {
        key: 'render',
        value: function render() {
            var _props2 = this.props,
                className = _props2.className,
                multiple = _props2.multiple;
            var isOpen = this.state.isOpen;

            // @TODO(jtan): Need invariants on specific conditions.
            // 1) # of options should be non-zero
            // 2) selectedValues, if defined, should all exist in options
            // 3) defaultValue, if defined, should exist in options
            // 4) defaultValue, if defined, should mean selectedValues is never empty
            // 5) defaultValue, if defined, cannot be selected in addition to other options (must be exclusive)

            var listboxProps = {};
            if (multiple) {
                listboxProps['aria-multiselectable'] = true;
            }

            return React.createElement(
                'div',
                {
                    className: classNames('select-container', className),
                    onBlur: this.handleBlur,
                    onKeyDown: this.handleKeyDown
                },
                React.createElement(
                    'div',
                    { className: 'select-field' },
                    this.renderSelectButton(),
                    React.createElement(
                        'div',
                        {
                            className: classNames('overlay-wrapper', {
                                'is-visible': isOpen
                            })
                        },
                        React.createElement(
                            'ul',
                            _extends({
                                className: 'overlay',
                                id: this.selectFieldID,
                                role: 'listbox'
                            }, listboxProps),
                            this.renderSelectOptions()
                        )
                    )
                )
            );
        }
    }]);

    return BaseSelectField;
}(React.Component);

BaseSelectField.defaultProps = {
    buttonProps: {},
    isDisabled: false,
    multiple: false,
    options: [],
    selectedValues: [],
    separatorIndices: []
};
BaseSelectField.propTypes = {
    buttonProps: PropTypes.object,
    className: PropTypes.string,
    defaultValue: function defaultValue() {
        return (typeof bpfrpt_proptype_SelectOptionValueProp === 'function' ? bpfrpt_proptype_SelectOptionValueProp : PropTypes.shape(bpfrpt_proptype_SelectOptionValueProp)).apply(this, arguments);
    },
    isDisabled: PropTypes.bool,
    multiple: PropTypes.bool.isRequired,
    onChange: PropTypes.func.isRequired,
    onOptionSelect: PropTypes.func,
    options: PropTypes.arrayOf(function () {
        return (typeof bpfrpt_proptype_SelectOptionProp === 'function' ? bpfrpt_proptype_SelectOptionProp : PropTypes.shape(bpfrpt_proptype_SelectOptionProp)).apply(this, arguments);
    }).isRequired,
    placeholder: PropTypes.oneOfType([PropTypes.string, PropTypes.node]),
    selectedValues: PropTypes.arrayOf(function () {
        return (typeof bpfrpt_proptype_SelectOptionValueProp === 'function' ? bpfrpt_proptype_SelectOptionValueProp : PropTypes.shape(bpfrpt_proptype_SelectOptionValueProp)).apply(this, arguments);
    }).isRequired,
    separatorIndices: PropTypes.arrayOf(PropTypes.number).isRequired,
    title: PropTypes.oneOfType([PropTypes.string, PropTypes.node])
};


export default BaseSelectField;
import { bpfrpt_proptype_SelectOptionValueProp } from './props';
import { bpfrpt_proptype_SelectOptionProp } from './props';
import PropTypes from 'prop-types';