var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

import * as React from 'react';
import classNames from 'classnames';

import IconInfo from '../../icons/general/IconInfo';

import Tooltip from '../tooltip';
import Label from '../label';

import './Select.scss';

var Select = function Select(_ref) {
    var children = _ref.children,
        _ref$className = _ref.className,
        className = _ref$className === undefined ? '' : _ref$className,
        error = _ref.error,
        infoTooltip = _ref.infoTooltip,
        infoIconProps = _ref.infoIconProps,
        isDisabled = _ref.isDisabled,
        label = _ref.label,
        name = _ref.name,
        labelTooltip = _ref.labelTooltip,
        onChange = _ref.onChange,
        _ref$showErrorOutline = _ref.showErrorOutline,
        showErrorOutline = _ref$showErrorOutline === undefined ? false : _ref$showErrorOutline,
        _ref$showLabel = _ref.showLabel,
        showLabel = _ref$showLabel === undefined ? true : _ref$showLabel,
        rest = _objectWithoutProperties(_ref, ['children', 'className', 'error', 'infoTooltip', 'infoIconProps', 'isDisabled', 'label', 'name', 'labelTooltip', 'onChange', 'showErrorOutline', 'showLabel']);

    var classes = classNames(className, 'select-input-container', {
        'show-error': !!error || showErrorOutline,
        'is-disabled': isDisabled
    });

    return React.createElement(
        'div',
        { className: classes },
        React.createElement(
            Label,
            { hideLabel: !showLabel, text: label, tooltip: labelTooltip },
            React.createElement(
                Tooltip,
                {
                    isShown: !!error,
                    text: error || '',
                    position: 'middle-right',
                    theme: 'error'
                },
                React.createElement(
                    'span',
                    { className: 'select-container' },
                    React.createElement(
                        'span',
                        { className: 'select-container-inner' },
                        React.createElement(
                            'select',
                            _extends({
                                name: name,
                                disabled: isDisabled,
                                onChange: onChange
                            }, rest),
                            children
                        ),
                        React.createElement('span', { className: 'select-overlay' })
                    ),
                    infoTooltip && React.createElement(
                        Tooltip,
                        { text: infoTooltip, position: 'middle-right' },
                        React.createElement(
                            'span',
                            { className: 'tooltip-icon-container' },
                            React.createElement(IconInfo, _extends({
                                height: 16,
                                width: 16
                            }, infoIconProps))
                        )
                    )
                )
            )
        )
    );
};

Select.propTypes = {
    /** Input `<option />`'s */
    children: PropTypes.node,
    className: PropTypes.string,
    error: PropTypes.node,
    infoTooltip: PropTypes.node,
    infoIconProps: PropTypes.object,
    isDisabled: PropTypes.bool,

    /** Label displayed for the input */
    label: PropTypes.node.isRequired,
    name: PropTypes.string.isRequired,
    labelTooltip: PropTypes.string,

    /** Handler for the change event on the select element */
    onChange: PropTypes.func,
    showErrorOutline: PropTypes.bool,
    showLabel: PropTypes.bool
};
export default Select;
import PropTypes from 'prop-types';