var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import * as React from 'react';
import classNames from 'classnames';
import scrollIntoViewIfNeeded from 'scroll-into-view-if-needed';
import uniqueId from 'lodash/uniqueId';

import ScrollWrapper from '../../components/scroll-wrapper';

import './SelectorDropdown.scss';

function stopDefaultEvent(event) {
    event.preventDefault();
    event.stopPropagation();
}

var SelectorDropdown = function (_React$Component) {
    _inherits(SelectorDropdown, _React$Component);

    function SelectorDropdown(props) {
        _classCallCheck(this, SelectorDropdown);

        var _this = _possibleConstructorReturn(this, (SelectorDropdown.__proto__ || Object.getPrototypeOf(SelectorDropdown)).call(this, props));

        _this.setActiveItem = function (index) {
            _this.setState({ activeItemIndex: index });
            if (index === -1) {
                _this.setActiveItemID(null);
            }
        };

        _this.setActiveItemID = function (id) {
            _this.setState({ activeItemID: id });
            _this.scrollItemIntoView(id);
        };

        _this.scrollItemIntoView = function (id) {
            // @NOTE(jackiechen): breaks encapsulation but alternative is unknown child ref
            var itemEl = id ? document.getElementById(id) : null;
            if (itemEl) {
                var parentEl = itemEl;
                while (parentEl.parentElement instanceof HTMLElement && !parentEl.classList.contains('scroll-wrap-container') && // Scroll the container, not the body when contained in a scroll-container.
                !parentEl.classList.contains('modal') // Scroll the modal, not the body when contained in a modal.
                ) {
                    parentEl = parentEl.parentElement;
                }
                scrollIntoViewIfNeeded(itemEl, false, undefined, parentEl);
            }
        };

        _this.haveChildrenChanged = function (nextChildren) {
            var children = _this.props.children;

            var childrenCount = React.Children.count(children);
            var nextChildrenCount = React.Children.count(nextChildren);

            if (childrenCount !== nextChildrenCount) {
                return true;
            }

            if (childrenCount === 0) {
                return false;
            }

            var childrenKeys = React.Children.map(children, function (child) {
                return child.key;
            });
            var nextChildrenKeys = React.Children.map(nextChildren, function (child) {
                return child.key;
            });
            return childrenKeys.some(function (childKey, index) {
                return childKey !== nextChildrenKeys[index];
            });
        };

        _this.resetActiveItem = function () {
            _this.setState({
                activeItemID: null,
                activeItemIndex: -1
            });
        };

        _this.handleFocus = function () {
            _this.openDropdown();
        };

        _this.handleDocumentClick = function (event) {
            var container = _this.selectorDropdownRef.current;
            var isInside = container && event.target instanceof Node && container.contains(event.target) || container === event.target;

            if (!isInside) {
                _this.closeDropdown();
            }
        };

        _this.handleInput = function () {
            _this.openDropdown();
        };

        _this.handleKeyDown = function (event) {
            var _this$props = _this.props,
                children = _this$props.children,
                isAlwaysOpen = _this$props.isAlwaysOpen,
                onEnter = _this$props.onEnter;
            var activeItemIndex = _this.state.activeItemIndex;

            var childrenCount = React.Children.count(children);

            switch (event.key) {
                case 'ArrowDown':
                    if (_this.isDropdownOpen()) {
                        if (childrenCount) {
                            stopDefaultEvent(event);
                        }
                        var nextIndex = activeItemIndex === childrenCount - 1 ? -1 : activeItemIndex + 1;
                        _this.setActiveItem(nextIndex);
                    } else {
                        _this.openDropdown();
                    }
                    break;
                case 'ArrowUp':
                    if (_this.isDropdownOpen()) {
                        if (childrenCount) {
                            stopDefaultEvent(event);
                        }
                        var prevIndex = activeItemIndex === -1 ? childrenCount - 1 : activeItemIndex - 1;
                        _this.setActiveItem(prevIndex);
                    } else {
                        _this.openDropdown();
                    }
                    break;
                case 'Enter':
                    if (activeItemIndex !== -1 && _this.isDropdownOpen()) {
                        stopDefaultEvent(event);
                        _this.selectItem(activeItemIndex, event);
                    } else if (onEnter) {
                        onEnter(event);
                    }
                    break;
                case 'Tab':
                    if (_this.isDropdownOpen()) {
                        _this.closeDropdown();
                        _this.resetActiveItem();
                    }
                    break;
                case 'Escape':
                    if (!isAlwaysOpen && _this.isDropdownOpen()) {
                        stopDefaultEvent(event);
                        _this.closeDropdown();
                        _this.resetActiveItem();
                    }
                    break;
                // no default
            }
        };

        _this.isDropdownOpen = function () {
            var _this$props2 = _this.props,
                children = _this$props2.children,
                isAlwaysOpen = _this$props2.isAlwaysOpen;
            var shouldOpen = _this.state.shouldOpen;

            var childrenCount = React.Children.count(children);
            return childrenCount > 0 && (!!isAlwaysOpen || shouldOpen);
        };

        _this.openDropdown = function () {
            if (!_this.state.shouldOpen) {
                _this.setState({ shouldOpen: true });
                document.addEventListener('click', _this.handleDocumentClick, true);
            }
        };

        _this.closeDropdown = function () {
            _this.setState({ shouldOpen: false });
            document.removeEventListener('click', _this.handleDocumentClick, true);
        };

        _this.selectItem = function (index, event) {
            var onSelect = _this.props.onSelect;

            if (onSelect) {
                onSelect(index, event);
            }
            _this.closeDropdown();
        };

        _this.listboxID = uniqueId('listbox');

        _this.state = {
            activeItemID: null,
            activeItemIndex: -1,
            shouldOpen: false
        };

        _this.selectorDropdownRef = React.createRef();
        return _this;
    }

    _createClass(SelectorDropdown, [{
        key: 'componentWillReceiveProps',
        value: function componentWillReceiveProps(nextProps) {
            if (this.haveChildrenChanged(nextProps.children)) {
                this.resetActiveItem();
            }
        }
    }, {
        key: 'componentWillUnmount',
        value: function componentWillUnmount() {
            // just in case event listener was added during openDropdown() but the component
            // gets unmounted without closeDropdown()
            document.removeEventListener('click', this.handleDocumentClick, true);
        }
    }, {
        key: 'render',
        value: function render() {
            var listboxID = this.listboxID,
                selectItem = this.selectItem,
                setActiveItem = this.setActiveItem,
                setActiveItemID = this.setActiveItemID,
                _closeDropdown = this.closeDropdown;
            var _props = this.props,
                children = _props.children,
                className = _props.className,
                title = _props.title,
                selector = _props.selector,
                shouldScroll = _props.shouldScroll;
            var _state = this.state,
                activeItemID = _state.activeItemID,
                activeItemIndex = _state.activeItemIndex;

            var isOpen = this.isDropdownOpen();
            var inputProps = {
                'aria-activedescendant': activeItemID,
                'aria-autocomplete': 'list',
                'aria-expanded': isOpen,
                role: 'combobox'
            };
            if (isOpen) {
                inputProps['aria-owns'] = listboxID;
            }

            var list = React.createElement(
                'ul',
                { className: 'overlay', id: listboxID, role: 'listbox' },
                React.Children.map(children, function (item, index) {
                    var itemProps = {
                        onClick: function onClick(event) {
                            selectItem(index, event);
                        },
                        /* preventDefault on mousedown so blur doesn't happen before click */
                        onMouseDown: function onMouseDown(event) {
                            event.preventDefault();
                        },
                        onMouseEnter: function onMouseEnter() {
                            setActiveItem(index);
                        },
                        closeDropdown: function closeDropdown() {
                            _closeDropdown();
                        },
                        setActiveItemID: setActiveItemID
                    };
                    if (index === activeItemIndex) {
                        itemProps.isActive = true;
                    }
                    return React.cloneElement(item, itemProps);
                })
            );

            // change onKeyPress/onPaste back to onInput when React fixes this IE11 bug: https://github.com/facebook/react/issues/7280

            // We're simulating the blur event with the tab key listener and the
            // click listener as a proxy because IE will trigger a blur when
            // using the scrollbar in the dropdown which indavertently closes the dropdown.
            return React.createElement(
                'div',
                {
                    className: classNames('selector-dropdown-wrapper', className),
                    onFocus: this.handleFocus,
                    onKeyDown: this.handleKeyDown,
                    onKeyPress: this.handleInput,
                    onPaste: this.handleInput,
                    ref: this.selectorDropdownRef
                },
                React.cloneElement(selector, { inputProps: inputProps }),
                isOpen && React.createElement(
                    'div',
                    { className: 'overlay-wrapper is-visible' },
                    title,
                    shouldScroll ? React.createElement(
                        ScrollWrapper,
                        null,
                        list
                    ) : list
                )
            );
        }
    }]);

    return SelectorDropdown;
}(React.Component);

SelectorDropdown.propTypes = {
    /** Options to keep the results always open */
    isAlwaysOpen: PropTypes.bool,

    /** Options to render in the dropdown filtered based on the input text */
    children: PropTypes.node,

    /** CSS class for the wrapper div */
    className: PropTypes.string,

    /** Optional title text that will be rendered above the list */
    title: PropTypes.node,

    /** Function called on keyboard "Enter" event only if enter does not trigger selection */
    onEnter: PropTypes.func,

    /** Function called with the index of the selected option and the event (selected by keyboard or click) */
    onSelect: PropTypes.func,

    /** Component containing an input text field and takes `inputProps` to spread onto the input element */
    selector: PropTypes.node.isRequired,

    /** Boolean to indicate whether the dropdown should scroll */
    shouldScroll: PropTypes.bool
};


export default SelectorDropdown;
import PropTypes from 'prop-types';