var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import * as React from 'react';
import classNames from 'classnames';
import omit from 'lodash/omit';
import { FormattedMessage } from 'react-intl';

import TextInput from '../text-input';
import Button from '../button';
import messages from '../../common/messages';

import './TextInputWithCopyButton.scss';

var DEFAULT_SUCCESS_STATE_DURATION = 3000;

var defaultCopyText = React.createElement(FormattedMessage, messages.copy);
var defaultCopiedText = React.createElement(FormattedMessage, messages.copied);

var TextInputWithCopyButton = function (_React$PureComponent) {
    _inherits(TextInputWithCopyButton, _React$PureComponent);

    function TextInputWithCopyButton(props) {
        _classCallCheck(this, TextInputWithCopyButton);

        // $FlowFixMe https://github.com/facebook/flow/issues/4335
        var _this = _possibleConstructorReturn(this, (TextInputWithCopyButton.__proto__ || Object.getPrototypeOf(TextInputWithCopyButton)).call(this, props));

        _this.copySelectedText = function () {
            return document.execCommand('copy');
        };

        _this.restoreCopyButton = function () {
            _this.setState({
                copySuccess: false,
                buttonText: _this.props.buttonDefaultText
            });
        };

        _this.handleCopyButtonClick = function () {
            _this.performAutofocus();
            _this.copySelectedText();
            _this.animateCopyButton();
        };

        _this.handleFocus = function (event) {
            if (_this.copyInputRef) {
                _this.copyInputRef.select();
            }

            if (_this.props.onFocus) {
                _this.props.onFocus(event);
            }
        };

        _this.handleCopyEvent = function (event) {
            _this.animateCopyButton();

            var onCopySuccess = _this.props.onCopySuccess;

            if (onCopySuccess) {
                onCopySuccess(event);
            }
        };

        _this.performAutofocus = function () {
            if (_this.copyInputRef) {
                _this.copyInputRef.select();
            }
        };

        _this.renderCopyButton = function () {
            return _this.isCopyCommandSupported ? React.createElement(
                Button,
                _extends({
                    onClick: _this.handleCopyButtonClick,
                    type: 'button',
                    isDisabled: _this.props.disabled
                }, _this.props.buttonProps),
                _this.state.buttonText
            ) : null;
        };

        _this.isCopyCommandSupported = document.queryCommandSupported('copy');

        _this.state = {
            copySuccess: false,
            buttonText: props.buttonDefaultText,
            hasFocused: false
        };
        return _this;
    }

    TextInputWithCopyButton.propTypes = {
        /** Set the focus to input when component loads */
        autofocus: PropTypes.bool,

        /** Default copy button text */
        buttonDefaultText: PropTypes.oneOfType([PropTypes.string, PropTypes.node]),

        /** Copy button text when copy is successful */
        buttonSuccessText: PropTypes.oneOfType([PropTypes.string, PropTypes.node]),
        buttonProps: PropTypes.object,
        className: PropTypes.string.isRequired,
        disabled: PropTypes.bool,

        /** Label displayed for the text input */
        // TODO: Make label required
        label: PropTypes.node,

        /** onFocus handler for the input el */
        onFocus: PropTypes.func,

        /** Function called when link is copied by keyboard or button */
        onCopySuccess: PropTypes.func,

        /** Duration (milliseconds) in which to show the copy success state */
        successStateDuration: PropTypes.number.isRequired,

        /** trigger the copy animation when the component loads (used to simulate a click on copy button) */
        triggerCopyOnLoad: PropTypes.bool,

        /** html input types (email, url, text, number), defaults to 'text' */
        type: PropTypes.string.isRequired,

        /** Value of the text input */
        value: PropTypes.node.isRequired
    };

    _createClass(TextInputWithCopyButton, [{
        key: 'componentDidMount',
        value: function componentDidMount() {
            var _props = this.props,
                autofocus = _props.autofocus,
                value = _props.value;


            if (autofocus && value) {
                this.performAutofocus();
            }
        }
    }, {
        key: 'componentDidUpdate',
        value: function componentDidUpdate() {
            var _props2 = this.props,
                autofocus = _props2.autofocus,
                value = _props2.value,
                triggerCopyOnLoad = _props2.triggerCopyOnLoad;
            var _state = this.state,
                copySuccess = _state.copySuccess,
                hasFocused = _state.hasFocused;

            // if we've set focus before, and should auto focus on update, make sure to
            // focus after component update

            if (autofocus && value) {
                this.performAutofocus();
            }

            if (triggerCopyOnLoad && !copySuccess && !hasFocused) {
                this.animateCopyButton();
            }
        }
    }, {
        key: 'componentWillUnmount',
        value: function componentWillUnmount() {
            this.clearCopySuccessTimeout();
        }
    }, {
        key: 'animateCopyButton',
        value: function animateCopyButton() {
            var _this2 = this;

            var _props3 = this.props,
                successStateDuration = _props3.successStateDuration,
                buttonSuccessText = _props3.buttonSuccessText;

            this.clearCopySuccessTimeout();

            this.setState({
                copySuccess: true,
                buttonText: buttonSuccessText,
                hasFocused: true
            }, function () {
                _this2.copySuccessTimeout = setTimeout(function () {
                    _this2.restoreCopyButton();
                }, successStateDuration);
            });
        }
    }, {
        key: 'clearCopySuccessTimeout',
        value: function clearCopySuccessTimeout() {
            if (!this.copySuccessTimeout) {
                return;
            }
            clearTimeout(this.copySuccessTimeout);
            this.copySuccessTimeout = null;
        }
    }, {
        key: 'render',
        value: function render() {
            var _this3 = this;

            var _props4 = this.props,
                className = _props4.className,
                rest = _objectWithoutProperties(_props4, ['className']);

            var copySuccess = this.state.copySuccess;
            var isCopyCommandSupported = this.isCopyCommandSupported;


            var inputProps = omit(rest, ['autofocus', 'buttonDefaultText', 'buttonSuccessText', 'buttonProps', 'onCopySuccess', 'successStateDuration', 'triggerCopyOnLoad']);

            if (isCopyCommandSupported) {
                inputProps.inputRef = function (ref) {
                    _this3.copyInputRef = ref;
                };
            }

            var wrapperClasses = classNames(className, {
                'copy-success': copySuccess,
                'text-input-with-copy-button-container': isCopyCommandSupported
            });

            var copyEvent = isCopyCommandSupported ? { onCopy: this.handleCopyEvent } : {};

            return React.createElement(
                'div',
                _extends({ className: wrapperClasses }, copyEvent),
                React.createElement(TextInput, _extends({}, inputProps, { onFocus: this.handleFocus })),
                this.renderCopyButton()
            );
        }
    }]);

    return TextInputWithCopyButton;
}(React.PureComponent);

TextInputWithCopyButton.defaultProps = {
    buttonDefaultText: defaultCopyText,
    buttonProps: {},
    buttonSuccessText: defaultCopiedText,
    className: '',
    hideOptionalLabel: true,
    readOnly: true,
    successStateDuration: DEFAULT_SUCCESS_STATE_DURATION,
    type: 'text'
};
TextInputWithCopyButton.propTypes = {
    autofocus: PropTypes.bool,
    buttonDefaultText: PropTypes.oneOfType([PropTypes.string, PropTypes.node]),
    buttonSuccessText: PropTypes.oneOfType([PropTypes.string, PropTypes.node]),
    buttonProps: PropTypes.object,
    className: PropTypes.string.isRequired,
    disabled: PropTypes.bool,
    label: PropTypes.node,
    onFocus: PropTypes.func,
    onCopySuccess: PropTypes.func,
    successStateDuration: PropTypes.number.isRequired,
    triggerCopyOnLoad: PropTypes.bool,
    type: PropTypes.string.isRequired,
    value: PropTypes.node.isRequired
};


export default TextInputWithCopyButton;
import PropTypes from 'prop-types';