var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import PropTypes from 'prop-types';
import React, { Component, cloneElement } from 'react';

import Overlay from './Overlay';

/**
 * Checks if there is a clickable ancestor or self
 * @param {Node} rootNode The base node we should stop at
 * @param {Node} targetNode The target node of the event
 * @returns {boolean}
 */
var hasClickableAncestor = function hasClickableAncestor(rootNode, targetNode) {
    // Check if the element or any of the ancestors are click-able (stopping at the component boundary)
    var currentNode = targetNode;
    while (currentNode && currentNode.parentNode && currentNode !== rootNode) {
        var nodeName = currentNode.nodeName.toUpperCase();
        if (nodeName === 'A' || nodeName === 'BUTTON') {
            return true;
        }
        currentNode = currentNode.parentNode;
    }
    return false;
};

var ToggleOverlay = function (_Component) {
    _inherits(ToggleOverlay, _Component);

    function ToggleOverlay(props) {
        _classCallCheck(this, ToggleOverlay);

        var _this = _possibleConstructorReturn(this, (ToggleOverlay.__proto__ || Object.getPrototypeOf(ToggleOverlay)).call(this, props));

        _this.handleOverlayClick = function (event) {
            var closeOnClick = _this.props.closeOnClick;

            // Close overlay on click if user interacted with a click-able element

            if (!closeOnClick || !hasClickableAncestor(_this.domNode, event.target)) {
                return;
            }

            _this.setState({ isVisible: false });
        };

        _this.handleClickOutside = function (event) {
            // Ignore "outside clicks" when clicking on the toggler. This means the toggler's handler
            // will take precedent over outside clicks.
            // Prevent clicks in pikaday datepicker (which is appended to body) from closing the overlay
            if (event.target !== _this.domNode && _this.domNode && _this.domNode.contains(event.target) || event.target.classList.contains('pika-select')) {
                return;
            }

            // Hide the menu when clicking outside of it
            _this.setState({ isVisible: false });
        };

        _this.handleTogglerClick = function (event) {
            _this.setState({ isVisible: !_this.state.isVisible });
            event.preventDefault();
        };

        _this.state = {
            isVisible: props.isVisibleByDefault
        };
        return _this;
    }

    _createClass(ToggleOverlay, [{
        key: 'render',
        value: function render() {
            var _this2 = this;

            var _props = this.props,
                className = _props.className,
                children = _props.children,
                toggler = _props.toggler;
            var isVisible = this.state.isVisible;

            // Clone the passed-in toggler to attach the click handler to it

            var togglerWithClickHandler = cloneElement(toggler, {
                onClick: this.handleTogglerClick
            });

            return React.createElement(
                'div',
                {
                    className: 'toggle-overlay-container ' + className,
                    ref: function ref(_ref) {
                        _this2.domNode = _ref;
                    }
                },
                togglerWithClickHandler,
                React.createElement(
                    Overlay,
                    {
                        isVisible: isVisible,
                        onClick: this.handleOverlayClick,
                        onClickOutside: this.handleClickOutside
                    },
                    children
                )
            );
        }
    }]);

    return ToggleOverlay;
}(Component);

ToggleOverlay.propTypes = {
    className: PropTypes.string,
    /** ToggleOverlay contents */
    children: PropTypes.node.isRequired,
    closeOnClick: PropTypes.bool,
    /** Component that toggles the overlay */
    toggler: PropTypes.node.isRequired,
    /** Is overlay visible by default */
    isVisibleByDefault: PropTypes.bool
};
ToggleOverlay.defaultProps = {
    className: '',
    closeOnClick: false,
    isVisibleByDefault: false
};


export default ToggleOverlay;