var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import PropTypes from 'prop-types';
import React, { cloneElement, Component } from 'react';
import classNames from 'classnames';
import { defineMessages, FormattedMessage } from 'react-intl';

import IconAlert from '../../icons/general/IconAlert';

import Label from '../../components/label';
import Tooltip from '../../components/tooltip';
import { SelectorItemsPropType } from '../../common/box-proptypes';
import parseCSV from '../../utils/parseCSV';
import Pill from '../pill';
import SelectorDropdown from '../selector-dropdown';

import '../../components/pill-selector-dropdown/PillSelector.scss';

export var UNLIMITED_NUM_OF_PILLS = -1;
var MaxNumPillsPropType = function MaxNumPillsPropType(props, propName, componentName) {
    var result = void 0;
    if (props[propName] && props[propName] < UNLIMITED_NUM_OF_PILLS) {
        result = new Error('Invalid prop \'' + propName + '\' supplied to \'' + componentName + '\'. Value must be greater than or equal to 0');
    }
    return result;
};

var messages = defineMessages({
    pillSelectorIconAlertText: {
        'id': 'boxui.pillSelector.iconAlertText',
        'defaultMessage': 'Input Error'
    }
});

var PillSelector = function (_Component) {
    _inherits(PillSelector, _Component);

    function PillSelector(props) {
        _classCallCheck(this, PillSelector);

        var _this = _possibleConstructorReturn(this, (PillSelector.__proto__ || Object.getPrototypeOf(PillSelector)).call(this, props));

        _this.handleDocumentClick = function (event) {
            var isInside = _this.domNode && _this.domNode.contains(event.target) || _this.domNode === event.target;

            if (!isInside) {
                _this.handleInputFocusOut();
            }
        };

        _this.handleInputFocus = function (event) {
            var onFocus = _this.props.onFocus;


            _this.setState({
                isFocused: true
            });

            if (onFocus) {
                onFocus(event);
            }
        };

        _this.handleInputFocusOut = function (event) {
            var isFocused = _this.state.isFocused;
            var onBlur = _this.props.onBlur;

            var numPillsAdded = _this.addPillsFromInput();

            if (numPillsAdded === 0) {
                if (isFocused) {
                    _this.setState({ isFocused: false });
                    if (onBlur) {
                        onBlur({ target: _this.pillSelectorInput });
                    }
                }
            } else if (event) {
                event.preventDefault();
            }
        };

        _this.hasHighlightedSelectorItem = function () {
            var selectorItems = _this.props.selectorItems;
            var _this$state = _this.state,
                isCompositionMode = _this$state.isCompositionMode,
                selectedItemIndex = _this$state.selectedItemIndex;

            var hasSelectedItem = selectorItems.length > 0 && selectedItemIndex < selectorItems.length;

            return isCompositionMode || hasSelectedItem;
        };

        _this.handleInputKeyDown = function (event) {
            var _this$props = _this.props,
                onItemRemove = _this$props.onItemRemove,
                selectedItems = _this$props.selectedItems;

            switch (event.key) {
                case 'Backspace':
                    {
                        // Only remove pill when input has no text
                        if (!event.target.value) {
                            event.preventDefault();
                            var index = selectedItems.length - 1;
                            onItemRemove(selectedItems[index], index);
                        }
                        break;
                    }
                case 'Enter':
                    {
                        if (_this.hasHighlightedSelectorItem()) {
                            return;
                        }
                        _this.addPillsFromInput();
                        break;
                    }
                case 'Tab':
                    {
                        if (_this.hasHighlightedSelectorItem()) {
                            return;
                        }
                        _this.handleInputFocusOut(event);
                        break;
                    }
                default:
                // Ignore other keys
            }
        };

        _this.handleCompositionStart = function () {
            _this.setState({
                isCompositionMode: true
            });
        };

        _this.handleCompositionEnd = function () {
            _this.setState({
                isCompositionMode: false
            });
        };

        _this.handleItemSelection = function (index) {
            var selectorItems = _this.props.selectorItems;


            _this.addPill(selectorItems[index]);
            _this.focusSelectorInput();

            // NOTE: setTimeout because this is in the path of the component
            // render cycle so the render will reset the scroll position afterward
            // if it is not done asynchronously.
            setTimeout(_this.scrollInputToBottom, 0);
        };

        _this.handleSelectedIndexChange = function (index) {
            _this.setState({ selectedItemIndex: index });
        };

        _this.addPill = function (newItem) {
            var onItemAdd = _this.props.onItemAdd;


            onItemAdd(newItem);
            _this.updateUserInput('');
        };

        _this.parsePills = function (text) {
            var _this$props2 = _this.props,
                maxNumPills = _this$props2.maxNumPills,
                parseItems = _this$props2.parseItems,
                validator = _this$props2.validator;
            // Use parseItems is provided, otherwise default to CSV parser

            var pills = parseItems ? parseItems(text) : parseCSV(text);

            if (validator) {
                pills = pills.filter(function (pill) {
                    return validator(pill);
                });
            }

            if (maxNumPills !== UNLIMITED_NUM_OF_PILLS && pills.length > maxNumPills) {
                pills = pills.slice(0, maxNumPills);
            }

            // Keep the data format consistent with SelectorItemPropType
            return pills.map(function (pill) {
                return {
                    id: pill,
                    name: pill
                };
            });
        };

        _this.addPillsFromInput = function () {
            var pills = _this.parsePills(_this.pillSelectorInput.value);
            var count = pills.length;

            if (count > 0) {
                _this.addPill(pills);
            }
            return count;
        };

        _this.handlePaste = function () {
            setTimeout(_this.addPillsFromInput, 0);
        };

        _this.focusSelectorInput = function () {
            _this.pillSelectorInput.focus();
        };

        _this.scrollInputToBottom = function () {
            if (_this.pillSelectorInputWrapper) {
                _this.pillSelectorInputWrapper.scrollTop = _this.pillSelectorInputWrapper.scrollHeight;
            }
        };

        _this.updateUserInput = function (text) {
            var onUserInput = _this.props.onUserInput;


            _this.pillSelectorInput.value = text;

            onUserInput(text);
        };

        _this.hasReachedMaxPills = function (maxNumPills, selectedItems) {
            return maxNumPills !== UNLIMITED_NUM_OF_PILLS && selectedItems.length >= maxNumPills;
        };

        _this.isTextareaDisabled = function () {
            var _this$props3 = _this.props,
                maxNumPills = _this$props3.maxNumPills,
                isDisabled = _this$props3.isDisabled,
                selectedItems = _this$props3.selectedItems;

            return isDisabled || _this.hasReachedMaxPills(maxNumPills, selectedItems);
        };

        _this.state = {
            isCompositionMode: false,
            isFocused: false,
            selectedItemIndex: 0
        };
        return _this;
    }

    _createClass(PillSelector, [{
        key: 'componentDidMount',
        value: function componentDidMount() {
            document.addEventListener('click', this.handleDocumentClick, true);
            document.addEventListener('contextmenu', this.handleDocumentClick, true);
        }
    }, {
        key: 'componentWillUnmount',
        value: function componentWillUnmount() {
            document.removeEventListener('click', this.handleDocumentClick, true);
            document.removeEventListener('contextmenu', this.handleDocumentClick, true);
        }

        /**
         * The keyboard event (Enter/Tab etc) is being captured in bubbling phase
         * The textarea receives the event before the selector dropdown.
         * In order to add the pill correctly, we need to check if there is
         * selected item in the dropdown list so that we add it first.
         *
         * We could probably avoid this check by handling the event in capturing phase.
         */


        /**
         * We only parse pills when its pasted in
         */

    }, {
        key: 'render',
        value: function render() {
            var _this2 = this;

            var _props = this.props,
                autoFocus = _props.autoFocus,
                error = _props.error,
                isRequired = _props.isRequired,
                label = _props.label,
                name = _props.name,
                onItemRemove = _props.onItemRemove,
                onUserInput = _props.onUserInput,
                placeholder = _props.placeholder,
                selectedItems = _props.selectedItems,
                selectorItems = _props.selectorItems,
                selectorRow = _props.selectorRow,
                showDropdownOnClick = _props.showDropdownOnClick;
            var _state = this.state,
                isCompositionMode = _state.isCompositionMode,
                isFocused = _state.isFocused;

            var isTextareaDisabled = this.isTextareaDisabled();
            var classes = classNames({
                'pill-selector-input-wrapper': true,
                'is-focused': isFocused,
                'is-disabled': isTextareaDisabled,
                'show-error': !!error
            });

            return React.createElement(
                'div',
                {
                    className: 'pill-selector-wrapper',
                    ref: function ref(_ref3) {
                        _this2.domNode = _ref3;
                    }
                },
                selectedItems.map(function (item, i) {
                    return React.createElement('input', {
                        key: i,
                        type: 'text',
                        name: name + '[]',
                        value: item.id,
                        hidden: true,
                        className: 'pill-selector-hidden-input',
                        readOnly: true
                    });
                }),
                React.createElement(
                    Label,
                    { text: label, showOptionalText: !isRequired },
                    React.createElement(
                        SelectorDropdown,
                        {
                            onItemSelected: this.handleItemSelection,
                            onSelectedIndexChanged: this.handleSelectedIndexChange,
                            onSelectorUserInput: onUserInput,
                            selectOnTab: true,
                            showOnSelectorClick: showDropdownOnClick,
                            selector: React.createElement(
                                Tooltip,
                                {
                                    isShown: !!error,
                                    text: error || '',
                                    theme: 'error',
                                    position: 'bottom-left'
                                },
                                React.createElement(
                                    'div',
                                    {
                                        className: classes,
                                        onClick: this.focusSelectorInput,
                                        ref: function ref(_ref2) {
                                            _this2.pillSelectorInputWrapper = _ref2;
                                        }
                                    },
                                    selectedItems.map(function (item, i) {
                                        return React.createElement(Pill, {
                                            key: i,
                                            onPillRemove: onItemRemove.bind(_this2, item, i),
                                            text: item.name,
                                            tooltip: item.tooltip,
                                            isValid: item.isValid
                                        });
                                    }),
                                    React.createElement('textarea', {
                                        disabled: isTextareaDisabled,
                                        autoFocus: autoFocus,
                                        className: 'pill-selector-input',
                                        autoComplete: 'off',
                                        onCompositionStart: this.handleCompositionStart,
                                        onCompositionEnd: this.handleCompositionEnd,
                                        ref: function ref(_ref) {
                                            _this2.pillSelectorInput = _ref;
                                        },
                                        rows: '1',
                                        style: { resize: 'none' },
                                        onFocus: this.handleInputFocus,
                                        onKeyDown: this.handleInputKeyDown,
                                        onPaste: this.handlePaste,
                                        placeholder: selectedItems.length === 0 ? placeholder : ''
                                    }),
                                    React.createElement(IconAlert, {
                                        height: 16,
                                        width: 16,
                                        title: React.createElement(FormattedMessage, messages.pillSelectorIconAlertText)
                                    })
                                )
                            )
                        },
                        isCompositionMode ? [] : selectorItems.map(function (item) {
                            return cloneElement(selectorRow, _extends({}, selectorRow.props, item, {
                                key: item.id
                            }));
                        })
                    )
                )
            );
        }
    }]);

    return PillSelector;
}(Component);

PillSelector.propTypes = {
    /** Whether to automatically focus the pill selector */
    autoFocus: PropTypes.bool,
    /** Error message */
    error: PropTypes.node,
    /** Is the input disabled */
    isDisabled: PropTypes.bool,
    /** Is the input required */
    isRequired: PropTypes.bool,
    /** Label displayed for the input */
    label: PropTypes.node.isRequired,
    /** Optionally specify the max number of pills at which point, the input will be disabled and no more pills will be allowed to be added. */
    maxNumPills: MaxNumPillsPropType,
    /** Name of the input */
    name: PropTypes.string.isRequired,
    onBlur: PropTypes.func,
    onFocus: PropTypes.func,
    /** Called when pills are converted successfully. A list of `pill` item is passed */
    onItemAdd: PropTypes.func.isRequired,
    /** Called when a pill item is removed. The pill `item` and `index` are passed */
    onItemRemove: PropTypes.func.isRequired,
    /** Handler called on user text input. The new `inputValue` is passed in. */
    onUserInput: PropTypes.func,
    /** function to parse user input into an array of items to be validated and then added to pill selector. If this function is not passed, a default CSV parser is used. */
    parseItems: PropTypes.func,
    placeholder: PropTypes.string,
    /** Data for the pill items displayed in the input field. */
    selectedItems: SelectorItemsPropType,
    /** Data for the items displayed in the dropdown */
    selectorItems: SelectorItemsPropType,
    /** Selector row render function */
    selectorRow: PropTypes.node.isRequired,
    /** Is dropdown shown when clicking the selector */
    showDropdownOnClick: PropTypes.bool,
    /** Called to check if pill item data is valid. The `item` is passed in. */
    validator: PropTypes.func
};
PillSelector.defaultProps = {
    autoFocus: false,
    isRequired: false,
    maxNumPills: UNLIMITED_NUM_OF_PILLS,
    onUserInput: function onUserInput() {},
    showDropdownOnClick: false
};


export default PillSelector;