import PropTypes from 'prop-types';
import React from 'react';

import SearchMetadataDateRangeField from './SearchMetadataDateRangeField';
import SearchMetadataNumericRangeField from './SearchMetadataNumericRangeField';
import SearchMetadataSelectField from './SearchMetadataSelectField';
import SearchMetadataTextField from './SearchMetadataTextField';

var SearchMetadataField = function SearchMetadataField(_ref) {
    var field = _ref.field,
        onChange = _ref.onChange;
    var widget = field.widget,
        id = field.id,
        format = field.format,
        isText = field.isText,
        label = field.displayName,
        options = field.options,
        description = field.description,
        initialValue = field.initialValue;


    switch (widget) {
        case 'text':
            return React.createElement(SearchMetadataTextField, {
                id: id,
                format: format,
                isText: isText,
                onChange: onChange,
                label: label,
                description: description,
                initialValue: initialValue
            });
        case 'dropdown':
            return React.createElement(SearchMetadataSelectField, {
                id: id,
                format: format,
                isText: isText,
                onChange: onChange,
                label: label,
                options: options,
                description: description,
                initialValue: initialValue
            });
        case 'datetimeRange':
            return React.createElement(SearchMetadataDateRangeField, {
                id: id,
                format: format,
                onChange: onChange,
                label: label,
                description: description,
                initialValue: initialValue
            });
        case 'numericRange':
            return React.createElement(SearchMetadataNumericRangeField, {
                id: id,
                format: format,
                onChange: onChange,
                label: label,
                description: description,
                initialValue: initialValue
            });
        default:
            return null;
    }
};

SearchMetadataField.propTypes = {
    field: PropTypes.shape({
        widget: PropTypes.string.isRequired,
        id: PropTypes.string.isRequired,
        format: PropTypes.string.isRequired,
        displayName: PropTypes.string.isRequired,
        isText: PropTypes.bool,
        description: PropTypes.string,
        options: PropTypes.arrayOf(PropTypes.shape({
            value: PropTypes.string.isRequired,
            displayName: PropTypes.string.isRequired
        })),
        initialValue: PropTypes.shape({
            enum: PropTypes.arrayOf(PropTypes.string),
            range: PropTypes.shape({
                gt: PropTypes.oneOfType([PropTypes.string, PropTypes.number]),
                lt: PropTypes.oneOfType([PropTypes.string, PropTypes.number])
            })
        })
    }).isRequired,
    onChange: PropTypes.func.isRequired
};

export default SearchMetadataField;