var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

import PropTypes from 'prop-types';
import React from 'react';
import { FormattedMessage } from 'react-intl';

import PlainButton from '../../components/plain-button';
import { ToggleOverlay } from '../overlay';
import IconCaretDown from '../../icons/general/IconCaretDown';

import SearchMetadata from './SearchMetadata';

import messages from './messages';

import './SearchMetadataFilter.scss';

var ToggleText = function ToggleText(_ref) {
    var numFiltersSet = _ref.numFiltersSet;
    return React.createElement(
        'span',
        { className: 'toggle-btn-text' },
        numFiltersSet ? React.createElement(FormattedMessage, _extends({}, messages.numFiltersSet, {
            values: { numFiltersSet: numFiltersSet }
        })) : React.createElement(FormattedMessage, messages.metadata)
    );
};

ToggleText.propTypes = {
    numFiltersSet: PropTypes.number
};

var ToggleCaret = function ToggleCaret() {
    return React.createElement(IconCaretDown, { width: 5, height: 3 });
};

var SearchMetadataFilter = function SearchMetadataFilter(_ref2) {
    var templates = _ref2.templates,
        filterState = _ref2.filterState,
        handleTemplateChange = _ref2.handleTemplateChange,
        numFiltersSet = _ref2.numFiltersSet;
    return React.createElement(
        ToggleOverlay,
        {
            className: 'box-ui-search-metadata-filter',
            toggler: React.createElement(
                PlainButton,
                {
                    className: 'toggle-btn',
                    type: 'button',
                    'data-resin-target': 'metadatafilter'
                },
                React.createElement(ToggleText, { numFiltersSet: numFiltersSet }),
                React.createElement(ToggleCaret, null)
            )
        },
        React.createElement(SearchMetadata, {
            templates: templates,
            filterState: filterState,
            handleTemplateChange: handleTemplateChange,
            includeFormButtons: true
        })
    );
};

SearchMetadataFilter.propTypes = {
    /** Array of metadata template objects */
    templates: PropTypes.arrayOf(PropTypes.shape({
        template: PropTypes.string.isRequired,
        scope: PropTypes.string.isRequired,
        typeKey: PropTypes.string.isRequired,
        displayName: PropTypes.string.isRequired
    })),
    /** Object with metadata filter info */
    filterState: PropTypes.shape({
        fields: PropTypes.arrayOf(PropTypes.shape({
            widget: PropTypes.string.isRequired,
            id: PropTypes.string.isRequired,
            format: PropTypes.string.isRequired,
            displayName: PropTypes.string.isRequired,
            isText: PropTypes.bool,
            description: PropTypes.string,
            options: PropTypes.arrayOf(PropTypes.shape({
                value: PropTypes.string.isRequired,
                displayName: PropTypes.string.isRequired
            })),
            initialValue: PropTypes.shape({
                enum: PropTypes.arrayOf(PropTypes.string),
                range: PropTypes.shape({
                    gt: PropTypes.oneOfType([PropTypes.string, PropTypes.number]),
                    lt: PropTypes.oneOfType([PropTypes.string, PropTypes.number])
                })
            })
        })),
        typeKey: PropTypes.string,
        template: PropTypes.string,
        scope: PropTypes.string,
        displayName: PropTypes.string,
        initialFilterMap: PropTypes.object
    }),
    /** A callback function for the change event on the template select element */
    handleTemplateChange: PropTypes.func.isRequired,
    numFiltersSet: PropTypes.number
};

SearchMetadataFilter.defaultProps = {
    templates: [],
    filterState: {},
    numFiltersSet: 0
};

export default SearchMetadataFilter;