var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import PropTypes from 'prop-types';
import React, { Component } from 'react';
import { defineMessages, injectIntl, intlShape } from 'react-intl';

import TextInput from '../../components/text-input';

import commonMessages from './messages';

var INTEGER_TYPE = 'integer';
var FLOAT_TYPE = 'float';
var RANGE_STR = 'range';

var messages = defineMessages({
    fromLabel: {
        'id': 'boxui.searchMetadata.fromNumericInputLabel',
        'defaultMessage': 'From'
    },
    toLabel: {
        'id': 'boxui.searchMetadata.toNumericInputLabel',
        'defaultMessage': 'To'
    },
    invalidIntegerValueError: {
        'id': 'boxui.searchMetadata.invalidIntegerValueError',
        'defaultMessage': 'Invalid integer value'
    },
    invalidFloatValueError: {
        'id': 'boxui.searchMetadata.invalidFloatValueError',
        'defaultMessage': 'Invalid float value'
    },
    invalidIntegerRangeError: {
        'id': 'boxui.searchMetadata.invalidIntegerRangeError',
        'defaultMessage': 'Invalid integer range'
    },
    invalidFloatRangeError: {
        'id': 'boxui.searchMetadata.invalidFloatRangeError',
        'defaultMessage': 'Invalid float range'
    }
});

function getNumberValue(value, format) {
    switch (format) {
        case INTEGER_TYPE:
            // eslint-disable-next-line no-useless-escape
            if (/^(\-|\+)?([0-9]+)$/.test(value)) {
                return parseInt(value, 10);
            }
            break;
        case FLOAT_TYPE:
            // eslint-disable-next-line no-useless-escape
            if (/^(\-|\+)?([0-9]+)(.[0-9]+)?$/.test(value)) {
                return parseFloat(value);
            }
            break;
        // no default
    }
    return null;
}

function getError(type, formatMessage) {
    switch (type) {
        case INTEGER_TYPE:
            return formatMessage(messages.invalidIntegerValueError);
        case FLOAT_TYPE:
            return formatMessage(messages.invalidFloatValueError);
        case INTEGER_TYPE + RANGE_STR:
            return formatMessage(messages.invalidIntegerRangeError);
        case FLOAT_TYPE + RANGE_STR:
            return formatMessage(messages.invalidFloatRangeError);
        default:
            return '';
    }
}

var SearchMetadataNumericRangeField = function (_Component) {
    _inherits(SearchMetadataNumericRangeField, _Component);

    function SearchMetadataNumericRangeField(props) {
        _classCallCheck(this, SearchMetadataNumericRangeField);

        var _this = _possibleConstructorReturn(this, (SearchMetadataNumericRangeField.__proto__ || Object.getPrototypeOf(SearchMetadataNumericRangeField)).call(this, props));

        _this.formatField = function () {
            var fromInputEl = _this.fromInputEl,
                toInputEl = _this.toInputEl;
            var _this$props = _this.props,
                id = _this$props.id,
                format = _this$props.format,
                onChange = _this$props.onChange;
            var _this$state = _this.state,
                fromValue = _this$state.fromValue,
                toValue = _this$state.toValue;

            var isFromValueValid = fromValue !== null;
            var isFromValueInvalid = !isFromValueValid && fromInputEl.value;
            var isToValueValid = toValue !== null;
            var isToValueInvalid = !isToValueValid && toInputEl.value;
            var isRangeValid = !(isFromValueValid && isToValueValid && toValue < fromValue);
            var field = null;
            if ((isFromValueValid || isToValueValid) && !isFromValueInvalid && !isToValueInvalid && isRangeValid) {
                var valueRange = {};
                if (isFromValueValid) {
                    valueRange.gt = fromValue;
                }
                if (isToValueValid) {
                    valueRange.lt = toValue;
                }
                field = {
                    key: id,
                    format: format,
                    value: { range: valueRange }
                };
            }
            onChange(id, field);
        };

        _this.checkRangeValidity = function (inputEl) {
            var fromInputEl = _this.fromInputEl,
                toInputEl = _this.toInputEl;
            var _this$props2 = _this.props,
                format = _this$props2.format,
                intl = _this$props2.intl;
            var _this$state2 = _this.state,
                fromValue = _this$state2.fromValue,
                toValue = _this$state2.toValue;


            if (fromValue !== null && toValue !== null && toValue < fromValue) {
                inputEl.setCustomValidity(getError(format + RANGE_STR, intl.formatMessage));
            } else {
                fromInputEl.setCustomValidity('');
                toInputEl.setCustomValidity('');
            }

            _this.setState({
                fromError: fromInputEl.validationMessage,
                toError: toInputEl.validationMessage
            });
        };

        _this.checkFromValidity = function () {
            var fromInputEl = _this.fromInputEl;
            var _this$props3 = _this.props,
                format = _this$props3.format,
                intl = _this$props3.intl;
            var fromValue = _this.state.fromValue;


            if (fromInputEl.value && fromValue === null) {
                fromInputEl.setCustomValidity(getError(format, intl.formatMessage));
                _this.setState({
                    fromError: fromInputEl.validationMessage
                });
            } else {
                _this.checkRangeValidity(fromInputEl);
            }
        };

        _this.checkToValidity = function () {
            var toInputEl = _this.toInputEl;
            var _this$props4 = _this.props,
                format = _this$props4.format,
                intl = _this$props4.intl;
            var toValue = _this.state.toValue;


            if (toInputEl.value && toValue === null) {
                toInputEl.setCustomValidity(getError(format, intl.formatMessage));
                _this.setState({
                    toError: toInputEl.validationMessage
                });
            } else {
                _this.checkRangeValidity(toInputEl);
            }
        };

        _this.handleFromChange = function (event) {
            var format = _this.props.format;
            var fromError = _this.state.fromError;

            var fromValue = getNumberValue(event.target.value, format);

            _this.setState({ fromValue: fromValue }, function () {
                if (fromError) {
                    _this.checkFromValidity();
                }
                _this.formatField();
            });
        };

        _this.handleToChange = function (event) {
            var format = _this.props.format;
            var toError = _this.state.toError;

            var toValue = getNumberValue(event.target.value, format);

            _this.setState({ toValue: toValue }, function () {
                if (toError) {
                    _this.checkToValidity();
                }
                _this.formatField();
            });
        };

        var _props$initialValue$r = props.initialValue.range,
            _props$initialValue$r2 = _props$initialValue$r.gt,
            gt = _props$initialValue$r2 === undefined ? null : _props$initialValue$r2,
            _props$initialValue$r3 = _props$initialValue$r.lt,
            lt = _props$initialValue$r3 === undefined ? null : _props$initialValue$r3;


        _this.state = {
            fromValue: gt,
            toValue: lt,
            fromError: '',
            toError: ''
        };
        return _this;
    }

    _createClass(SearchMetadataNumericRangeField, [{
        key: 'render',
        value: function render() {
            var _this2 = this;

            var _props = this.props,
                intl = _props.intl,
                label = _props.label,
                description = _props.description;
            var _state = this.state,
                fromValue = _state.fromValue,
                toValue = _state.toValue,
                fromError = _state.fromError,
                toError = _state.toError;
            var formatMessage = intl.formatMessage;
            var handleMouseEnter = this.handleMouseEnter,
                handleMouseLeave = this.handleMouseLeave,
                handleFromChange = this.handleFromChange,
                handleToChange = this.handleToChange,
                checkFromValidity = this.checkFromValidity,
                checkToValidity = this.checkToValidity;


            return React.createElement(
                'fieldset',
                { className: 'metadata-field' },
                React.createElement(
                    'legend',
                    {
                        onMouseEnter: handleMouseEnter,
                        onMouseLeave: handleMouseLeave
                    },
                    label
                ),
                React.createElement(TextInput, {
                    className: 'numeric-range-field',
                    type: 'number',
                    step: 'any',
                    label: formatMessage(messages.fromLabel),
                    placeholder: formatMessage(commonMessages.inputPlaceholder),
                    hideOptionalLabel: true,
                    onChange: handleFromChange,
                    defaultValue: fromValue,
                    inputRef: function inputRef(input) {
                        _this2.fromInputEl = input;
                    },
                    onBlur: checkFromValidity,
                    error: fromError,
                    'data-resin-target': 'metadatavalue'
                }),
                React.createElement(TextInput, {
                    className: 'numeric-range-field',
                    type: 'number',
                    step: 'any',
                    label: formatMessage(messages.toLabel),
                    placeholder: formatMessage(commonMessages.inputPlaceholder),
                    hideOptionalLabel: true,
                    onChange: handleToChange,
                    defaultValue: toValue,
                    onBlur: checkToValidity,
                    inputRef: function inputRef(input) {
                        _this2.toInputEl = input;
                    },
                    error: toError,
                    'data-resin-target': 'metadatavalue'
                }),
                React.createElement(
                    'small',
                    null,
                    description
                )
            );
        }
    }]);

    return SearchMetadataNumericRangeField;
}(Component);

SearchMetadataNumericRangeField.propTypes = {
    intl: intlShape.isRequired,
    id: PropTypes.string.isRequired,
    format: PropTypes.string.isRequired,
    onChange: PropTypes.func.isRequired,
    label: PropTypes.string.isRequired,
    description: PropTypes.string,
    initialValue: PropTypes.shape({
        range: PropTypes.shape({
            gt: PropTypes.number,
            lt: PropTypes.number
        }).isRequired
    })
};
SearchMetadataNumericRangeField.defaultProps = {
    initialValue: {
        range: {}
    }
};


export { SearchMetadataNumericRangeField as SearchMetadataNumericRangeFieldBase };
export default injectIntl(SearchMetadataNumericRangeField);