import PropTypes from 'prop-types';
import React from 'react';
import { defineMessages, injectIntl, intlShape } from 'react-intl';

import Select from '../../components/select';

var messages = defineMessages({
    selectPlaceholder: {
        'id': 'boxui.searchMetadata.selectValueSelectPlaceholder',
        'defaultMessage': 'Select Value'
    }
});

var SearchMetadataSelectField = function SearchMetadataSelectField(_ref) {
    var intl = _ref.intl,
        id = _ref.id,
        format = _ref.format,
        isText = _ref.isText,
        onChange = _ref.onChange,
        label = _ref.label,
        options = _ref.options,
        description = _ref.description,
        initialValue = _ref.initialValue;

    var formatField = function formatField(event) {
        var value = event.target.value;
        var field = null;
        if (value) {
            field = {
                key: id,
                format: format,
                value: { enum: [value] },
                isText: isText
            };
        }
        onChange(id, field);
    };

    return React.createElement(
        'div',
        { className: 'metadata-field' },
        React.createElement(
            Select,
            {
                name: '',
                label: label,
                onChange: formatField,
                defaultValue: initialValue ? initialValue.enum[0] : '',
                'data-resin-target': 'metadatavalue'
            },
            React.createElement(
                'option',
                { value: '' },
                intl.formatMessage(messages.selectPlaceholder)
            ),
            options.map(function (option) {
                return React.createElement(
                    'option',
                    { value: option.value, key: option.value },
                    option.displayName
                );
            })
        ),
        React.createElement(
            'small',
            null,
            description
        )
    );
};

SearchMetadataSelectField.propTypes = {
    intl: intlShape.isRequired,
    id: PropTypes.string.isRequired,
    format: PropTypes.string.isRequired,
    isText: PropTypes.bool.isRequired,
    onChange: PropTypes.func.isRequired,
    label: PropTypes.string.isRequired,
    options: PropTypes.arrayOf(PropTypes.shape({
        value: PropTypes.string.isRequired,
        displayName: PropTypes.string.isRequired
    })).isRequired,
    description: PropTypes.string,
    initialValue: PropTypes.shape({
        enum: PropTypes.arrayOf(PropTypes.string).isRequired
    })
};

export default injectIntl(SearchMetadataSelectField);