import PropTypes from 'prop-types';
import React from 'react';
import { defineMessages, injectIntl, intlShape } from 'react-intl';

import Select from '../../components/select';

var messages = defineMessages({
    selectLabel: {
        'id': 'boxui.searchMetadata.metadataTemplate',
        'defaultMessage': 'Metadata Template'
    },
    selectPlaceholder: {
        'id': 'boxui.searchMetadata.selectATemplate',
        'defaultMessage': 'Select a Template'
    }
});

var SearchMetadataTemplateSelect = function SearchMetadataTemplateSelect(_ref) {
    var intl = _ref.intl,
        templates = _ref.templates,
        onChange = _ref.onChange,
        selectedTemplateTypeKey = _ref.selectedTemplateTypeKey;
    var formatMessage = intl.formatMessage;


    return React.createElement(
        Select,
        {
            className: 'box-ui-metadata-template-select',
            name: '',
            label: formatMessage(messages.selectLabel),
            onChange: onChange,
            value: selectedTemplateTypeKey
        },
        React.createElement(
            'option',
            { value: '' },
            formatMessage(messages.selectPlaceholder)
        ),
        templates.map(function (template) {
            return React.createElement(
                'option',
                {
                    value: template.typeKey,
                    key: template.typeKey,
                    'data-metadata-template': template.template,
                    'data-metadata-scope': template.scope,
                    'data-resin-target': 'metadatatemplate',
                    'data-resin-metadatatemplatename': template.displayName
                },
                template.displayName
            );
        })
    );
};

SearchMetadataTemplateSelect.propTypes = {
    intl: intlShape.isRequired,
    templates: PropTypes.arrayOf(PropTypes.shape({
        template: PropTypes.string.isRequired,
        scope: PropTypes.string.isRequired,
        typeKey: PropTypes.string.isRequired,
        displayName: PropTypes.string.isRequired
    })).isRequired,
    onChange: PropTypes.func.isRequired,
    selectedTemplateTypeKey: PropTypes.string
};

SearchMetadataTemplateSelect.defaultProps = {
    selectedTemplateTypeKey: ''
};

export default injectIntl(SearchMetadataTemplateSelect);