import PropTypes from 'prop-types';
import React from 'react';
import { injectIntl, intlShape } from 'react-intl';

import TextInput from '../../components/text-input';

import commonMessages from './messages';

var SearchMetadataTextField = function SearchMetadataTextField(_ref) {
    var intl = _ref.intl,
        id = _ref.id,
        format = _ref.format,
        isText = _ref.isText,
        onChange = _ref.onChange,
        label = _ref.label,
        description = _ref.description,
        initialValue = _ref.initialValue;

    var formatField = function formatField(event) {
        var value = event.target.value.trim();
        var field = null;
        if (value) {
            field = {
                key: id,
                format: format,
                value: { enum: [value] },
                isText: isText
            };
        }
        onChange(id, field);
    };

    return React.createElement(
        'div',
        { className: 'metadata-field' },
        React.createElement(TextInput, {
            type: 'text',
            label: label,
            hideOptionalLabel: true,
            placeholder: intl.formatMessage(commonMessages.inputPlaceholder),
            onChange: formatField,
            defaultValue: initialValue ? initialValue.enum[0] : '',
            'data-resin-target': 'metadatavalue'
        }),
        React.createElement(
            'small',
            null,
            description
        )
    );
};

SearchMetadataTextField.propTypes = {
    intl: intlShape.isRequired,
    id: PropTypes.string.isRequired,
    format: PropTypes.string.isRequired,
    isText: PropTypes.bool.isRequired,
    onChange: PropTypes.func.isRequired,
    label: PropTypes.string.isRequired,
    description: PropTypes.string,
    initialValue: PropTypes.shape({
        enum: PropTypes.arrayOf(PropTypes.string).isRequired
    })
};

export default injectIntl(SearchMetadataTextField);