import PropTypes from 'prop-types';
import React from 'react';
import { defineMessages, FormattedMessage } from 'react-intl';

import IconCheck from '../../icons/general/IconCheck';

import Label from '../../components/label';
import Link from '../../components/link/Link';
import LinkGroup from '../../components/link/LinkGroup';
import Menu from '../menu/Menu';

import './SelectMulti.scss';

var messages = defineMessages({
    selectMultiPrimitiveIconCheckText: {
        'id': 'boxui.selectMultiPrimitive.iconCheckText',
        'defaultMessage': 'Checked'
    }
});

var SelectMultiPrimitive = function SelectMultiPrimitive(_ref) {
    var className = _ref.className,
        name = _ref.name,
        items = _ref.items,
        label = _ref.label,
        isVisible = _ref.isVisible,
        toggle = _ref.toggle,
        onItemSelected = _ref.onItemSelected,
        onClickOutside = _ref.onClickOutside;
    return React.createElement(
        'div',
        { className: 'select-multi select-container ' + className },
        React.createElement(
            Label,
            { text: label },
            toggle,
            items.map(function (item, i) {
                return React.createElement('input', {
                    key: i,
                    type: 'checkbox',
                    name: name + '[' + item.value + ']',
                    checked: !!item.isSelected,
                    readOnly: true
                });
            }),
            React.createElement(
                Menu,
                { isVisible: isVisible, onClickOutside: onClickOutside },
                React.createElement(
                    LinkGroup,
                    null,
                    items.map(function (item, i) {
                        return React.createElement(
                            Link,
                            {
                                key: i,
                                onClick: function onClick(event) {
                                    event.preventDefault();
                                    onItemSelected(i, item);
                                }
                            },
                            item.isSelected ? React.createElement(IconCheck, {
                                height: 16,
                                width: 16,
                                title: React.createElement(FormattedMessage, messages.selectMultiPrimitiveIconCheckText)
                            }) : null,
                            React.createElement(
                                'span',
                                { className: 'item-text' },
                                item.displayText
                            )
                        );
                    })
                )
            )
        )
    );
};

SelectMultiPrimitive.displayName = 'SelectMultiPrimitive';

SelectMultiPrimitive.propTypes = {
    className: PropTypes.string,
    isVisible: PropTypes.bool.isRequired,
    items: PropTypes.arrayOf(PropTypes.shape({
        displayText: PropTypes.string.isRequired,
        value: PropTypes.string.isRequired,
        isSelected: PropTypes.bool
    })),
    label: PropTypes.string.isRequired,
    name: PropTypes.string.isRequired,
    onClickOutside: PropTypes.func.isRequired,
    onItemSelected: PropTypes.func.isRequired,
    toggle: PropTypes.node.isRequired
};

export default SelectMultiPrimitive;