var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import PropTypes from 'prop-types';
import React, { Children, cloneElement, Component } from 'react';
import classNames from 'classnames';
import range from 'lodash/range';

import TableHeader from './TableHeader';
import TableRow from './TableRow';

var Table = function (_Component) {
    _inherits(Table, _Component);

    function Table(props) {
        _classCallCheck(this, Table);

        // These don't need to be react state, since we're not using them for rendering anything
        var _this = _possibleConstructorReturn(this, (Table.__proto__ || Object.getPrototypeOf(Table)).call(this, props));

        _this.state = {
            isScrolling: false
        };

        _this.handleScroll = function (event) {
            var scrollTop = event.target.scrollTop;

            if (scrollTop > 0 && !_this.state.isScrolling) {
                _this.setState({ isScrolling: true });
            } else if (scrollTop === 0 && _this.state.isScrolling) {
                _this.setState({ isScrolling: false });
            }
        };

        _this.renderRow = function (index) {
            var _this$props = _this.props,
                children = _this$props.children,
                data = _this$props.data,
                onRowClick = _this$props.onRowClick,
                onRowDoubleClick = _this$props.onRowDoubleClick,
                onRowMouseDown = _this$props.onRowMouseDown,
                onRowMouseEnter = _this$props.onRowMouseEnter,
                onRowMouseLeave = _this$props.onRowMouseLeave,
                onRowMouseUp = _this$props.onRowMouseUp,
                rowPropsGetter = _this$props.rowPropsGetter;


            var rowProps = rowPropsGetter ? rowPropsGetter(index) : null;
            return React.createElement(
                TableRow,
                _extends({
                    data: data,
                    index: index,
                    key: index,
                    onClick: onRowClick,
                    onDoubleClick: onRowDoubleClick,
                    onMouseDown: onRowMouseDown,
                    onMouseEnter: onRowMouseEnter,
                    onMouseLeave: onRowMouseLeave,
                    onMouseUp: onRowMouseUp
                }, rowProps),
                Children.map(children, function (column) {
                    return cloneElement(column.props.cell, _extends({}, column.props.cell.props, {
                        data: data,
                        rowIndex: index
                    }));
                })
            );
        };

        _this.anchorIndex = null;
        _this.previousRowIndex = null;
        return _this;
    }

    /**
     * Handles scroll events on the table body, so we can show/hide the header shadow.
     * We don't need to throttle this, because we will only call setState when the
     * scrolling state should change
     * @param {SyntheticEvent} event
     */


    /**
     * Render a single row from its index
     * @param {Number} index - The row index to render
     * @return {ReactElement} - Element of type TableRow
     */


    _createClass(Table, [{
        key: 'renderBody',


        /**
         * Renders the table children
         * @return {ReactElement[]} - an array of elements of type TableRow
         */
        value: function renderBody() {
            // http://facebook.github.io/react/docs/multiple-components.html#dynamic-children
            return range(0, this.props.data.length).map(this.renderRow);
        }
    }, {
        key: 'render',
        value: function render() {
            var _props = this.props,
                children = _props.children,
                className = _props.className,
                footer = _props.footer,
                isCompact = _props.isCompact;
            var isScrolling = this.state.isScrolling;


            var classes = classNames('table', 'has-hover-styles', className, {
                'is-compact': isCompact,
                'is-scrolling': isScrolling
            });

            return React.createElement(
                'div',
                { className: classes },
                React.createElement(
                    TableHeader,
                    null,
                    children
                ),
                React.createElement(
                    'div',
                    { className: 'table-body', onScroll: this.handleScroll },
                    this.renderBody(),
                    React.createElement(
                        'div',
                        { className: 'table-footer' },
                        footer
                    )
                )
            );
        }
    }]);

    return Table;
}(Component);

Table.propTypes = {
    /** `<TableColumns>`'s */
    children: PropTypes.node.isRequired,
    className: PropTypes.string,
    /** Array of objects to display */
    data: PropTypes.array.isRequired,
    /** Section to render DOM in `.table-body` underneath all of the table rows */
    footer: PropTypes.node,
    /** Render a compact table */
    isCompact: PropTypes.bool,
    /** Function called when row is clicked. `(event, index, rowData) => undefined` */
    onRowClick: PropTypes.func,
    /** Function called when row is double-clicked. `(event, index, rowData) => undefined`. */
    onRowDoubleClick: PropTypes.func,
    /** Function called when row is mouse-downed. `(event, index, rowData) => undefined`. */
    onRowMouseDown: PropTypes.func,
    /** Function called when row is hovered over. `(event, index, rowData) => undefined`. */
    onRowMouseEnter: PropTypes.func,
    /** Function called when row is un-hovered over. `(event, index, rowData) => undefined`. */
    onRowMouseLeave: PropTypes.func,
    /** Function called when row is mouse-upped. `(event, index, rowData) => undefined`. */
    onRowMouseUp: PropTypes.func,
    /** Function that returns an object containing each row's props. `(index) => Object`. */
    rowPropsGetter: PropTypes.func
};
Table.defaultProps = {
    className: '',
    data: []
};


export default Table;