var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import PropTypes from 'prop-types';
import React, { Component } from 'react';
import ImmutablePropTypes from 'react-immutable-proptypes';
import classNames from 'classnames';
import { Set } from 'immutable';

import shiftSelect from './shiftSelect';

/**
 * Enhance a Table with selection functionality
 * @param {Component} BaseTable - The table to enhance
 */
function makeSelectable(BaseTable) {
    var _class, _temp;

    var originalDisplayName = BaseTable.displayName || BaseTable.name || 'Table';
    return _temp = _class = function (_Component) {
        _inherits(SelectableTable, _Component);

        function SelectableTable(props) {
            _classCallCheck(this, SelectableTable);

            // These don't need to be react state, since we're not using them for rendering anything
            var _this = _possibleConstructorReturn(this, (SelectableTable.__proto__ || Object.getPrototypeOf(SelectableTable)).call(this, props));

            _this.selectToggle = function (rowIndex) {
                var _this$props = _this.props,
                    data = _this$props.data,
                    onSelect = _this$props.onSelect,
                    selectedRows = _this$props.selectedRows;


                if (selectedRows.has(rowIndex)) {
                    onSelect(selectedRows.delete(rowIndex), data[rowIndex]);
                } else {
                    onSelect(selectedRows.add(rowIndex), data[rowIndex]);
                }

                _this.anchorIndex = rowIndex;
                _this.previousRowIndex = rowIndex;
            };

            _this.selectRange = function (rowIndex) {
                var _this$props2 = _this.props,
                    data = _this$props2.data,
                    onSelect = _this$props2.onSelect,
                    selectedRows = _this$props2.selectedRows;

                // Don't change selection if we're shift-clicking the same row

                if (rowIndex === _this.previousRowIndex) {
                    return;
                }

                var newSelection = shiftSelect(selectedRows, _this.previousRowIndex, rowIndex, _this.anchorIndex);
                onSelect(newSelection, data[rowIndex]);
                _this.previousRowIndex = rowIndex;
            };

            _this.selectOne = function (rowIndex) {
                var _this$props3 = _this.props,
                    data = _this$props3.data,
                    onSelect = _this$props3.onSelect,
                    selectedRows = _this$props3.selectedRows;

                // Don't change selection if we're clicking on a row that we've already selected
                // This allows us to use the native onDoubleClick handler because we're referencing the
                // same DOM node on double-click.

                if (selectedRows.has(rowIndex) && selectedRows.size === 1) {
                    return;
                }

                onSelect(new Set([rowIndex]), data[rowIndex]);
                _this.anchorIndex = rowIndex;
                _this.previousRowIndex = rowIndex;
            };

            _this.handleRowClick = function (event, index) {
                var _this$props4 = _this.props,
                    onRowClick = _this$props4.onRowClick,
                    onSelect = _this$props4.onSelect;

                // Execute select functions only if onSelect is passed in

                if (onSelect) {
                    if (event.metaKey || event.ctrlKey) {
                        _this.selectToggle(index);
                    } else if (event.shiftKey) {
                        _this.selectRange(index);
                    } else {
                        _this.selectOne(index);
                    }
                }

                // Execute a possible higher-order onRowClick
                if (onRowClick) {
                    onRowClick(event, index);
                }
            };

            _this.handleRowKeyDown = function (event, index) {
                var key = event.key,
                    target = event.target;


                switch (key) {
                    case 'j':
                        if (target && target.nextSibling) {
                            target.nextSibling.focus();
                        }
                        break;

                    case 'k':
                        if (target && target.previousSibling) {
                            target.previousSibling.focus();
                        }
                        break;

                    case ' ':
                    case 'x':
                        event.preventDefault();
                        _this.selectToggle(index);
                        break;

                    default:
                    // no default
                }
            };

            _this.rowPropsGetter = function (index) {
                var _this$props5 = _this.props,
                    rowPropsGetter = _this$props5.rowPropsGetter,
                    selectedRows = _this$props5.selectedRows;

                var isSelected = selectedRows.has(index);

                // Get props passed in from another passed-in rowPropsGetter
                var higherOrderProps = rowPropsGetter ? rowPropsGetter(index) : {};
                var higherOrderClassName = higherOrderProps.className;

                return _extends({
                    'aria-checked': isSelected,
                    role: 'checkbox',
                    tabIndex: 0,
                    onKeyDown: function onKeyDown(event) {
                        return _this.handleRowKeyDown(event, index);
                    }
                }, higherOrderProps, {
                    className: classNames(higherOrderClassName, {
                        'is-selected': isSelected
                    })
                });
            };

            _this.anchorIndex = null;
            _this.previousRowIndex = null;
            return _this;
        }

        /**
         * Handle toggling the selection of the row at rowIndex
         * @param {number} rowIndex - table row index to select
         */


        /**
         * Handle selecting multiple rows with shift logic.
         * @param {number} rowIndex - table row index to select
         */


        /**
         * Handle selecting one row. This will blow away the existing selection!
         * @param {number} rowIndex - table row index to select
         */


        /**
         * Event handler for clicking on a row. Figures out which type of select click was used and
         * calls the corresponding select function.
         * @param {SyntheticMouseEvent} event
         * @param {Number} index
         * @return {void}
         */


        /**
         * Event handler for pressing a key on the currently focused row. It will change focus with
         * vim keybindings, and select with spacebar or x.
         * @param {SyntheticKeyboardEvent} event
         * @param {Number} index
         * @return {void}
         */


        _createClass(SelectableTable, [{
            key: 'render',
            value: function render() {
                return React.createElement(BaseTable, _extends({}, this.props, {
                    rowPropsGetter: this.rowPropsGetter,
                    onRowClick: this.handleRowClick
                }));
            }
        }]);

        return SelectableTable;
    }(Component), _class.displayName = 'Selectable(' + originalDisplayName + ')', _class.propTypes = _extends({}, BaseTable.propTypes, { // eslint-disable-line react/forbid-foreign-prop-types
        data: PropTypes.array.isRequired,
        onRowClick: PropTypes.func,
        onSelect: PropTypes.func,
        rowPropsGetter: PropTypes.func,
        selectedRows: ImmutablePropTypes.set
    }), _class.defaultProps = {
        selectedRows: new Set()
    }, _temp;
}

export default makeSelectable;