var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

import * as React from 'react';
import { FormattedMessage, FormattedNumber } from 'react-intl';

import IconEye from '../../icons/general/IconEye';
import IconComment from '../../icons/general/IconComment';
import IconDownloadSolid from '../../icons/general/IconDownloadSolid';
import IconPencilSolid from '../../icons/general/IconPencilSolid';
import PlainButton from '../../components/plain-button/PlainButton';

import messages from './messages';

import './AccessStatsItem.scss';

var statsAttributesTable = {
    preview: {
        icon: IconEye,
        message: messages.accessStatsPreviews
    },
    view: {
        icon: IconEye,
        message: messages.accessStatsViews
    },
    download: {
        icon: IconDownloadSolid,
        message: messages.accessStatsDownloads
    },
    comment: {
        icon: IconComment,
        message: messages.accessStatsComments
    },
    edit: {
        icon: IconPencilSolid,
        message: messages.accessStatsEdits
    }
};
var ICON_COLOR = '#2a62b9';
var ITEM_CONTENT_CLASS_NAME = 'access-stats-item-content';

var AccessStatsItem = function AccessStatsItem(_ref) {
    var type = _ref.type,
        _ref$count = _ref.count,
        count = _ref$count === undefined ? 0 : _ref$count,
        _ref$hasCountOverflow = _ref.hasCountOverflowed,
        hasCountOverflowed = _ref$hasCountOverflow === undefined ? false : _ref$hasCountOverflow,
        openAccessStatsModal = _ref.openAccessStatsModal,
        statButtonProps = _ref.statButtonProps;

    var statAttributes = statsAttributesTable[type];
    var IconComponent = statAttributes.icon;
    var labelMessage = statAttributes.message;

    var itemContent = React.createElement(
        React.Fragment,
        null,
        React.createElement(IconComponent, { color: ICON_COLOR, width: 14 }),
        React.createElement(
            'span',
            { className: 'access-stats-label' },
            React.createElement(FormattedMessage, labelMessage)
        ),
        React.createElement(FormattedNumber, { value: count }),
        hasCountOverflowed && '+'
    );

    return React.createElement(
        'li',
        { className: 'access-stats-item' },
        openAccessStatsModal ? React.createElement(
            PlainButton,
            _extends({
                className: ITEM_CONTENT_CLASS_NAME,
                onClick: openAccessStatsModal
            }, statButtonProps),
            itemContent
        ) : React.createElement(
            'span',
            { className: ITEM_CONTENT_CLASS_NAME },
            itemContent
        )
    );
};

AccessStatsItem.propTypes = {
    count: PropTypes.number.isRequired,
    hasCountOverflowed: PropTypes.bool,
    openAccessStatsModal: PropTypes.func,
    statButtonProps: PropTypes.object.isRequired,
    type: function type() {
        return (typeof $Keys === 'function' ? PropTypes.instanceOf($Keys).isRequired : PropTypes.any.isRequired).apply(this, arguments);
    }
};
export default AccessStatsItem;
import PropTypes from 'prop-types';