var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import PropTypes from 'prop-types';
import React, { Component } from 'react';
import { FormattedMessage } from 'react-intl';

import LoadingIndicator from '../../../components/loading-indicator';
import { SelectorItemsPropType, UserPropType } from '../../../common/box-proptypes';

import ApprovalCommentForm from '../approval-comment-form';
import Comment from '../comment';
import ActivityFeedEmptyState from '../../../icons/states/ActivityFeedEmptyState';
import Task from '../task';
import Version, { CollapsedVersion, VersionError } from '../version';
import Keywords from '../keywords';

import messages from '../messages';

import './ActivityFeed.scss';

var EmptyState = function EmptyState(_ref) {
    var isLoading = _ref.isLoading,
        showCommentMessage = _ref.showCommentMessage;
    return React.createElement(
        'div',
        { className: 'box-ui-activity-feed-empty-state' },
        React.createElement(ActivityFeedEmptyState, null),
        isLoading ? React.createElement(LoadingIndicator, null) : React.createElement(
            'div',
            { className: 'empty-state-cta' },
            React.createElement(
                'b',
                null,
                React.createElement(FormattedMessage, messages.noActivity)
            ),
            showCommentMessage ? React.createElement(
                'aside',
                null,
                React.createElement(FormattedMessage, messages.noActivityCommentPrompt)
            ) : null
        )
    );
};

EmptyState.propTypes = {
    isLoading: PropTypes.bool,
    showCommentMessage: PropTypes.bool
};

var ActiveState = function ActiveState(_ref2) {
    var currentUser = _ref2.currentUser,
        items = _ref2.items,
        onCommentDelete = _ref2.onCommentDelete,
        onTaskDelete = _ref2.onTaskDelete,
        onTaskEdit = _ref2.onTaskEdit,
        onTaskAssignmentUpdate = _ref2.onTaskAssignmentUpdate,
        onVersionInfo = _ref2.onVersionInfo,
        translations = _ref2.translations,
        inputState = _ref2.inputState,
        handlers = _ref2.handlers;
    return React.createElement(
        'ul',
        { className: 'box-ui-activity-feed-active-state' },
        items.map(function (item) {
            switch (item.type) {
                case 'comment':
                    return React.createElement(
                        'li',
                        {
                            className: 'box-ui-activity-feed-comment',
                            key: item.type + item.id
                        },
                        React.createElement(Comment, _extends({
                            id: item.id,
                            currentUser: currentUser,
                            onDelete: onCommentDelete
                        }, item, {
                            translations: translations,
                            inputState: inputState,
                            handlers: handlers
                        }))
                    );
                case 'task':
                    return React.createElement(
                        'li',
                        {
                            className: 'box-ui-activity-feed-task',
                            key: item.type + item.id
                        },
                        React.createElement(Task, _extends({
                            currentUser: currentUser
                        }, item, {
                            onDelete: onTaskDelete,
                            onEdit: onTaskEdit,
                            onTaskAssignmentUpdate: onTaskAssignmentUpdate,
                            translations: translations,
                            inputState: inputState,
                            handlers: handlers
                        }))
                    );
                case 'file_version':
                    return React.createElement(
                        'li',
                        {
                            className: 'box-ui-version-item',
                            key: item.type + item.id
                        },
                        item.versions ? React.createElement(CollapsedVersion, _extends({}, item, {
                            onInfo: onVersionInfo
                        })) : React.createElement(Version, _extends({}, item, { onInfo: onVersionInfo }))
                    );
                case 'file_version_error':
                    // we currently only display this if errorCode is tooManyVersions
                    if (item.errorCode !== 'tooManyVersions') {
                        return null;
                    }
                    return React.createElement(
                        'li',
                        {
                            className: 'box-ui-version-item',
                            key: item.type + item.errorCode
                        },
                        React.createElement(VersionError, item)
                    );
                case 'keywords':
                    return React.createElement(
                        'li',
                        {
                            className: 'box-ui-keywords-item',
                            key: item.type + item.id
                        },
                        React.createElement(Keywords, item)
                    );
                default:
                    return null;
            }
        })
    );
};

ActiveState.propTypes = {
    currentUser: UserPropType.isRequired,
    handlers: PropTypes.shape({
        comments: PropTypes.shape({
            create: PropTypes.func,
            delete: PropTypes.func
        }),
        tasks: PropTypes.shape({
            create: PropTypes.func,
            delete: PropTypes.func,
            onTaskAssignmentUpdate: PropTypes.func
        }),
        contacts: PropTypes.shape({
            getApproverWithQuery: PropTypes.func.isRequired,
            getMentionWithQuery: PropTypes.func.isRequired
        }),
        versions: PropTypes.shape({
            info: PropTypes.func
        })
    }),
    inputState: PropTypes.shape({
        approverSelectorContacts: SelectorItemsPropType,
        mentionSelectorContacts: SelectorItemsPropType,
        currentUser: UserPropType.isRequired,
        isDisabled: PropTypes.bool
    }),
    items: PropTypes.arrayOf(PropTypes.shape({
        type: PropTypes.oneOf(['comment', 'task', 'file_version', 'keywords']),
        createdAt: PropTypes.any,
        createdBy: UserPropType,
        id: PropTypes.string.isRequired
    })),
    onCommentDelete: PropTypes.func,
    onTaskAssignmentUpdate: PropTypes.func,
    onTaskDelete: PropTypes.func,
    onTaskEdit: PropTypes.func,
    onVersionInfo: PropTypes.func,
    translations: PropTypes.shape({
        translationEnabled: PropTypes.bool,
        onTranslate: PropTypes.func
    })
};

function collapseFeedState(feedState) {
    return feedState.reduce(function (collapsedFeedState, feedItem) {
        var previousFeedItem = collapsedFeedState.pop();

        if (!previousFeedItem) {
            return collapsedFeedState.concat([feedItem]);
        }

        if (feedItem.type === 'file_version' && previousFeedItem.type === 'file_version' && feedItem.action === 'upload' && previousFeedItem.action === 'upload') {
            var prevCreatedBy = previousFeedItem.createdBy,
                _previousFeedItem$ver = previousFeedItem.versions,
                versions = _previousFeedItem$ver === undefined ? [previousFeedItem] : _previousFeedItem$ver,
                _previousFeedItem$ver2 = previousFeedItem.versionStart,
                versionStart = _previousFeedItem$ver2 === undefined ? previousFeedItem.versionNumber : _previousFeedItem$ver2,
                _previousFeedItem$ver3 = previousFeedItem.versionEnd,
                versionEnd = _previousFeedItem$ver3 === undefined ? previousFeedItem.versionNumber : _previousFeedItem$ver3;
            var action = feedItem.action,
                createdBy = feedItem.createdBy,
                id = feedItem.id,
                versionNumber = feedItem.versionNumber;

            var collaborators = previousFeedItem.collaborators || _defineProperty({}, prevCreatedBy.id, _extends({}, prevCreatedBy));

            // add collaborators
            collaborators[createdBy.id] = _extends({}, createdBy);

            return collapsedFeedState.concat([{
                action: action,
                collaborators: collaborators,
                id: id,
                type: 'file_version',
                versions: versions.concat([feedItem]),
                versionStart: Math.min(versionStart, versionNumber),
                versionEnd: Math.max(versionEnd, versionNumber)
            }]);
        }

        return collapsedFeedState.concat([previousFeedItem, feedItem]);
    }, []);
}

function shouldShowEmptyState(feedState) {
    return feedState.length === 0 || feedState.length === 1 && feedState[0].type === 'file_version';
}

var ActivityFeed = function (_Component) {
    _inherits(ActivityFeed, _Component);

    function ActivityFeed(props) {
        _classCallCheck(this, ActivityFeed);

        var _this = _possibleConstructorReturn(this, (ActivityFeed.__proto__ || Object.getPrototypeOf(ActivityFeed)).call(this, props));

        _this.onKeyDown = function (event) {
            var nativeEvent = event.nativeEvent;

            nativeEvent.stopImmediatePropagation();
        };

        _this.approvalCommentFormFocusHandler = function () {
            return _this.setState({ isInputOpen: true });
        };

        _this.approvalCommentFormCancelHandler = function () {
            return _this.setState({ isInputOpen: false });
        };

        _this.approvalCommentFormSubmitHandler = function () {
            return _this.setState({ isInputOpen: false });
        };

        _this.createCommentHandler = function (args) {
            var handlers = _this.props.handlers;

            handlers.comments.create(args);
            _this.approvalCommentFormSubmitHandler();
        };

        _this.createTaskHandler = function (args) {
            var handlers = _this.props.handlers;

            handlers.tasks.create(args);
            _this.approvalCommentFormSubmitHandler();
        };

        _this.state = {
            isInputOpen: false
        };
        return _this;
    }

    _createClass(ActivityFeed, [{
        key: 'render',
        value: function render() {
            var _this2 = this;

            var _props = this.props,
                feedState = _props.feedState,
                handlers = _props.handlers,
                inputState = _props.inputState,
                isLoading = _props.isLoading,
                translations = _props.translations;
            var isInputOpen = this.state.isInputOpen;
            var approverSelectorContacts = inputState.approverSelectorContacts,
                mentionSelectorContacts = inputState.mentionSelectorContacts,
                currentUser = inputState.currentUser;

            var showApprovalCommentForm = !!(handlers && handlers.comments && handlers.comments.create);
            var onTaskAssignmentUpdate = handlers && handlers.tasks && handlers.tasks.onTaskAssignmentUpdate;
            var commentDeleteHandler = handlers && handlers.comments && handlers.comments.delete;
            var taskDeleteHandler = handlers && handlers.tasks && handlers.tasks.delete;
            var taskEditHandler = handlers && handlers.tasks && handlers.tasks.edit;
            var versionInfoHandler = handlers && handlers.versions && handlers.versions.info;

            return React.createElement(
                'div',
                { className: 'box-ui-activity-feed', onKeyDown: this.onKeyDown },
                React.createElement(
                    'div',
                    {
                        ref: function ref(_ref4) {
                            _this2.feedContainer = _ref4;
                        },
                        className: 'box-ui-activity-feed-items-container'
                    },
                    shouldShowEmptyState(feedState) ? React.createElement(EmptyState, {
                        isLoading: isLoading,
                        showCommentMessage: showApprovalCommentForm
                    }) : React.createElement(ActiveState, {
                        handlers: handlers,
                        items: collapseFeedState(feedState),
                        currentUser: currentUser,
                        onTaskAssignmentUpdate: onTaskAssignmentUpdate,
                        onCommentDelete: commentDeleteHandler,
                        onTaskDelete: taskDeleteHandler,
                        onTaskEdit: taskEditHandler,
                        onVersionInfo: versionInfoHandler,
                        translations: translations,
                        inputState: inputState
                    })
                ),
                showApprovalCommentForm ? React.createElement(ApprovalCommentForm, {
                    onSubmit: function onSubmit() {
                        _this2.feedContainer.scrollTop = 0;
                    },
                    isDisabled: inputState.isDisabled,
                    approverSelectorContacts: approverSelectorContacts,
                    mentionSelectorContacts: mentionSelectorContacts,
                    className: 'box-ui-activity-feed-comment-input ' + (inputState.isDisabled ? 'is-disabled' : ''),
                    createComment: this.createCommentHandler,
                    createTask: handlers && handlers.tasks ? this.createTaskHandler : null,
                    getApproverContactsWithQuery: handlers && handlers.contacts ? handlers.contacts.getApproverWithQuery : null,
                    getMentionContactsWithQuery: handlers && handlers.contacts ? handlers.contacts.getMentionWithQuery : null,
                    isOpen: isInputOpen,
                    user: currentUser,
                    onCancel: this.approvalCommentFormCancelHandler,
                    onFocus: this.approvalCommentFormFocusHandler
                }) : null
            );
        }
    }]);

    return ActivityFeed;
}(Component);

ActivityFeed.propTypes = {
    isLoading: PropTypes.bool,
    feedState: PropTypes.arrayOf(PropTypes.shape({
        type: PropTypes.oneOf(['comment', 'task', 'file_version', 'keywords']),
        createdAt: PropTypes.any,
        createdBy: UserPropType,
        id: PropTypes.string.isRequired
    })),
    inputState: PropTypes.shape({
        approverSelectorContacts: SelectorItemsPropType,
        mentionSelectorContacts: SelectorItemsPropType,
        currentUser: UserPropType.isRequired,
        isDisabled: PropTypes.bool
    }),
    handlers: PropTypes.shape({
        comments: PropTypes.shape({
            create: PropTypes.func,
            delete: PropTypes.func
        }),
        tasks: PropTypes.shape({
            create: PropTypes.func,
            delete: PropTypes.func,
            edit: PropTypes.func,
            onTaskAssignmentUpdate: PropTypes.func
        }),
        contacts: PropTypes.shape({
            getApproverWithQuery: PropTypes.func.isRequired,
            getMentionWithQuery: PropTypes.func.isRequired
        }),
        versions: PropTypes.shape({
            info: PropTypes.func
        })
    }),
    translations: PropTypes.shape({
        translationEnabled: PropTypes.bool,
        onTranslate: PropTypes.func
    })
};
ActivityFeed.defaultProps = {
    isLoading: false,
    feedState: []
};


export default ActivityFeed;