var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import PropTypes from 'prop-types';
import React, { Component } from 'react';
import cx from 'classnames';
import { EditorState } from 'draft-js';
import { FormattedMessage, injectIntl, intlShape } from 'react-intl';

import Avatar from '../../../components/avatar';
import Button from '../../../components/button';
import Checkbox from '../../../components/checkbox';
import ContactDatalistItem from '../../../components/contact-datalist-item';
import DatePicker from '../../../components/date-picker';
import PrimaryButton from '../../../components/primary-button';

import Form from '../../../components/form-elements/form';
import DraftJSMentionSelector, { DraftMentionDecorator } from '../../../components/form-elements/draft-js-mention-selector';
import PillSelectorDropdown from '../../../components/pill-selector-dropdown';

import { OptionsPropType, SelectorItemsPropType, UserPropType } from '../../../common/box-proptypes';
import commonMessages from '../../../common/messages';
import parseEmails from '../../../utils/parseEmails';

import messages from '../messages';

import './ApprovalCommentForm.scss';

var CommentInputControls = function CommentInputControls(_ref) {
    var onCancel = _ref.onCancel;
    return React.createElement(
        'div',
        { className: 'comment-input-controls' },
        React.createElement(
            Button,
            {
                className: 'comment-input-cancel-btn',
                onClick: onCancel,
                type: 'button'
            },
            React.createElement(FormattedMessage, messages.commentCancel)
        ),
        React.createElement(
            PrimaryButton,
            { className: 'comment-input-submit-btn' },
            React.createElement(FormattedMessage, messages.commentPost)
        )
    );
};

CommentInputControls.propTypes = {
    onCancel: PropTypes.func
};

var AddApprovalFields = function AddApprovalFields(_ref2) {
    var approvalDate = _ref2.approvalDate,
        approvers = _ref2.approvers,
        _ref2$approverSelecto = _ref2.approverSelectorContacts,
        approverSelectorContacts = _ref2$approverSelecto === undefined ? [] : _ref2$approverSelecto,
        approverSelectorError = _ref2.approverSelectorError,
        formatMessage = _ref2.formatMessage,
        onApprovalDateChange = _ref2.onApprovalDateChange,
        onApproverSelectorInput = _ref2.onApproverSelectorInput,
        onApproverSelectorRemove = _ref2.onApproverSelectorRemove,
        onApproverSelectorSelect = _ref2.onApproverSelectorSelect;

    var approverOptions = approverSelectorContacts
    // filter selected approvers
    .filter(function (_ref3) {
        var id = _ref3.id;
        return !approvers.find(function (_ref4) {
            var value = _ref4.value;
            return value === id;
        });
    })
    // map to datalist item format
    .map(function (_ref5) {
        var id = _ref5.id,
            item = _ref5.item;
        return {
            email: item.email,
            text: item.name,
            value: id
        };
    });

    return React.createElement(
        'div',
        { className: 'comment-add-approver-fields-container' },
        React.createElement(
            PillSelectorDropdown,
            {
                error: approverSelectorError,
                label: React.createElement(FormattedMessage, messages.approvalAssignees),
                onInput: onApproverSelectorInput,
                onRemove: onApproverSelectorRemove,
                onSelect: onApproverSelectorSelect,
                parseItems: parseEmails,
                placeholder: formatMessage(messages.approvalAddAssignee),
                selectedOptions: approvers,
                selectorOptions: approverOptions
            },
            approverOptions.map(function (_ref6) {
                var email = _ref6.email,
                    text = _ref6.text,
                    value = _ref6.value;
                return React.createElement(ContactDatalistItem, {
                    key: value,
                    name: text,
                    subtitle: email
                });
            })
        ),
        React.createElement(DatePicker, {
            className: 'comment-add-approver-date-input',
            label: React.createElement(FormattedMessage, messages.approvalDueDate),
            minDate: new Date(),
            name: 'approverDateInput',
            placeholder: formatMessage(messages.approvalSelectDate),
            onChange: onApprovalDateChange,
            value: approvalDate
        })
    );
};

AddApprovalFields.propTypes = {
    approvalDate: PropTypes.instanceOf(Date),
    approvers: OptionsPropType,
    approverSelectorContacts: SelectorItemsPropType,
    approverSelectorError: PropTypes.string,
    formatMessage: PropTypes.func.isRequired,
    onApprovalDateChange: PropTypes.func,
    onApproverSelectorInput: PropTypes.func.isRequired,
    onApproverSelectorRemove: PropTypes.func.isRequired,
    onApproverSelectorSelect: PropTypes.func.isRequired
};

var AddApproval = function AddApproval(_ref7) {
    var approvalDate = _ref7.approvalDate,
        approvers = _ref7.approvers,
        approverSelectorContacts = _ref7.approverSelectorContacts,
        approverSelectorError = _ref7.approverSelectorError,
        formatMessage = _ref7.formatMessage,
        isAddApprovalVisible = _ref7.isAddApprovalVisible,
        onApprovalDateChange = _ref7.onApprovalDateChange,
        onApproverSelectorInput = _ref7.onApproverSelectorInput,
        onApproverSelectorRemove = _ref7.onApproverSelectorRemove,
        onApproverSelectorSelect = _ref7.onApproverSelectorSelect;
    return React.createElement(
        'div',
        { className: 'comment-add-approver' },
        React.createElement(Checkbox, {
            className: 'box-ui-comment-add-approver-checkbox',
            label: formatMessage(messages.approvalAddTask),
            name: 'addApproval',
            isChecked: isAddApprovalVisible,
            tooltip: formatMessage(messages.approvalAddTaskTooltip)
        }),
        isAddApprovalVisible ? React.createElement(AddApprovalFields, {
            approvalDate: approvalDate,
            approvers: approvers,
            approverSelectorContacts: approverSelectorContacts,
            approverSelectorError: approverSelectorError,
            formatMessage: formatMessage,
            onApproverSelectorInput: onApproverSelectorInput,
            onApproverSelectorRemove: onApproverSelectorRemove,
            onApproverSelectorSelect: onApproverSelectorSelect,
            onApprovalDateChange: onApprovalDateChange
        }) : null
    );
};

AddApproval.propTypes = {
    approvalDate: PropTypes.instanceOf(Date),
    approvers: OptionsPropType,
    approverSelectorContacts: SelectorItemsPropType,
    approverSelectorError: PropTypes.string,
    formatMessage: PropTypes.func,
    isAddApprovalVisible: PropTypes.bool,
    onApprovalDateChange: PropTypes.func,
    onApproverSelectorInput: PropTypes.func,
    onApproverSelectorRemove: PropTypes.func,
    onApproverSelectorSelect: PropTypes.func
};

var ApprovalCommentForm = function (_Component) {
    _inherits(ApprovalCommentForm, _Component);

    function ApprovalCommentForm(props) {
        _classCallCheck(this, ApprovalCommentForm);

        var _this = _possibleConstructorReturn(this, (ApprovalCommentForm.__proto__ || Object.getPrototypeOf(ApprovalCommentForm)).call(this, props));

        _this.onFormChangeHandler = function (formData) {
            return _this.setState({ isAddApprovalVisible: formData.addApproval === 'on' });
        };

        _this.onFormValidSubmitHandler = function (formData) {
            var _this$props = _this.props,
                createComment = _this$props.createComment,
                createTask = _this$props.createTask,
                intl = _this$props.intl,
                updateTask = _this$props.updateTask,
                onSubmit = _this$props.onSubmit,
                entityId = _this$props.entityId;


            var commentText = _this.getFormattedCommentText();
            if (!commentText) {
                return;
            }

            if (formData.addApproval === 'on') {
                var approvers = _this.state.approvers;

                if (approvers.length === 0) {
                    _this.setState({
                        approverSelectorError: intl.formatMessage(commonMessages.requiredFieldError)
                    });
                    return;
                }
                createTask({
                    text: commentText,
                    approvers: approvers.map(function (_ref8) {
                        var value = _ref8.value;
                        return value;
                    }),
                    dueDate: formData.approverDateInput
                });
            } else if (entityId) {
                updateTask({ text: commentText, id: entityId });
            } else {
                createComment({ text: commentText });
            }

            if (onSubmit) {
                onSubmit();
            }

            _this.setState({
                commentEditorState: EditorState.createEmpty(DraftMentionDecorator),
                isAddApprovalVisible: false,
                approvalDate: null,
                approvers: []
            });
        };

        _this.onMentionSelectorChangeHandler = function (nextEditorState) {
            return _this.setState({ commentEditorState: nextEditorState });
        };

        _this.onApprovalDateChangeHandler = function (date) {
            return _this.setState({ approvalDate: date });
        };

        _this.getFormattedCommentText = function () {
            var commentEditorState = _this.state.commentEditorState;


            var contentState = commentEditorState.getCurrentContent();
            var blockMap = contentState.getBlockMap();

            var resultStringArr = [];

            // For all ContentBlocks in the ContentState:
            blockMap.forEach(function (block) {
                var text = block.getText();
                var blockMapStringArr = [];

                // Break down the ContentBlock into ranges
                block.findEntityRanges(function () {
                    return true;
                }, function (start, end) {
                    var entityKey = block.getEntityAt(start);
                    // If the range is an Entity, format its text eg "@[1:Username]"
                    // Otherwise append its text to the block result as-is
                    if (entityKey) {
                        var entity = contentState.getEntity(entityKey);
                        var stringToAdd = '@[' + entity.getData().id + ':' + text.substring(start + 1, end) + ']';
                        blockMapStringArr.push(stringToAdd);
                    } else {
                        blockMapStringArr.push(text.substring(start, end));
                    }
                });
                resultStringArr.push(blockMapStringArr.join(''));
            });

            // Concatentate the array of block strings with newlines
            // (Each block represents a paragraph)
            return resultStringArr.join('\n');
        };

        _this.handleApproverSelectorInput = function (value) {
            _this.props.getApproverContactsWithQuery(value);
            _this.setState({ approverSelectorError: '' });
        };

        _this.handleApproverSelectorSelect = function (pills) {
            _this.setState({ approvers: _this.state.approvers.concat(pills) });
        };

        _this.handleApproverSelectorRemove = function (option, index) {
            var approvers = _this.state.approvers.slice();
            approvers.splice(index, 1);
            _this.setState({ approvers: approvers });
        };

        _this.state = {
            approvalDate: null,
            approvers: [],
            approverSelectorError: '',
            commentEditorState: EditorState.createEmpty(DraftMentionDecorator),
            isAddApprovalVisible: false
        };
        return _this;
    }

    _createClass(ApprovalCommentForm, [{
        key: 'componentWillReceiveProps',
        value: function componentWillReceiveProps(nextProps) {
            var isOpen = nextProps.isOpen;


            if (isOpen !== this.props.isOpen && !isOpen) {
                this.setState({
                    commentEditorState: EditorState.createEmpty(DraftMentionDecorator),
                    isAddApprovalVisible: false
                });
            }
        }

        /**
         * Formats the comment editor's text such that it will be accepted by the server.
         *
         * @returns {string}
         */

    }, {
        key: 'render',
        value: function render() {
            var _props = this.props,
                approverSelectorContacts = _props.approverSelectorContacts,
                className = _props.className,
                createTask = _props.createTask,
                getMentionContactsWithQuery = _props.getMentionContactsWithQuery,
                formatMessage = _props.intl.formatMessage,
                isDisabled = _props.isDisabled,
                isOpen = _props.isOpen,
                _props$mentionSelecto = _props.mentionSelectorContacts,
                mentionSelectorContacts = _props$mentionSelecto === undefined ? [] : _props$mentionSelecto,
                onCancel = _props.onCancel,
                onFocus = _props.onFocus,
                user = _props.user,
                isEditing = _props.isEditing,
                taggedMessage = _props.taggedMessage;
            var _state = this.state,
                approvalDate = _state.approvalDate,
                approvers = _state.approvers,
                approverSelectorError = _state.approverSelectorError,
                commentEditorState = _state.commentEditorState,
                isAddApprovalVisible = _state.isAddApprovalVisible;
            var avatarUrl = user.avatarUrl,
                id = user.id,
                name = user.name;

            var classNames = cx('comment-input-container', className, {
                'comment-input-is-open': isOpen
            });

            return React.createElement(
                'div',
                { className: classNames },
                !isEditing && React.createElement(
                    'div',
                    { className: 'avatar-container' },
                    React.createElement(Avatar, { id: id, avatarUrl: avatarUrl, name: name })
                ),
                React.createElement(
                    'div',
                    { className: 'comment-input-form-container' },
                    React.createElement(
                        Form,
                        {
                            onChange: this.onFormChangeHandler,
                            onValidSubmit: this.onFormValidSubmitHandler
                        },
                        React.createElement(DraftJSMentionSelector, {
                            className: 'comment-input',
                            contacts: isOpen ? mentionSelectorContacts : [],
                            editorState: commentEditorState,
                            hideLabel: true,
                            isDisabled: isDisabled,
                            isRequired: isOpen,
                            name: 'commentText',
                            label: 'Comment',
                            onChange: this.onMentionSelectorChangeHandler,
                            onFocus: onFocus,
                            onMention: getMentionContactsWithQuery,
                            placeholder: taggedMessage || formatMessage(messages.commentWrite),
                            validateOnBlur: false
                        }),
                        React.createElement(
                            'aside',
                            {
                                className: cx('at-mention-tip', {
                                    'accessibility-hidden': isOpen
                                })
                            },
                            React.createElement(FormattedMessage, messages.atMentionTip)
                        ),
                        createTask ? React.createElement(AddApproval, {
                            approvalDate: approvalDate,
                            approvers: approvers,
                            approverSelectorContacts: approverSelectorContacts,
                            approverSelectorError: approverSelectorError,
                            formatMessage: formatMessage,
                            isAddApprovalVisible: isAddApprovalVisible,
                            onApprovalDateChange: this.onApprovalDateChangeHandler,
                            onApproverSelectorInput: this.handleApproverSelectorInput,
                            onApproverSelectorRemove: this.handleApproverSelectorRemove,
                            onApproverSelectorSelect: this.handleApproverSelectorSelect
                        }) : null,
                        React.createElement(CommentInputControls, { onCancel: onCancel })
                    )
                )
            );
        }
    }]);

    return ApprovalCommentForm;
}(Component);

// For testing only


ApprovalCommentForm.propTypes = {
    approverSelectorContacts: SelectorItemsPropType,
    className: PropTypes.string,
    createComment: PropTypes.func,
    createTask: PropTypes.func,
    updateTask: PropTypes.func,
    getApproverContactsWithQuery: PropTypes.func,
    getMentionContactsWithQuery: PropTypes.func,
    intl: intlShape.isRequired,
    isDisabled: PropTypes.bool,
    isOpen: PropTypes.bool,
    mentionSelectorContacts: SelectorItemsPropType,
    onCancel: PropTypes.func,
    onFocus: PropTypes.func,
    onSubmit: PropTypes.func,
    user: UserPropType.isRequired,
    isEditing: PropTypes.bool,
    entityId: PropTypes.string,
    taggedMessage: PropTypes.string
};
ApprovalCommentForm.defaultProps = {
    isOpen: false
};
export { ApprovalCommentForm as ApprovalCommentFormBase };

export default injectIntl(ApprovalCommentForm);