var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import PropTypes from 'prop-types';
import React, { Component } from 'react';
import classNames from 'classnames';
import { FormattedMessage } from 'react-intl';

import Avatar from '../../../components/avatar';
import InlineError from '../../../components/inline-error';
import { Link } from '../../../components/link';
import PlainButton from '../../../components/plain-button';
import { ReadableTime } from '../../../components/time';
import Tooltip from '../../../components/tooltip';
import { ActionItemErrorPropType, UserPropType, SelectorItemsPropType } from '../../../common/box-proptypes';

import InlineDelete from './InlineDelete';
import InlineEdit from './InlineEdit';
import CommentText from './CommentText';
import ApprovalCommentForm from '../approval-comment-form';
import formatTaggedMessage from '../utils/formatTaggedMessage';
import messages from '../messages';

import './Comment.scss';

var oneHourInMs = 3600000; // 60 * 60 * 1000

var CommentInlineError = function CommentInlineError(_ref) {
    var action = _ref.action,
        message = _ref.message,
        title = _ref.title;
    return React.createElement(
        InlineError,
        { className: 'box-ui-comment-error', title: title },
        React.createElement(
            'div',
            null,
            message
        ),
        action ? React.createElement(
            PlainButton,
            {
                className: 'lnk box-ui-comment-error-action',
                onClick: action.onAction,
                type: 'button'
            },
            action.text
        ) : null
    );
};

CommentInlineError.propTypes = {
    action: PropTypes.shape({
        onAction: PropTypes.func,
        text: PropTypes.node
    }),
    message: PropTypes.node,
    title: PropTypes.node
};

var Comment = function (_Component) {
    _inherits(Comment, _Component);

    function Comment(props) {
        _classCallCheck(this, Comment);

        var _this = _possibleConstructorReturn(this, (Comment.__proto__ || Object.getPrototypeOf(Comment)).call(this, props));

        _this.onKeyDown = function (event) {
            var nativeEvent = event.nativeEvent;

            nativeEvent.stopImmediatePropagation();
        };

        _this.approvalCommentFormFocusHandler = function () {
            return _this.setState({ isInputOpen: true });
        };

        _this.approvalCommentFormCancelHandler = function () {
            return _this.setState({ isInputOpen: false, isEditing: false });
        };

        _this.approvalCommentFormSubmitHandler = function () {
            return _this.setState({ isInputOpen: false, isEditing: false });
        };

        _this.updateTaskHandler = function (args) {
            var onEdit = _this.props.onEdit;

            onEdit(args);
            _this.approvalCommentFormSubmitHandler();
        };

        _this.toEdit = function () {
            return _this.setState({ isEditing: true, isInputOpen: true });
        };

        _this.handleCommentFocus = function () {
            _this.setState({ isFocused: true });
        };

        _this.handleCommentBlur = function () {
            _this.setState({ isFocused: false });
        };

        _this.state = {
            isEditing: false,
            isFocused: false,
            isInputOpen: false
        };
        return _this;
    }

    _createClass(Comment, [{
        key: 'render',
        value: function render() {
            var _props = this.props,
                createdBy = _props.createdBy,
                createdAt = _props.createdAt,
                permissions = _props.permissions,
                id = _props.id,
                isPending = _props.isPending,
                error = _props.error,
                onDelete = _props.onDelete,
                onEdit = _props.onEdit,
                taggedMessage = _props.taggedMessage,
                translatedTaggedMessage = _props.translatedTaggedMessage,
                translations = _props.translations,
                handlers = _props.handlers,
                inputState = _props.inputState;
            var approverSelectorContacts = inputState.approverSelectorContacts,
                mentionSelectorContacts = inputState.mentionSelectorContacts,
                currentUser = inputState.currentUser;

            var toEdit = this.toEdit;
            var _state = this.state,
                isEditing = _state.isEditing,
                isFocused = _state.isFocused,
                isInputOpen = _state.isInputOpen;

            var createdAtTimestamp = new Date(createdAt).getTime();
            return React.createElement(
                'div',
                { className: 'box-ui-comment-container' },
                React.createElement(
                    'div',
                    {
                        className: classNames('box-ui-comment', {
                            'is-pending': isPending || error,
                            'is-focused': isFocused
                        }),
                        onBlur: this.handleCommentBlur,
                        onFocus: this.handleCommentFocus
                    },
                    React.createElement(Avatar, _extends({ className: 'box-ui-comment-avatar' }, createdBy)),
                    React.createElement(
                        'div',
                        { className: 'box-ui-comment-content' },
                        React.createElement(
                            'div',
                            { className: 'box-ui-comment-headline' },
                            React.createElement(
                                Link,
                                {
                                    className: 'box-ui-comment-user-name',
                                    href: '/profile/' + createdBy.id
                                },
                                createdBy.name
                            ),
                            React.createElement(
                                Tooltip,
                                {
                                    text: React.createElement(FormattedMessage, _extends({}, messages.commentPostedFullDateTime, {
                                        values: { time: createdAtTimestamp }
                                    }))
                                },
                                React.createElement(
                                    'small',
                                    { className: 'box-ui-comment-created-at' },
                                    React.createElement(ReadableTime, {
                                        timestamp: createdAtTimestamp,
                                        relativeThreshold: oneHourInMs
                                    })
                                )
                            ),
                            onEdit && permissions && permissions.task_edit ? React.createElement(InlineEdit, { id: id, toEdit: toEdit }) : null,
                            onDelete && permissions && (permissions.comment_delete || permissions.task_delete) ? React.createElement(InlineDelete, {
                                id: id,
                                message: permissions.task_delete || false ? React.createElement(FormattedMessage, messages.taskDeletePrompt) : React.createElement(FormattedMessage, messages.commentDeletePrompt),
                                onDelete: onDelete
                            }) : null
                        ),
                        isEditing ? React.createElement(ApprovalCommentForm, {
                            onSubmit: function onSubmit() {},
                            isDisabled: inputState.isDisabled,
                            approverSelectorContacts: approverSelectorContacts,
                            mentionSelectorContacts: mentionSelectorContacts,
                            className: 'box-ui-activity-feed-comment-input ' + (inputState.isDisabled ? 'is-disabled' : ''),
                            createComment: this.createCommentHandler,
                            updateTask: this.updateTaskHandler,
                            getApproverContactsWithQuery: handlers && handlers.contacts ? handlers.contacts.getApproverWithQuery : null,
                            getMentionContactsWithQuery: handlers && handlers.contacts ? handlers.contacts.getMentionWithQuery : null,
                            isOpen: isInputOpen,
                            user: currentUser,
                            onCancel: this.approvalCommentFormCancelHandler,
                            onFocus: this.approvalCommentFormFocusHandler,
                            isEditing: isEditing,
                            entityId: id,
                            taggedMessage: formatTaggedMessage(taggedMessage, id, true)
                        }) : null,
                        !isEditing ? React.createElement(CommentText, _extends({
                            id: id,
                            taggedMessage: taggedMessage,
                            translatedTaggedMessage: translatedTaggedMessage
                        }, translations, {
                            translationFailed: error ? true : null
                        })) : null
                    )
                ),
                error ? React.createElement(CommentInlineError, error) : null
            );
        }
    }]);

    return Comment;
}(Component);

Comment.displayName = 'Comment';
Comment.propTypes = {
    createdBy: UserPropType.isRequired,
    createdAt: PropTypes.any,
    permissions: PropTypes.shape({
        comment_delete: PropTypes.bool,
        comment_edit: PropTypes.bool
    }),
    id: PropTypes.string.isRequired,
    isPending: PropTypes.bool,
    error: ActionItemErrorPropType,
    onDelete: PropTypes.func,
    onEdit: PropTypes.func,
    taggedMessage: PropTypes.string.isRequired,
    translatedTaggedMessage: PropTypes.string,
    translations: PropTypes.shape({
        translationEnabled: PropTypes.bool,
        onTranslate: PropTypes.func
    }),
    handlers: PropTypes.shape({
        tasks: PropTypes.shape({
            update: PropTypes.func
        }),
        contacts: PropTypes.shape({
            getApproverWithQuery: PropTypes.func.isRequired,
            getMentionWithQuery: PropTypes.func.isRequired
        }),
        versions: PropTypes.shape({
            info: PropTypes.func
        })
    }),
    inputState: PropTypes.shape({
        approverSelectorContacts: SelectorItemsPropType,
        mentionSelectorContacts: SelectorItemsPropType,
        currentUser: UserPropType.isRequired,
        isDisabled: PropTypes.bool
    })
};


export default Comment;