var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import PropTypes from 'prop-types';
import React, { Component } from 'react';
import { FormattedDate, FormattedMessage } from 'react-intl';

import PlainButton from '../../../components/plain-button';
import Tooltip from '../../../components/tooltip';
import IconCheck from '../../../icons/general/IconCheck';
import IconClose from '../../../icons/general/IconClose';
import { ActionItemErrorPropType, SelectorItemsPropType, UserPropType } from '../../../common/box-proptypes';

import Comment from '../comment';
import messages from '../messages';

import './Task.scss';

var TASK_APPROVED = 'approved';
var TASK_REJECTED = 'rejected';
var TASK_COMPLETED = 'completed';
var TASK_INCOMPLETE = 'incomplete';

var CompletedAssignment = function CompletedAssignment(_ref) {
    var name = _ref.name;
    return React.createElement(
        'div',
        { className: 'box-ui-task-completed-assignment' },
        React.createElement(
            'div',
            { className: 'box-ui-task-assignment-name' },
            name
        ),
        React.createElement(
            'div',
            { className: 'box-ui-task-assignment-actions' },
            React.createElement(IconCheck, {
                className: 'box-ui-task-check-icon',
                height: 18,
                title: React.createElement(FormattedMessage, messages.completedAssignment),
                width: 18
            })
        )
    );
};

CompletedAssignment.propTypes = {
    name: PropTypes.string
};

var RejectedAssignment = function RejectedAssignment(_ref2) {
    var name = _ref2.name;
    return React.createElement(
        'div',
        { className: 'box-ui-task-rejected-assignment' },
        React.createElement(
            'div',
            { className: 'box-ui-task-assignment-name' },
            name
        ),
        React.createElement(
            'div',
            { className: 'box-ui-task-assignment-actions' },
            React.createElement(IconClose, {
                className: 'box-ui-task-x-icon',
                height: 18,
                title: React.createElement(FormattedMessage, messages.rejectedAssignment),
                width: 18
            })
        )
    );
};

RejectedAssignment.propTypes = {
    name: PropTypes.string
};

var PendingAssignment = function PendingAssignment(_ref3) {
    var name = _ref3.name,
        onTaskApproval = _ref3.onTaskApproval,
        onTaskReject = _ref3.onTaskReject,
        shouldShowActions = _ref3.shouldShowActions;
    return React.createElement(
        'div',
        { className: 'box-ui-task-pending-assignment' },
        React.createElement(
            'div',
            { className: 'box-ui-task-assignment-name' },
            name
        ),
        shouldShowActions ? React.createElement(
            'div',
            { className: 'box-ui-task-assignment-actions' },
            React.createElement(
                Tooltip,
                {
                    position: 'bottom-center',
                    text: React.createElement(FormattedMessage, messages.taskApprove)
                },
                React.createElement(
                    PlainButton,
                    {
                        className: 'box-ui-task-check-btn',
                        onClick: onTaskApproval
                    },
                    React.createElement(IconCheck, {
                        className: 'box-ui-task-check-icon',
                        height: 18,
                        width: 18
                    })
                )
            ),
            React.createElement(
                Tooltip,
                {
                    position: 'bottom-center',
                    text: React.createElement(FormattedMessage, messages.taskReject)
                },
                React.createElement(
                    PlainButton,
                    {
                        className: 'box-ui-task-x-btn',
                        onClick: onTaskReject
                    },
                    React.createElement(IconClose, {
                        className: 'box-ui-task-x-icon',
                        height: 18,
                        width: 18
                    })
                )
            )
        ) : null
    );
};

PendingAssignment.displayName = 'PendingAssignment';

PendingAssignment.propTypes = {
    name: PropTypes.string,
    onTaskApproval: PropTypes.func,
    onTaskReject: PropTypes.func,
    shouldShowActions: PropTypes.bool
};

// eslint-disable-next-line

var Task = function (_Component) {
    _inherits(Task, _Component);

    function Task() {
        _classCallCheck(this, Task);

        return _possibleConstructorReturn(this, (Task.__proto__ || Object.getPrototypeOf(Task)).apply(this, arguments));
    }

    _createClass(Task, [{
        key: 'render',
        value: function render() {
            var _props = this.props,
                assignees = _props.assignees,
                createdAt = _props.createdAt,
                createdBy = _props.createdBy,
                currentUser = _props.currentUser,
                dueDate = _props.dueDate,
                error = _props.error,
                handlers = _props.handlers,
                id = _props.id,
                inputState = _props.inputState,
                isPending = _props.isPending,
                onDelete = _props.onDelete,
                onEdit = _props.onEdit,
                onTaskAssignmentUpdate = _props.onTaskAssignmentUpdate,
                permissions = _props.permissions,
                taggedMessage = _props.taggedMessage,
                translatedTaggedMessage = _props.translatedTaggedMessage,
                translations = _props.translations;

            return React.createElement(
                'div',
                {
                    className: 'box-ui-task ' + (isPending || error ? 'is-pending' : '')
                },
                React.createElement(Comment, {
                    createdAt: createdAt,
                    createdBy: createdBy,
                    currentUser: currentUser,
                    error: error,
                    handlers: handlers,
                    id: id,
                    inputState: inputState,
                    isPending: isPending,
                    onDelete: onDelete,
                    onEdit: onEdit,
                    permissions: permissions,
                    taggedMessage: taggedMessage,
                    translatedTaggedMessage: translatedTaggedMessage,
                    translations: translations
                }),
                React.createElement(
                    'div',
                    { className: 'box-ui-task-approvers-container' },
                    React.createElement(
                        'div',
                        { className: 'box-ui-task-approvers-header' },
                        React.createElement(
                            'strong',
                            null,
                            React.createElement(FormattedMessage, messages.tasksForApproval)
                        ),
                        dueDate ? React.createElement(
                            'span',
                            { className: 'box-ui-task-due-date' },
                            React.createElement(FormattedMessage, messages.taskDueDate),
                            React.createElement(FormattedDate, {
                                value: dueDate,
                                day: 'numeric',
                                month: 'long',
                                year: 'numeric'
                            })
                        ) : null
                    ),
                    React.createElement(
                        'div',
                        { className: 'box-ui-task-assignees' },
                        assignees.map(function (_ref4) {
                            var taskAssignmentId = _ref4.id,
                                assigneeUser = _ref4.user,
                                status = _ref4.status;

                            switch (status) {
                                case TASK_INCOMPLETE:
                                    return React.createElement(PendingAssignment, _extends({}, assigneeUser, {
                                        key: assigneeUser.id,
                                        onTaskApproval: function onTaskApproval() {
                                            return onTaskAssignmentUpdate(id, taskAssignmentId, TASK_APPROVED);
                                        },
                                        onTaskReject: function onTaskReject() {
                                            return onTaskAssignmentUpdate(id, taskAssignmentId, TASK_REJECTED);
                                        },
                                        shouldShowActions: onTaskAssignmentUpdate && assigneeUser.id === currentUser.id
                                    }));
                                case TASK_COMPLETED:
                                case TASK_APPROVED:
                                    return React.createElement(CompletedAssignment, _extends({}, assigneeUser, {
                                        key: assigneeUser.id
                                    }));
                                case TASK_REJECTED:
                                    return React.createElement(RejectedAssignment, _extends({}, assigneeUser, {
                                        key: assigneeUser.id
                                    }));
                                default:
                                    return null;
                            }
                        })
                    )
                )
            );
        }
    }]);

    return Task;
}(Component);

Task.propTypes = {
    assignees: PropTypes.arrayOf(PropTypes.shape({
        id: PropTypes.number.isRequired,
        user: UserPropType.isRequired,
        status: PropTypes.string.isRequired
    })),
    createdAt: PropTypes.any,
    createdBy: UserPropType.isRequired,
    currentUser: UserPropType.isRequired,
    dueDate: PropTypes.any,
    error: ActionItemErrorPropType,
    handlers: PropTypes.shape({
        comments: PropTypes.shape({
            create: PropTypes.func,
            delete: PropTypes.func
        }),
        tasks: PropTypes.shape({
            create: PropTypes.func,
            delete: PropTypes.func,
            onTaskAssignmentUpdate: PropTypes.func
        }),
        contacts: PropTypes.shape({
            getApproverWithQuery: PropTypes.func.isRequired,
            getMentionWithQuery: PropTypes.func.isRequired
        }),
        versions: PropTypes.shape({
            info: PropTypes.func
        })
    }),
    id: PropTypes.string.isRequired,
    inputState: PropTypes.shape({
        approverSelectorContacts: SelectorItemsPropType,
        mentionSelectorContacts: SelectorItemsPropType,
        currentUser: UserPropType.isRequired,
        isDisabled: PropTypes.bool
    }),
    isPending: PropTypes.bool,
    onDelete: PropTypes.func,
    onEdit: PropTypes.func,
    onTaskAssignmentUpdate: PropTypes.func,
    permissions: PropTypes.shape({
        comment_delete: PropTypes.bool,
        comment_edit: PropTypes.bool
    }),
    translatedTaggedMessage: PropTypes.string,
    translations: PropTypes.shape({
        translationEnabled: PropTypes.bool,
        onTranslate: PropTypes.func
    }),
    taggedMessage: PropTypes.string.isRequired
};

export default Task;