var _slicedToArray = function () { function sliceIterator(arr, i) { var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"]) _i["return"](); } finally { if (_d) throw _e; } } return _arr; } return function (arr, i) { if (Array.isArray(arr)) { return arr; } else if (Symbol.iterator in Object(arr)) { return sliceIterator(arr, i); } else { throw new TypeError("Invalid attempt to destructure non-iterable instance"); } }; }();

import React from 'react';
import { Link } from '../../../components/link';
import Mention from '../comment/Mention';

/**
 * Formats a message a string and replaces the following:
 * - all occurrence of mention patterns with a Mention component
 * - all occurrence of urls with a Link component
 * Ex mention format: @[123:Hello World]
 * @param {String} taggedMessage The message string to format
 * @param {String} itemID The id of the tagged message
 * @param {Boolean} shouldReturnString The boolean value whether it should return string
 * @returns {Array|String}
 */
var formatTaggedMessage = function formatTaggedMessage(taggedMessage, itemID, shouldReturnString) {
    // this regex matches one of the following regular expressions:
    // mentions: ([@＠﹫]\[[0-9]+:[^\]]+])
    // urls: (?:\b)((?:(?:ht|f)tps?:\/\/)[\w\._\-]+(:\d+)?(\/[\w\-_\.~\+\/#\?&%=:\[\]@!$'\(\)\*;,]*)?)
    // NOTE: There are useless escapes in the regex below, should probably remove them when safe
    // eslint-disable-next-line no-useless-escape
    var splitRegex = /((?:[@＠﹫]\[[0-9]+:[^\]]+])|(?:\b(?:(?:ht|f)tps?:\/\/)[\w\._\-]+(?::\d+)?(?:\/[\w\-_\.~\+\/#\?&%=:\[\]@!$'\(\)\*;,]*)?))/gim;
    var contentItems = taggedMessage.split(splitRegex).map(function (text, contentIndex) {
        // attempt mention match
        var mentionMatch = text.match(/([@＠﹫])\[([0-9]+):([^\]]+)]/i);
        if (mentionMatch) {
            var _mentionMatch = _slicedToArray(mentionMatch, 4),
                trigger = _mentionMatch[1],
                id = _mentionMatch[2],
                name = _mentionMatch[3];

            if (shouldReturnString) {
                return '' + trigger + name;
            }
            return React.createElement(
                Mention,
                {
                    id: Number(id),
                    key: contentIndex + '-' + itemID
                },
                '' + trigger + name
            );
        }

        if (!shouldReturnString) {
            // attempt url match
            // NOTE: There are useless escapes in the regex below, should probably remove them when safe
            var urlMatch = text.match(
            // eslint-disable-next-line no-useless-escape
            /((?:(?:ht|f)tps?:\/\/)[\w\._\-]+(?::\d+)?(?:\/[\w\-_\.~\+\/#\?&%=:\[\]@!$'\(\)\*;,]*)?)/i);
            if (urlMatch) {
                var _urlMatch = _slicedToArray(urlMatch, 2),
                    url = _urlMatch[1];

                return React.createElement(
                    Link,
                    { key: contentIndex + '-' + itemID, href: url },
                    url
                );
            }
        }

        return text;
    });

    return shouldReturnString ? contentItems.join('') : contentItems;
};

export default formatTaggedMessage;