var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

import PropTypes from 'prop-types';
import React from 'react';
import { FormattedMessage, injectIntl, intlShape } from 'react-intl';

import PlainButton from '../../../components/plain-button';
import IconInfoInverted from '../../../icons/general/IconInfoInverted';
import { UserPropType } from '../../../common/box-proptypes';

import messages from '../messages';

import './Version.scss';

function getMessageForAction(action, collaborators, versionStart, versionEnd) {
    // We only support collapsing for multiple upload versions
    if (action !== 'upload') {
        return null;
    }
    var collaboratorIDs = Object.keys(collaborators);
    var numberOfCollaborators = collaboratorIDs.length;

    if (numberOfCollaborators === 1) {
        var collaborator = collaborators[collaboratorIDs[0]];
        return React.createElement(FormattedMessage, _extends({}, messages.versionUploadCollapsed, {
            values: {
                name: React.createElement(
                    'strong',
                    null,
                    collaborator.name
                ),
                versions: React.createElement(
                    'span',
                    { className: 'box-ui-version-range' },
                    versionStart,
                    ' - ',
                    versionEnd
                )
            }
        }));
    }

    return React.createElement(FormattedMessage, _extends({}, messages.versionMultipleUsersUploaded, {
        values: {
            numberOfCollaborators: numberOfCollaborators,
            versions: React.createElement(
                'span',
                { className: 'box-ui-version-range' },
                versionStart,
                ' - ',
                versionEnd
            )
        }
    }));
}

var CollapsedVersion = function CollapsedVersion(_ref) {
    var action = _ref.action,
        collaborators = _ref.collaborators,
        intl = _ref.intl,
        onInfo = _ref.onInfo,
        versions = _ref.versions,
        versionStart = _ref.versionStart,
        versionEnd = _ref.versionEnd;
    return React.createElement(
        'div',
        { className: 'box-ui-collapsed-version' },
        React.createElement(
            'span',
            { className: 'box-ui-version-message' },
            getMessageForAction(action, collaborators, versionStart, versionEnd)
        ),
        onInfo ? React.createElement(
            'span',
            { className: 'box-ui-version-actions' },
            React.createElement(
                PlainButton,
                {
                    'aria-label': intl.formatMessage(messages.getVersionInfo),
                    className: 'box-ui-version-info',
                    onClick: function onClick() {
                        onInfo({ versions: versions });
                    },
                    type: 'button'
                },
                React.createElement(IconInfoInverted, { height: 16, width: 16 })
            )
        ) : null
    );
};

CollapsedVersion.displayName = 'CollapsedVersion';

CollapsedVersion.propTypes = {
    action: PropTypes.oneOf(['upload']).isRequired,
    collaborators: PropTypes.objectOf(UserPropType).isRequired,
    intl: intlShape.isRequired,
    onInfo: PropTypes.func,
    versions: PropTypes.array,
    versionStart: PropTypes.number.isRequired,
    versionEnd: PropTypes.number.isRequired
};

export { CollapsedVersion as CollapsedVersionBase };
export default injectIntl(CollapsedVersion);