var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

import PropTypes from 'prop-types';
import React from 'react';
import { FormattedMessage, injectIntl, intlShape } from 'react-intl';

import PlainButton from '../../../components/plain-button';
import IconInfoInverted from '../../../icons/general/IconInfoInverted';
import { UserPropType } from '../../../common/box-proptypes';

import messages from '../messages';

import './Version.scss';

function getMessageForAction(name, action, versionNumber) {
    switch (action) {
        case 'upload':
            return React.createElement(FormattedMessage, _extends({}, messages.versionUploaded, {
                values: {
                    name: React.createElement(
                        'strong',
                        null,
                        name
                    ),
                    versionNumber: versionNumber
                }
            }));
        case 'delete':
            return React.createElement(FormattedMessage, _extends({}, messages.versionDeleted, {
                values: {
                    name: React.createElement(
                        'strong',
                        null,
                        name
                    ),
                    versionNumber: versionNumber
                }
            }));
        case 'restore':
            return React.createElement(FormattedMessage, _extends({}, messages.versionRestored, {
                values: {
                    name: React.createElement(
                        'strong',
                        null,
                        name
                    ),
                    versionNumber: versionNumber
                }
            }));
        default:
            return null;
    }
}

var Version = function Version(_ref) {
    var action = _ref.action,
        createdBy = _ref.createdBy,
        id = _ref.id,
        intl = _ref.intl,
        onInfo = _ref.onInfo,
        versionNumber = _ref.versionNumber;
    return React.createElement(
        'div',
        { className: 'box-ui-version' },
        React.createElement(
            'span',
            { className: 'box-ui-version-message' },
            getMessageForAction(createdBy.name, action, versionNumber)
        ),
        onInfo ? React.createElement(
            'span',
            { className: 'box-ui-version-actions' },
            React.createElement(
                PlainButton,
                {
                    'aria-label': intl.formatMessage(messages.getVersionInfo),
                    className: 'box-ui-version-info',
                    onClick: function onClick() {
                        onInfo({ id: id, versionNumber: versionNumber });
                    },
                    type: 'button'
                },
                React.createElement(IconInfoInverted, { height: 16, width: 16 })
            )
        ) : null
    );
};

Version.displayName = 'Version';

Version.propTypes = {
    action: PropTypes.oneOf(['delete', 'restore', 'upload']).isRequired,
    createdBy: UserPropType.isRequired,
    id: PropTypes.string.isRequired,
    intl: intlShape.isRequired,
    onInfo: PropTypes.func,
    versionNumber: PropTypes.number
};

export { Version as VersionBase };
export default injectIntl(Version);