var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import PropTypes from 'prop-types';
import React, { Component } from 'react';
import { injectIntl, intlShape } from 'react-intl';

import ContentExplorerSearch from './ContentExplorerSearch';
import ContentExplorerNewFolderButton from './ContentExplorerNewFolderButton';
import ContentExplorerBreadcrumbs from './ContentExplorerBreadcrumbs';

import { ContentExplorerModePropType, FoldersPathPropType } from '../prop-types';
import messages from '../messages';

var SEARCH_RESULTS_FOLDER_ID = 'search_results_id';

var isSearchResultsFolder = function isSearchResultsFolder(folder) {
    return folder && folder.id === SEARCH_RESULTS_FOLDER_ID;
};

var ContentExplorerHeaderActions = function (_Component) {
    _inherits(ContentExplorerHeaderActions, _Component);

    function ContentExplorerHeaderActions(props) {
        _classCallCheck(this, ContentExplorerHeaderActions);

        var _this = _possibleConstructorReturn(this, (ContentExplorerHeaderActions.__proto__ || Object.getPrototypeOf(ContentExplorerHeaderActions)).call(this, props));

        _this.handleBreadcrumbClick = function (folderPathIndex, event) {
            var _this$props = _this.props,
                foldersPath = _this$props.foldersPath,
                onEnterFolder = _this$props.onEnterFolder;

            var clickedFolder = foldersPath[folderPathIndex];

            if (event) {
                event.preventDefault();
            }

            // Do nothing if the right-most breadcrumb (current folder) is clicked
            if (folderPathIndex === foldersPath.length - 1) {
                return;
            }

            // Show the search results for the last submitted input when clicking the "Search Results" breadcrumb
            if (isSearchResultsFolder(clickedFolder)) {
                _this.submitSearch(_this.lastSubmittedSearchInput);
                return;
            }

            onEnterFolder(clickedFolder);
        };

        _this.handleBreadcrumbsUpButtonClick = function () {
            var foldersPath = _this.props.foldersPath;

            var newFolderIndex = foldersPath.length - 2;

            if (_this.isViewingSearchResults()) {
                _this.exitSearch();
            } else if (newFolderIndex >= 0) {
                _this.handleBreadcrumbClick(newFolderIndex);
            }
        };

        _this.handleSearchInput = function (input) {
            _this.setState({
                searchInput: input
            });
        };

        _this.handleClearSearchButtonClick = function () {
            _this.exitSearch();
        };

        _this.handleSubmitSearch = function () {
            var searchInput = _this.state.searchInput;


            _this.submitSearch(searchInput);
        };

        _this.state = {
            searchInput: ''
        };
        _this.foldersPathBeforeSearch = [];
        _this.lastSubmittedSearchInput = '';
        return _this;
    }

    _createClass(ContentExplorerHeaderActions, [{
        key: 'getCurrentFolder',
        value: function getCurrentFolder() {
            var foldersPath = this.props.foldersPath;

            return foldersPath[foldersPath.length - 1];
        }
    }, {
        key: 'isInSearchMode',
        value: function isInSearchMode() {
            var foldersPath = this.props.foldersPath;

            return foldersPath.some(isSearchResultsFolder);
        }
    }, {
        key: 'isViewingSearchResults',
        value: function isViewingSearchResults() {
            return isSearchResultsFolder(this.getCurrentFolder());
        }
    }, {
        key: 'exitSearch',
        value: function exitSearch() {
            var _props = this.props,
                onFoldersPathUpdated = _props.onFoldersPathUpdated,
                onExitSearch = _props.onExitSearch;

            // Clear the search input even if we aren't in search mode

            this.setState({ searchInput: '' });

            if (this.isInSearchMode()) {
                var foldersPathLength = this.foldersPathBeforeSearch.length;
                var folderBeforeSearch = foldersPathLength > 0 ? this.foldersPathBeforeSearch[foldersPathLength - 1] : {};
                onFoldersPathUpdated(this.foldersPathBeforeSearch);
                onExitSearch(folderBeforeSearch);
            }
        }
    }, {
        key: 'submitSearch',
        value: function submitSearch(searchInput) {
            var _props2 = this.props,
                foldersPath = _props2.foldersPath,
                intl = _props2.intl,
                onFoldersPathUpdated = _props2.onFoldersPathUpdated,
                onSearchSubmit = _props2.onSearchSubmit;


            if (searchInput) {
                // Only save folders path if we aren't already in search mode
                if (!this.isInSearchMode()) {
                    this.foldersPathBeforeSearch = foldersPath;
                }

                this.lastSubmittedSearchInput = searchInput;
                onFoldersPathUpdated([{
                    id: SEARCH_RESULTS_FOLDER_ID,
                    name: intl.formatMessage(messages.searchResults)
                }]);

                onSearchSubmit(searchInput);
            } else {
                this.exitSearch();
            }
        }
    }, {
        key: 'render',
        value: function render() {
            var _props3 = this.props,
                children = _props3.children,
                contentExplorerMode = _props3.contentExplorerMode,
                CustomInput = _props3.customInput,
                foldersPath = _props3.foldersPath,
                onCreateNewFolderButtonClick = _props3.onCreateNewFolderButtonClick,
                showCreateNewFolderButton = _props3.showCreateNewFolderButton,
                isCreateNewFolderAllowed = _props3.isCreateNewFolderAllowed,
                searchInputProps = _props3.searchInputProps;
            var searchInput = this.state.searchInput;

            var isInSearchMode = this.isInSearchMode();

            return React.createElement(
                'div',
                { className: 'content-explorer-header-actions' },
                React.createElement(
                    'div',
                    { className: 'content-explorer-search-new-folder-container' },
                    CustomInput ? React.createElement(CustomInput, null) : React.createElement(ContentExplorerSearch, {
                        inputValue: searchInput,
                        onClearButtonClick: this.handleClearSearchButtonClick,
                        onInput: this.handleSearchInput,
                        onSubmit: this.handleSubmitSearch,
                        searchInputProps: searchInputProps
                    }),
                    showCreateNewFolderButton && React.createElement(ContentExplorerNewFolderButton, {
                        contentExplorerMode: contentExplorerMode,
                        onClick: onCreateNewFolderButtonClick,
                        isDisabled: !isCreateNewFolderAllowed || isInSearchMode,
                        isCreateNewFolderAllowed: isCreateNewFolderAllowed
                    }),
                    children
                ),
                React.createElement(ContentExplorerBreadcrumbs, {
                    foldersPath: foldersPath,
                    isUpButtonDisabled: foldersPath.length <= 1 && !isInSearchMode,
                    onUpButtonClick: this.handleBreadcrumbsUpButtonClick,
                    onBreadcrumbClick: this.handleBreadcrumbClick
                })
            );
        }
    }]);

    return ContentExplorerHeaderActions;
}(Component);

ContentExplorerHeaderActions.propTypes = {
    children: PropTypes.node,
    contentExplorerMode: ContentExplorerModePropType.isRequired,
    customInput: PropTypes.func,
    foldersPath: FoldersPathPropType.isRequired,
    intl: intlShape.isRequired,
    onFoldersPathUpdated: PropTypes.func.isRequired,
    onEnterFolder: PropTypes.func.isRequired,
    onCreateNewFolderButtonClick: PropTypes.func,
    showCreateNewFolderButton: PropTypes.bool,
    isCreateNewFolderAllowed: PropTypes.bool,
    onSearchSubmit: PropTypes.func.isRequired,
    onExitSearch: PropTypes.func.isRequired,
    searchInputProps: PropTypes.object
};
ContentExplorerHeaderActions.defaultProps = {
    showCreateNewFolderButton: true,
    isCreateNewFolderAllowed: true,
    searchInputProps: {}
};


export { ContentExplorerHeaderActions as ContentExplorerHeaderActionsBase };
export default injectIntl(ContentExplorerHeaderActions);