var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import PropTypes from 'prop-types';
import React, { Component } from 'react';
import classNames from 'classnames';
import { FormattedMessage, injectIntl, intlShape } from 'react-intl';

import { Modal, ModalActions } from '../../../components/modal';
import TextInput from '../../../components/text-input';
import Button from '../../../components/button';
import PrimaryButton from '../../../components/primary-button';

import messages from '../messages';

import './NewFolderModal.scss';

var NewFolderModal = function (_Component) {
    _inherits(NewFolderModal, _Component);

    function NewFolderModal(props) {
        _classCallCheck(this, NewFolderModal);

        var _this = _possibleConstructorReturn(this, (NewFolderModal.__proto__ || Object.getPrototypeOf(NewFolderModal)).call(this, props));

        _this.handleCreateClick = function () {
            var onCreateFolderSubmit = _this.props.onCreateFolderSubmit;
            var folderNameInput = _this.state.folderNameInput;

            onCreateFolderSubmit(folderNameInput);
        };

        _this.handleFolderNameInput = function (event) {
            var onCreateFolderInput = _this.props.onCreateFolderInput;

            var input = event.target.value;
            _this.setState({
                folderNameInput: input
            });
            if (onCreateFolderInput) {
                onCreateFolderInput(input);
            }
        };

        _this.state = {
            folderNameInput: ''
        };
        return _this;
    }

    _createClass(NewFolderModal, [{
        key: 'render',
        value: function render() {
            var _props = this.props,
                className = _props.className,
                intl = _props.intl,
                isOpen = _props.isOpen,
                onRequestClose = _props.onRequestClose,
                parentFolderName = _props.parentFolderName,
                isCreatingFolder = _props.isCreatingFolder,
                createFolderError = _props.createFolderError;
            var folderNameInput = this.state.folderNameInput;


            var isCreateButtonDisabled = !folderNameInput.trim().length || !!createFolderError || !!isCreatingFolder;

            return React.createElement(
                Modal,
                {
                    className: classNames('new-folder-modal', className),
                    isOpen: isOpen,
                    onRequestClose: onRequestClose,
                    focusElementSelector: '.folder-name-input input',
                    title: React.createElement(FormattedMessage, _extends({}, messages.newFolderModalTitle, {
                        values: {
                            parentFolderName: parentFolderName
                        }
                    }))
                },
                React.createElement(TextInput, {
                    className: 'folder-name-input',
                    type: 'text',
                    onInput: this.handleFolderNameInput,
                    label: React.createElement(FormattedMessage, messages.newFolderModalFolderNameLabel),
                    placeholder: intl.formatMessage(messages.newFolderModalFolderNamePlaceholder),
                    error: createFolderError,
                    value: folderNameInput,
                    isRequired: true
                }),
                React.createElement(
                    ModalActions,
                    null,
                    React.createElement(
                        Button,
                        {
                            className: 'new-folder-modal-cancel-button',
                            type: 'button',
                            onClick: onRequestClose
                        },
                        React.createElement(FormattedMessage, messages.newFolderModalCancel)
                    ),
                    React.createElement(
                        PrimaryButton,
                        {
                            className: 'new-folder-modal-create-button',
                            type: 'button',
                            onClick: this.handleCreateClick,
                            isLoading: isCreatingFolder,
                            isDisabled: isCreateButtonDisabled
                        },
                        React.createElement(FormattedMessage, messages.newFolderModalCreate)
                    )
                )
            );
        }
    }]);

    return NewFolderModal;
}(Component);

NewFolderModal.propTypes = {
    /** Adds class name to modal. */
    className: PropTypes.string,
    intl: intlShape.isRequired,
    /** Opens the modal. */
    isOpen: PropTypes.bool,
    /** Called when the modal is requested to be closed. */
    onRequestClose: PropTypes.func.isRequired,
    /**
     * Called when the folder creation is submitted.
     *
     * @param {string} folderName
     */
    onCreateFolderSubmit: PropTypes.func.isRequired,
    /**
     * Called with the latest folder name input.
     *
     * @param {string} folderName
     */
    onCreateFolderInput: PropTypes.func,
    /** The name of the parent folder that the new folder will be created in. */
    parentFolderName: PropTypes.string,
    /** Folder is in the process of being created. */
    isCreatingFolder: PropTypes.bool,
    /** Message that will be shown when there was an error creating the folder. */
    createFolderError: PropTypes.string
};
NewFolderModal.defaultProps = {
    className: '',
    isOpen: false,
    parentFolderName: '',
    isCreatingFolder: false,
    createFolderError: null
};


export { NewFolderModal as NewFolderModalBase };
export default injectIntl(NewFolderModal);