var _slicedToArray = function () { function sliceIterator(arr, i) { var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"]) _i["return"](); } finally { if (_d) throw _e; } } return _arr; } return function (arr, i) { if (Array.isArray(arr)) { return arr; } else if (Symbol.iterator in Object(arr)) { return sliceIterator(arr, i); } else { throw new TypeError("Invalid attempt to destructure non-iterable instance"); } }; }();

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import PropTypes from 'prop-types';
import React, { Component } from 'react';

import Button from '../../../components/button';
import DatePicker from '../../../components/date-picker';
import Form from '../../../components/form-elements/form';
import { Modal, ModalActions } from '../../../components/modal';
import PrimaryButton from '../../../components/primary-button';
import Select from '../../../components/select';
import TextArea from '../../../components/form-elements/text-area';
import TextInput from '../../../components/form-elements/text-input';
import Toggle from '../../../components/toggle';

import SelectMulti from '../../../deprecated/select-multi';

import TargetingExpressionEditor from '../targeting-expression-editor';
import * as Constants from './constants';

import './CreateMessageForm.scss';

/**
 * Validate time string in format hh:mm:ss
 * @param {string} value
 * @returns {object|void}
 */
function timeValidationFn(value) {
    // regular expression to match required time format
    var regex = /^([01]?\d|2[0-3]):([0-5]?\d):([0-5]?\d)$/;
    if (!value || !value.match(regex)) {
        return {
            code: 'invalidTime',
            message: 'invalid time'
        };
    }
    // If validated, just return null
    return null;
}

// Toggle/checkboxs require an onChange or defaultChecked property if we pass a checked (isOn) prop
// To stop React from throwing prop type warnings, we are just stubbing onChange
var bubbleToForm = function bubbleToForm() {};

var CreateMessageForm = function (_Component) {
    _inherits(CreateMessageForm, _Component);

    function CreateMessageForm(props) {
        _classCallCheck(this, CreateMessageForm);

        var _this = _possibleConstructorReturn(this, (CreateMessageForm.__proto__ || Object.getPrototypeOf(CreateMessageForm)).call(this, props));

        _this.onActivateDateChange = function (date) {
            var newState = _this.state;
            newState.activateDate = date;
            _this.setState(newState);
        };

        _this.onDeactivateDateChange = function (date) {
            var newState = _this.state;
            newState.deactivateDate = date;
            _this.setState(newState);
        };

        _this.onExpressionChange = function (newTargetingExpression) {
            _this.setState({
                targetingExpression: newTargetingExpression
            });
        };

        _this.openModal = function (modalMessage) {
            _this.setState({
                isModalOpen: true,
                modalMessage: modalMessage
            });
        };

        _this.closeModal = function () {
            _this.setState({
                isModalOpen: false
            });
        };

        _this.secondsTohhmmss = function (totalSeconds) {
            var hours = Math.floor(totalSeconds / 3600);
            var remain = totalSeconds - hours * 3600;
            var minutes = Math.floor(remain / 60);
            remain -= minutes * 60;
            var hh = hours > 9 ? hours : '0' + hours;
            var mm = minutes > 9 ? minutes : '0' + minutes;
            var ss = remain > 9 ? remain : '0' + remain;
            return hh + ':' + mm + ':' + ss;
        };

        _this.hhmmssToSeconds = function (timeString) {
            if (timeString === '') {
                return 0;
            }

            var _timeString$split = timeString.split(':'),
                _timeString$split2 = _slicedToArray(_timeString$split, 3),
                hours = _timeString$split2[0],
                minutes = _timeString$split2[1],
                seconds = _timeString$split2[2];

            return Number(hours * 3600) + Number(minutes * 60) + Number(seconds);
        };

        _this.formatTimeField = function (dateInMilliSeconds, timeAsString) {
            if (!dateInMilliSeconds) {
                return null;
            }
            var timeInSeconds = _this.hhmmssToSeconds(timeAsString);
            // divide by 1000 to convert ms to s.
            return dateInMilliSeconds / 1000 + timeInSeconds;
        };

        _this.deleteRuleEditorFields = function (formData) {
            delete formData.expressionType;
            delete formData.useTextEditor;
            delete formData.name;
            delete formData.key;
            delete formData.value;
        };

        _this.previewHandler = function () {
            _this.props.onPreview(_this.state.previewData);
        };

        _this.handleModalSubmit = function () {
            _this.formSubmit(_this.state.formData);
            _this.setState({
                formData: null
            });
            _this.closeModal();
        };

        _this.validSubmitHandler = function (formData) {
            var confirmationMessage = '';
            var targetingExpressionObj = JSON.parse(_this.state.targetingExpression);

            // Display confirmation modal if targetingExpression is set to be sent
            // to all users when the object is empty
            if (Object.keys(targetingExpressionObj).length === 0) {
                confirmationMessage = 'WARNING - this message has no targeting rules and will go out to every Box user. Please confirm that you want to create this message and that you intend to send to every user.';
            } else if (!_this.props.isUpdatingExistingMessage) {
                // display confirmation message if creating a new message
                confirmationMessage = 'Please confirm to create the message.';
            }

            if (confirmationMessage.length > 0) {
                _this.openModal(confirmationMessage);
                _this.setState({
                    formData: formData
                });
            } else {
                _this.formSubmit(formData);
            }
        };

        _this.formSubmit = function (formData) {
            // rule editor should only expose expression field, remove all the other fields.
            _this.deleteRuleEditorFields(formData);

            // format form data and submit
            formData.activateDate = _this.formatTimeField(formData.activateDate, formData.activateTime);
            delete formData.activateTime;

            formData.deactivateDate = _this.formatTimeField(formData.deactivateDate, formData.deactivateTime);
            delete formData.deactivateTime;

            formData.duration = formData.duration === '' ? '' : Number(formData.duration) * Constants.SECONDS_IN_DAY;
            formData.shouldAutoShow = formData.shouldAutoShow === 'on';
            formData.exemptFromSuppression = formData.exemptFromSuppression === 'on';
            formData.canBeShownMultipleTimes = formData.canBeShownMultipleTimes === 'on';
            formData.useTemplate = formData.useTemplate === 'on';
            formData.shouldBeLocalized = formData.shouldBeLocalized === 'on';

            var contexts = [];
            // @TODO: This needs to be rewritten to not use for-in
            // eslint-disable-next-line no-restricted-syntax
            for (var context in formData.messageContexts) {
                if (formData.messageContexts[context] === 'on') {
                    contexts.push(context);
                }
            }
            formData.messageContexts = contexts.join(',');
            _this.props.onSubmit(formData);
        };

        _this.invalidSubmitHandler = function () {
            // TODO(haiwang): add logic to handle in valid form submition if needed.
        };

        _this.formOnChangeHandler = function (formData) {
            var onTypeChange = _this.props.onTypeChange;
            var newMessageType = formData.messageType,
                newUseTemplate = formData.useTemplate;
            // Call onTypeChange whenever 'type' field or 'use template' toggle changed.

            if (onTypeChange && (newMessageType !== _this.state.previewData.type || newUseTemplate !== _this.state.useTemplate)) {
                onTypeChange(newMessageType, newUseTemplate === 'on');

                // shouldAutoShow should always turn on automatically when selecting modal or banner
                if (newMessageType === 'modal' || newMessageType === 'banner') {
                    formData.shouldAutoShow = 'on';
                }
            }

            var newFetchRunmode = newUseTemplate ? '' : formData.fetchRunmode;
            if (typeof newFetchRunmode !== 'string') {
                // When swtiching 'use tamplate' toggle from 'on' to 'off' formData.fetchRunmode will be undefined, should default to the prop.
                newFetchRunmode = _this.props.fetchRunmode;
            }

            var newState = {
                useTemplate: formData.useTemplate,
                useTextEditor: formData.useTextEditor,
                shouldAutoShow: formData.shouldAutoShow,
                targetingExpression: formData.targetingExpression,
                exemptFromSuppression: formData.exemptFromSuppression,
                canBeShownMultipleTimes: formData.canBeShownMultipleTimes,
                shouldBeLocalized: formData.shouldBeLocalized,
                previewData: {
                    type: newMessageType,
                    name: formData.messageName,
                    fetchRunmode: newFetchRunmode
                },
                isModalOpen: false,
                formData: null
            };
            _this.setState(newState);
        };

        _this.state = {
            useTemplate: props.useTemplate ? 'on' : '',
            shouldAutoShow: props.shouldAutoShow ? 'on' : '',
            exemptFromSuppression: props.exemptFromSuppression ? 'on' : '',
            canBeShownMultipleTimes: props.canBeShownMultipleTimes ? 'on' : '',
            shouldBeLocalized: props.shouldBeLocalized ? 'on' : '',
            activateDate: Number.isInteger(props.activateDate) ? new Date(props.activateDate * 1000) : null,
            deactivateDate: Number.isInteger(props.deactivateDate) ? new Date(props.deactivateDate * 1000) : null,
            targetingExpression: props.targetingExpression,
            previewData: {
                type: props.messageType,
                name: props.messageName,
                fetchRunmode: props.fetchRunmode
            },
            isModalOpen: false,
            modalMessage: '',
            formData: null
        };
        return _this;
    }

    /**
     * Ativate date change handler
     * @param {int} date
     * @returns {void}
     */


    /**
     * Deactivate date change handler
     * @param {int} date
     * @returns {void}
     */


    /**
     * Update expression when it is modified in editor.
     * @param {string} newTargetingExpression
     * @returns {void}
     */


    /**
     * Opens new message confirmation modal
     * @param {string} modalMessage
     * @returns {void}
     */


    /**
     * Closes new message confirmation modal
     * @returns {void}
     */


    /**
     * Format time string from seconds to hh:mm:ss string.
     * @param {int} totalSeconds
     * @returns {string}
     */


    /**
     * Format time string from hh:mm:ss into seconds.
     * @param {string} timeString
     * @returns {int}
     */


    /**
     * NOTE: Duration field is temporarily disabled.
     * Format duration from seconds into days.
     * @param {number} durationInSeconds
     * @returns {int}
     */
    //  durationToDays = (durationInSeconds) => {
    //      return Math.floor(durationInSeconds / Constants.SECONDS_IN_DAY);
    //  };

    /**
     * Add date and day time timestamp together to get the time field for submit.
     * @param {int} dateInMilliSeconds
     * @param {string} timeAsString
     * @returns {int|null}
     */


    /**
     * Remove fields submitted from TargetingExpressionEditor component.
     * @param {object} formData
     * @returns {void}
     */


    /**
     * Modal action button handler
     * @returns {void}
     */


    /**
     * form valid submit handler
     * @param {object} formData
     * @returns {void}
     */


    _createClass(CreateMessageForm, [{
        key: 'render',
        value: function render() {
            var _props = this.props,
                ruleValueFormatMap = _props.ruleValueFormatMap,
                contextChoices = _props.contextChoices,
                messageName = _props.messageName,
                description = _props.description,
                messageType = _props.messageType,
                messageContexts = _props.messageContexts,
                priority = _props.priority,
                activateTime = _props.activateTime,
                deactivateTime = _props.deactivateTime,
                isUpdatingExistingMessage = _props.isUpdatingExistingMessage;

            // preselected contexts

            if (messageContexts) {
                var contexts = messageContexts.split(',');
                // mark seleteted on all choices appear in contexts array.
                contextChoices.forEach(function (contextChoice) {
                    if (contexts.indexOf(contextChoice.value) > -1) {
                        contextChoice.isSelected = true;
                    }
                });
            }

            return React.createElement(
                'div',
                { className: 'create-message-form' },
                React.createElement(
                    Modal,
                    {
                        title: 'In App Message Confirmation',
                        isOpen: this.state.isModalOpen,
                        onRequestClose: this.closeModal
                    },
                    React.createElement(
                        'p',
                        null,
                        this.state.modalMessage
                    ),
                    React.createElement(
                        ModalActions,
                        null,
                        React.createElement(
                            Button,
                            { onClick: this.closeModal },
                            'Close'
                        ),
                        React.createElement(
                            PrimaryButton,
                            { onClick: this.handleModalSubmit },
                            'Yes'
                        )
                    )
                ),
                React.createElement(
                    Form,
                    {
                        onChange: this.formOnChangeHandler,
                        onValidSubmit: this.validSubmitHandler,
                        onInvalidSubmit: this.invalidSubmitHandler
                    },
                    React.createElement(
                        Button,
                        { type: 'submit' },
                        'Save'
                    ),
                    React.createElement(
                        Button,
                        {
                            type: 'button',
                            className: 'preview_btn',
                            onClick: this.previewHandler
                        },
                        'Preview'
                    ),
                    React.createElement(
                        'div',
                        null,
                        React.createElement(TextInput, {
                            name: 'messageName',
                            className: isUpdatingExistingMessage ? 'readonly-input' : '',
                            label: 'Message Name (must be lowercase)',
                            placeholder: 'lowercase_message_name',
                            type: 'text',
                            value: messageName,
                            isReadOnly: isUpdatingExistingMessage,
                            isRequired: true
                        })
                    ),
                    React.createElement(
                        'div',
                        null,
                        React.createElement(TextArea, {
                            name: 'description',
                            label: 'Message Description / Purpose',
                            placeholder: 'What this message is about?',
                            value: description,
                            isRequired: true
                        })
                    ),
                    isUpdatingExistingMessage ? React.createElement(TextInput, {
                        name: 'messageType',
                        className: 'readonly-input',
                        label: 'Message Type',
                        placeholder: 'message_type',
                        type: 'text',
                        value: messageType,
                        isReadOnly: true,
                        isRequired: true
                    }) : React.createElement(
                        Select,
                        {
                            name: 'messageType',
                            label: 'Message Type',
                            defaultValue: messageType
                        },
                        React.createElement(
                            'option',
                            { value: 'popout' },
                            'Popout'
                        ),
                        React.createElement(
                            'option',
                            { value: 'modal' },
                            'Modal'
                        ),
                        React.createElement(
                            'option',
                            { value: 'fullscreentour' },
                            'FS Tour'
                        ),
                        React.createElement(
                            'option',
                            { value: 'banner' },
                            'Banner'
                        ),
                        React.createElement(
                            'option',
                            { value: 'email' },
                            'Email'
                        ),
                        React.createElement(
                            'option',
                            { value: 'adhoc' },
                            'Ad Hoc'
                        )
                    ),
                    React.createElement(SelectMulti, {
                        name: 'messageContexts',
                        className: 'contexts-multi-select',
                        label: 'Message Contexts',
                        placeholder: 'Choose message contexts',
                        defaultItems: contextChoices
                    }),
                    React.createElement(
                        Select,
                        {
                            name: 'messagePriority',
                            label: 'Message Priority',
                            defaultValue: priority
                        },
                        React.createElement(
                            'option',
                            { value: 10 },
                            '1(low)'
                        ),
                        React.createElement(
                            'option',
                            { value: 20 },
                            '2'
                        ),
                        React.createElement(
                            'option',
                            { value: 30 },
                            '3'
                        ),
                        React.createElement(
                            'option',
                            { value: 40 },
                            '4'
                        ),
                        React.createElement(
                            'option',
                            { value: 50 },
                            '5(high)'
                        )
                    ),
                    React.createElement(
                        'div',
                        null,
                        React.createElement(
                            'div',
                            { className: 'create-message-inline-control' },
                            React.createElement(DatePicker, {
                                label: 'Activate Date',
                                placeholder: 'mm-dd-yyyy',
                                name: 'activateDate',
                                value: this.state.activateDate,
                                onChange: this.onActivateDateChange,
                                isRequired: true
                            })
                        ),
                        React.createElement(
                            'div',
                            { className: 'create-message-inline-control' },
                            React.createElement(TextInput, {
                                name: 'activateTime',
                                label: 'Activate Time',
                                placeholder: 'hh:mm:ss',
                                type: 'text',
                                value: Number.isInteger(activateTime) ? this.secondsTohhmmss(activateTime) : '',
                                validation: timeValidationFn
                            })
                        )
                    ),
                    React.createElement(
                        'div',
                        null,
                        React.createElement(
                            'div',
                            { className: 'create-message-inline-control' },
                            React.createElement(DatePicker, {
                                label: 'Deactivate Date',
                                placeholder: 'mm-dd-yyyy',
                                name: 'deactivateDate',
                                value: this.state.deactivateDate,
                                onChange: this.onDeactivateDateChange,
                                isRequired: true
                            })
                        ),
                        React.createElement(
                            'div',
                            { className: 'create-message-inline-control' },
                            React.createElement(TextInput, {
                                name: 'deactivateTime',
                                label: 'Deactivate Time',
                                placeholder: 'hh:mm:ss',
                                type: 'text',
                                value: Number.isInteger(deactivateTime) ? this.secondsTohhmmss(deactivateTime) : '',
                                validation: timeValidationFn
                            })
                        )
                    ),
                    React.createElement(
                        'div',
                        null,
                        React.createElement(Toggle, {
                            name: 'shouldAutoShow',
                            id: 'shouldAutoShow',
                            label: 'Should Auto Show',
                            isOn: this.state.shouldAutoShow === 'on',
                            onChange: bubbleToForm
                        }),
                        React.createElement(Toggle, {
                            name: 'exemptFromSuppression',
                            id: 'exemptFromSuppression',
                            label: 'Exempt From Suppression',
                            isOn: this.state.exemptFromSuppression === 'on',
                            onChange: bubbleToForm
                        }),
                        React.createElement(Toggle, {
                            name: 'canBeShownMultipleTimes',
                            id: 'canBeShownMultipleTimes',
                            label: 'Can Be Shown Again After Message Closed',
                            isOn: this.state.canBeShownMultipleTimes === 'on',
                            onChange: bubbleToForm
                        })
                    ),
                    React.createElement(
                        'div',
                        null,
                        React.createElement(TextInput, {
                            name: 'duration',
                            label: 'Duration',
                            placeholder: 'Temporarily Turned Off',
                            className: 'hidden',
                            type: 'number',
                            value: ''
                        })
                    ),
                    React.createElement(
                        'div',
                        null,
                        React.createElement(Toggle, {
                            name: 'useTextEditor',
                            id: 'useTextEditor',
                            label: 'Use Targeting Expression Text Editor',
                            isOn: this.state.useTextEditor === 'on',
                            onChange: bubbleToForm
                        }),
                        React.createElement(TargetingExpressionEditor, {
                            useTextEditor: this.state.useTextEditor === 'on',
                            targetingExpression: this.state.targetingExpression,
                            ruleValueFormatMap: ruleValueFormatMap,
                            onExpressionChange: this.onExpressionChange
                        })
                    ),
                    React.createElement(
                        'div',
                        null,
                        React.createElement(
                            'div',
                            null,
                            React.createElement(Toggle, {
                                name: 'useTemplate',
                                id: 'useTemplate',
                                label: 'Use Message Template',
                                isOn: this.state.useTemplate === 'on',
                                onChange: bubbleToForm
                            })
                        ),
                        this.state.useTemplate ? React.createElement(Toggle, {
                            name: 'shouldBeLocalized',
                            id: 'shouldBeLocalized',
                            label: 'Should Be Localized',
                            isOn: this.state.shouldBeLocalized === 'on',
                            onChange: bubbleToForm
                        }) : React.createElement(TextInput, {
                            name: 'fetchRunmode',
                            label: 'Fetch Runmode',
                            placeholder: 'rm_message',
                            type: 'text',
                            value: this.state.previewData.fetchRunmode
                        })
                    )
                )
            );
        }
    }]);

    return CreateMessageForm;
}(Component);

CreateMessageForm.propTypes = {
    onSubmit: PropTypes.func.isRequired,
    onPreview: PropTypes.func.isRequired,
    onTypeChange: PropTypes.func,
    ruleValueFormatMap: PropTypes.object.isRequired,
    contextChoices: PropTypes.arrayOf(PropTypes.shape({
        displayText: PropTypes.string,
        value: PropTypes.string
    })).isRequired,
    messageName: PropTypes.string,
    description: PropTypes.string,
    messageType: PropTypes.string,
    messageContexts: PropTypes.string,
    priority: PropTypes.number,
    activateDate: PropTypes.number,
    deactivateDate: PropTypes.number,
    activateTime: PropTypes.number,
    deactivateTime: PropTypes.number,
    shouldAutoShow: PropTypes.bool,
    exemptFromSuppression: PropTypes.bool,
    canBeShownMultipleTimes: PropTypes.bool,
    targetingExpression: PropTypes.string,
    shouldBeLocalized: PropTypes.bool,
    useTemplate: PropTypes.bool,
    fetchRunmode: PropTypes.string,
    isUpdatingExistingMessage: PropTypes.bool
};


export default CreateMessageForm;