### Description

A form in Internal Admin UI to collect info and create a new contextual message.

### Examples

```js
// Format of expression value
const FORMAT_NUMBER_VALUE = 'format_number_value';
const FORMAT_BOOL_VALUE = 'format_bool_value';
const FORMAT_STRING_VALUE = 'format_string_value';
const FORMAT_MIXED_VALUE = 'format_mixed_value'; // could be string , bool , number

// Used to look up individual rule's expected value format.
//  ex. rule 'isMaster' will expect a bool as its expected value.
const ruleValueFormatMap = {
    userId: { format: FORMAT_NUMBER_VALUE, optionUIstr: 'User Id' },
    enterpriseId: { format: FORMAT_NUMBER_VALUE, optionUIstr: 'Enterprise Id' },
    isMaster: { format: FORMAT_BOOL_VALUE, optionUIstr: 'Is Master', options: [ true, false ] },
    primaryLanguage: { format: FORMAT_STRING_VALUE, optionUIstr: 'Primary Language', options: [ 'zh', 'en', 'ja' ] },
    session: { format: FORMAT_MIXED_VALUE, optionUIstr: 'Session', context: { 'varName': FORMAT_STRING_VALUE } },
    daysSinceMessageLastInteraction: { format: FORMAT_NUMBER_VALUE, optionUIstr: 'Days Since Message Last Interaction', context: { messageName: FORMAT_STRING_VALUE, messageType: FORMAT_STRING_VALUE } },
    ruleXWithOptionsAndContext: { format: FORMAT_STRING_VALUE, optionUIstr: 'Rule X With Options & Context', options: [ 'football', 'basketball', 'volleyball' ], context: { context1: FORMAT_STRING_VALUE, context2: FORMAT_NUMBER_VALUE } },
};

function submitHandler(formData) {
    console.log('AJAX submit form data:');
    console.log(formData);
}

function previewHandler(previewData) {
    console.log('Display message preview with data:');
    console.log(previewData);
}

function onTypeChangeHandler(type, shouldUseTemplate) {
    console.log(`Message type: ${type}`);
    console.log(`Should use template: ${shouldUseTemplate}`);
}

const contextChoices = [
    { displayText: 'Account Settings Page', value: 'page_account_settings' },
    { displayText: 'All Files Page', value: 'page_all_files' },
    { displayText: 'Collaborators Page', value: 'page_collaborators' },
    { displayText: 'Favorites Page', value: 'page_favorites' },
    { displayText: 'Notifications Page', value: 'page_notifications' },
    { displayText: 'Profile Page', value: 'page_profile' },
    { displayText: 'Search Page', value: 'page_search' },
    { displayText: 'Synced Items Page', value: 'page_synced_items' },
    { displayText: 'Trash Page', value: 'page_trash' },
    { displayText: 'Updates Page', value: 'page_updates' },
    { displayText: 'Collab Sidebar Module', value: 'collab_sidebar' },
    { displayText: 'Preview Module', value: 'preview' },
    { displayText: 'Email Education', value: 'email_educational' },
    { displayText: 'Email Feature Anoucement', value: 'email_feature_announcement' },
    { displayText: 'AC Groups Page', value: 'page_ac_groups' },
    { displayText: 'AC Custom Branding Page', value: 'page_ac_custom_branding' },
];


const targetingExpression = JSON.stringify({
    'type': 'logic',
    'operation': 'AND',
    'expressions': [
        { 'type': 'equal', 'term': { 'name': 'userId', 'value': 2 } },
        {
            'type': 'logic',
            'operation': 'OR',
            'expressions': [
                {
                    'type': 'logic',
                    'operation': 'NOT',
                    'expressions': [ { 'type': 'among', 'term': { 'name': 'enterpriseId', 'value': [ 1, 2, 3, 4 ] } } ],
                },
                { 'type': 'among', 'term': { 'name': 'primaryLanguage', 'value': [ 'en', 'ja' ] } },
                { 'type': 'in_range', 'term': { 'name': 'daysSinceMessageLastInteraction', 'value': { 'lower': 3 } }, 'context': { 'messageName': 'message1', 'messageType': 'popout' } },
                { 'type': 'among', 'term': { 'name': 'ruleXWithOptionsAndContext', 'value': 'football,volleyball' }, 'context': { 'context1': 'xxx', 'context2': 222 } },
            ],
        },
    ],
});

<CreateMessageForm
    onSubmit={ submitHandler }
    onPreview={ previewHandler }
    onTypeChange={ onTypeChangeHandler }
    ruleValueFormatMap={ ruleValueFormatMap }
    contextChoices={ contextChoices }
    messageName='message_name'
    description='this test message is about blar'
    messageType='popout'
    messageContexts='page_account_settings,page_all_files,page_collaborators'
    priority={ 30 }
    activateDate={ new Date('05/10/2016') / 1000 } // 1462863600
    deactivateDate={ new Date('05/24/2016') / 1000 } // 1464073200
    activateTime={ 234 }
    deactivateTime={ 0 }
    shouldAutoShow
    targetingExpression={ targetingExpression }
    fetchRunmode='test_runmode'
    isUpdatingExistingMessage
/>
```
