### Description

A Editor UI in Internal Admin to edit targeting expression of a contextual message.

### Examples

```js
// Format of expression value
const FORMAT_NUMBER_VALUE = 'format_number_value';
const FORMAT_BOOL_VALUE = 'format_bool_value';
const FORMAT_STRING_VALUE = 'format_string_value';
const FORMAT_MIXED_VALUE = 'format_mixed_value'; // could be string , bool , number

// Used to look up individual rule's expected value format.
//  ex. rule 'isMaster' will expect a bool as its expected value.
const ruleValueFormatMap = {
    userId: { format: FORMAT_NUMBER_VALUE, optionUIstr: 'User Id' },
    enterpriseId: { format: FORMAT_NUMBER_VALUE, optionUIstr: 'Enterprise Id' },
    isMaster: { format: FORMAT_BOOL_VALUE, optionUIstr: 'Is Master', options: [ true, false ] },
    primaryLanguage: { format: FORMAT_STRING_VALUE, optionUIstr: 'Primary Language', options: [ 'zh', 'en', 'ja' ] },
    session: { format: FORMAT_MIXED_VALUE, optionUIstr: 'Session', context: { 'varName': FORMAT_STRING_VALUE } },
    daysSinceMessageLastInteraction: { format: FORMAT_NUMBER_VALUE, optionUIstr: 'Days Since Message Last Interaction', context: { messageName: FORMAT_STRING_VALUE, messageType: FORMAT_STRING_VALUE } },
    ruleXWithOptionsAndContext: { format: FORMAT_STRING_VALUE, optionUIstr: 'Rule X With Options & Context', options: [ 'football', 'basketball', 'volleyball' ], context: { context1: FORMAT_STRING_VALUE, context2: FORMAT_NUMBER_VALUE } },
};

const expressionChangeHandler = (updatedExpression) => {
    console.log(updatedExpression);
};

const targetingExpression = JSON.stringify({
    'type': 'logic',
    'operation': 'OR',
    'expressions': [
        { 'type': 'equal', 'term': { 'name': 'userId', 'value': 2 } },
        {
            'type': 'logic',
            'operation': 'AND',
            'expressions': [
                { 'type': 'equal', 'term': { 'name': 'session', 'value': 321 }, 'context': { 'varName': 'session_abc' } },
                {
                    'type': 'logic',
                    'operation': 'NOT',
                    'expressions': [ { 'type': 'among', 'term': { 'name': 'enterpriseId', 'value': [ 1, 2, 3, 4 ] } } ],
                },
            ],
        },
    ],
});

<TargetingExpressionEditor
    targetingExpression={ targetingExpression }
    ruleValueFormatMap={ ruleValueFormatMap }
    onExpressionChange={ expressionChangeHandler }
/>

```
