var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import PropTypes from 'prop-types';
import React, { Component } from 'react';

import TextInput from '../../../components/text-input';

import * as Constants from './constants';

/**
 * The input fields for 'context'.
 * Depends on how many context are defined in the rule's value format, we will render one input per context.
 */

var RuleContextInputs = function (_Component) {
    _inherits(RuleContextInputs, _Component);

    function RuleContextInputs(props) {
        _classCallCheck(this, RuleContextInputs);

        var _this = _possibleConstructorReturn(this, (RuleContextInputs.__proto__ || Object.getPrototypeOf(RuleContextInputs)).call(this, props));

        _this.componentWillReceiveProps = function (nextProps) {
            if (nextProps.ruleContext !== _this.props.ruleContext) {
                _this.setState({
                    ruleContext: _this.validateContext(nextProps.ruleContext)
                });
            }
        };

        _this.onChange = function (event) {
            var currentTarget = event.currentTarget;
            var name = currentTarget.name,
                value = currentTarget.value;
            // All input fields' names are prefixed with  CONTEXT_FIELDS_PREFIX to avoid duplication with other input names on the page, remove the prefix here.

            var nameWithoutPrefix = name.replace(Constants.CONTEXT_FIELDS_PREFIX, '');
            var newState = _this.state;
            var changedContextProp = newState.ruleContext[nameWithoutPrefix];
            changedContextProp.value = value;
            changedContextProp.validationError = _this.validateContextField(nameWithoutPrefix, value, changedContextProp.format);
            _this.setState(newState);

            // Report the new context to parent component.
            _this.props.onChange(nameWithoutPrefix, _this.formatWithValueType(changedContextProp.format, value));
            event.stopPropagation();
        };

        _this.validateContext = function (ruleContext) {
            Object.keys(ruleContext).forEach(function (item) {
                ruleContext[item].validationError = _this.validateContextField(item, ruleContext[item].value, ruleContext[item].format);
            });
            return ruleContext;
        };

        _this.validateContextField = function (name, value, format) {
            if (value === '') {
                return {
                    code: 'required',
                    message: 'Required field'
                };
            }

            switch (format) {
                case Constants.FORMAT_NUMBER_VALUE:
                    if (isNaN(Number(value))) {
                        return {
                            code: 'invalid_number',
                            message: 'Invalid number'
                        };
                    }
                    break;
                case Constants.FORMAT_BOOL_VALUE:
                    if (value !== 'false' && value !== 'true') {
                        return {
                            code: 'invalid_bool',
                            message: 'Invalid bool'
                        };
                    }
                    break;
                default:
                    break;
            }
            return null;
        };

        _this.renderContextInputs = function () {
            var ruleContext = _this.state.ruleContext;


            return Object.keys(ruleContext).map(function (item) {
                return React.createElement(TextInput, {
                    key: item
                    // All input fields' names are prefixed to avoid duplication with other input names on the page.
                    , name: Constants.CONTEXT_FIELDS_PREFIX + item,
                    placeholder: '',
                    label: item,
                    type: 'text',
                    className: 'half-width-control inline-control',
                    value: String(ruleContext[item].value),
                    error: ruleContext[item].validationError ? ruleContext[item].validationError.message : null,
                    onChange: _this.onChange,
                    isRequired: true
                });
            });
        };

        _this.state = {
            ruleContext: _this.validateContext(props.ruleContext)
        };
        return _this;
    }
    // ruleContext has following structure:
    // {
    //      'context1': { format: 'format1', value: 'value', validationError: {code: 'error_code', message: 'validation error message'}}
    //      'context2': { format: 'format1', value: 'value', validationError: {code: 'error_code', message: 'validation error message'}}
    // }


    /**
     * Event handler when user changes input value.
     * @param {object} event
     */


    _createClass(RuleContextInputs, [{
        key: 'formatWithValueType',


        /**
         * @param {string} format
         * @param {string} value
         * @returns {mixed}
         */
        value: function formatWithValueType(format, value) {
            // eslint-disable-line class-methods-use-this
            switch (format) {
                case Constants.FORMAT_NUMBER_VALUE:
                    value = Number(value);
                    break;
                case Constants.FORMAT_BOOL_VALUE:
                    value = Boolean(value);
                    break;
                default:
                    break;
            }
            return value;
        }

        /**
         * Validate all contexts fields, add validationError field.
         * @param {object} ruleContext
         * @returns {object} ruleContext object with validation error.
         */


        /**
         * Validate context fields according to defined format.
         * @param {string} name
         * @param {string|number|bool} value
         * @param {string} format
         * @returns {object|null} Validation error object, null when valid.
         */


        /**
         * render context inputs.
         */

    }, {
        key: 'render',


        /**
         * For rules expressed with bool we will only have a dropdown for 'true' 'false'
         * For rules expressed with number we will have an input.
         */
        value: function render() {
            return React.createElement(
                'div',
                null,
                React.createElement(
                    'div',
                    { className: 'context-label' },
                    'Context:'
                ),
                this.renderContextInputs()
            );
        }
    }]);

    return RuleContextInputs;
}(Component);

RuleContextInputs.propTypes = {
    onChange: PropTypes.func.isRequired,
    ruleContext: PropTypes.object.isRequired
};


export default RuleContextInputs;