var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import PropTypes from 'prop-types';
import React, { Component } from 'react';

import RuleSelect from './RuleSelect';
import RuleTypeSelect from './RuleTypeSelect';
import RuleValueInputAmong from './RuleValueInputAmong';
import RuleValueInputEqual from './RuleValueInputEqual';
import RuleValueInputsInRange from './RuleValueInputsInRange';
import RuleContextInputs from './RuleContextInputs';
import * as Constants from './constants';

import './TargetingRule.scss';

/**
 * Represent a basic rule UI element.
 * A basic rule can be an expression of logical NOT, EQUAL, AMONG, IN_RANGE.
 */

var TargetingRule = function (_Component) {
    _inherits(TargetingRule, _Component);

    function TargetingRule(props) {
        _classCallCheck(this, TargetingRule);

        var _this = _possibleConstructorReturn(this, (TargetingRule.__proto__ || Object.getPrototypeOf(TargetingRule)).call(this, props));

        _this.onRuleChange = function (event) {
            var currentTarget = event.currentTarget;

            var newRule = currentTarget.value;
            var newState = _this.getDefaultState(newRule);
            _this.setState(newState);

            // Report the new expression to parent component.
            var formattedExpression = _this.getFormattedExpression(newState);
            _this.props.onChange(formattedExpression);
            event.stopPropagation();
        };

        _this.onRuleTypeChange = function (event) {
            var currentTarget = event.currentTarget;

            var ruleName = _this.state.type === Constants.EXPRESSION_TYPE_LOGIC ? _this.state.expressions[0].term.name : _this.state.term.name;
            var newType = currentTarget.value;
            var newState = _this.getDefaultState(ruleName, newType);
            _this.setState(newState);

            // Report the new expression to parent component.
            var formattedExpression = _this.getFormattedExpression(newState);
            _this.props.onChange(formattedExpression);
            event.stopPropagation();
        };

        _this.onRuleValueChange = function (updatedExpression) {
            var newState = _this.state;
            if (newState.type === Constants.EXPRESSION_TYPE_LOGIC) {
                // NOT expression
                newState.expressions[0] = updatedExpression;
            } else {
                newState = updatedExpression;
            }
            newState.validationError = _this.getUpdatedValidationState(updatedExpression);
            _this.setState(newState);

            // Report the new expression to parent component.
            var formattedExpression = _this.getFormattedExpression(newState);
            _this.props.onChange(formattedExpression);
        };

        _this.onRuleContextValueChange = function (updatedContextName, updatedContextValue) {
            var newState = _this.state;
            var updatedExpression = newState.type === Constants.EXPRESSION_TYPE_LOGIC ? newState.expressions[0] : newState;
            updatedExpression.context[updatedContextName] = updatedContextValue;
            _this.setState(newState);

            // Report the new expression to parent component.
            var formattedExpression = _this.getFormattedExpression(newState);
            _this.props.onChange(formattedExpression);
        };

        _this.getFormattedExpression = function (newState) {
            if (newState.type === Constants.EXPRESSION_TYPE_LOGIC) {
                // NOT expression
                return {
                    type: newState.type,
                    operation: newState.operation,
                    expressions: [_this.getFormattedBasicExpression(newState.expressions[0])]
                };
            }
            return _this.getFormattedBasicExpression(newState);
        };

        _this.getFormattedBasicExpression = function (expression) {
            var result = {
                type: expression.type,
                term: {
                    name: expression.term.name,
                    value: null
                }
            };
            if (expression.context && Object.keys(expression.context).length > 0) {
                result.context = expression.context;
            }
            switch (result.type) {
                case Constants.EXPRESSION_TYPE_EQUAL:
                    _this.formatEqualExpression(result, expression);
                    break;
                case Constants.EXPRESSION_TYPE_IN_RANGE:
                    _this.formatInRangeExpression(result, expression);
                    break;
                case Constants.EXPRESSION_TYPE_AMONG:
                    _this.formatAmongExpression(result, expression);
                    break;
                default:
                    break;
            }
            return result;
        };

        _this.getUpdatedValidationState = function (updatedExpression) {
            var validationError = null;
            switch (updatedExpression.type) {
                case Constants.EXPRESSION_TYPE_EQUAL:
                    {
                        var equalExpressionFormat = _this.props.ruleValueFormatMap[updatedExpression.term.name].format;
                        validationError = _this.validateEqualField(updatedExpression.term.value, equalExpressionFormat);
                        break;
                    }
                case Constants.EXPRESSION_TYPE_AMONG:
                    {
                        var amongExpressionFormat = _this.props.ruleValueFormatMap[updatedExpression.term.name].format;
                        var stringValue = Array.isArray(updatedExpression.term.value) ? updatedExpression.term.value.join() : updatedExpression.term.value;
                        validationError = _this.validateAmongField(stringValue, amongExpressionFormat);
                        break;
                    }
                case Constants.EXPRESSION_TYPE_IN_RANGE:
                    {
                        validationError = _this.validateInRangeFields(updatedExpression.term.value);
                        break;
                    }
                default:
                    {
                        break;
                    }
            }
            return validationError;
        };

        _this.getDefaultState = function (ruleName) {
            var ruleType = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : '';

            var ruleFormat = _this.props.ruleValueFormatMap[ruleName];
            var valueFormat = ruleFormat.format;
            ruleType = ruleType || Constants.defaultRuleTypeForValueFormat[valueFormat];

            var newState = null;
            var newBasicExpression = {
                term: {
                    name: ruleName,
                    value: null
                },
                type: null,
                context: {}
            };

            // All 'NOT' expressions' ruleType format is: 'not_' + a bacis expression type.
            // When we run into 'NOT' expression ruleTypes, turn newState into a NOT expression,
            // trim off the 'not_' prefix, and assign the basic expression type to the newBasicExpression in 'expressions' array.
            if (_this.isRuleTypeNegated(ruleType)) {
                newBasicExpression.type = ruleType.replace(Constants.NOT_EXPRESSION_PREFIX, '');
                newState = {
                    type: Constants.EXPRESSION_TYPE_LOGIC,
                    operation: Constants.LOGIC_OPERATION_NOT,
                    expressions: [newBasicExpression]
                };
            } else {
                newBasicExpression.type = ruleType;
                newState = newBasicExpression;
            }

            var defaultValue = Constants.expressionDefaultValueMap[newBasicExpression.type][valueFormat];
            // Copy over properties when value is an object.
            newBasicExpression.term.value = (typeof defaultValue === 'undefined' ? 'undefined' : _typeof(defaultValue)) === 'object' ? Object.assign({}, defaultValue) : defaultValue;

            // set default value to first option if there is any
            var valueOptions = ruleFormat.options;
            if (valueOptions) {
                newBasicExpression.term.value = String(valueOptions[0]);
            }

            // set context param default values
            var contextFormats = ruleFormat.context;
            if (contextFormats) {
                Object.keys(contextFormats).forEach(function (key) {
                    var contextParamValueType = contextFormats[key];
                    newBasicExpression.context[key] = Constants.expressionDefaultValueMap[Constants.EXPRESSION_TYPE_EQUAL][contextParamValueType];
                });
            }

            newState.validationError = _this.getUpdatedValidationState(newBasicExpression);
            return newState;
        };

        _this.getRuleContextObject = function (contextValues, contextFormats) {
            var ruleContext = {};

            Object.keys(contextFormats).forEach(function (item) {
                ruleContext[item] = {
                    format: contextFormats[item],
                    value: contextValues[item] || ''
                };
            });
            return ruleContext;
        };

        _this.isRuleTypeNegated = function (ruleType) {
            return ruleType.search('not_') === 0;
        };

        _this.formatAmongExpression = function (result, expression) {
            var valueFormat = _this.props.ruleValueFormatMap[expression.term.name].format;
            if (valueFormat === Constants.FORMAT_NUMBER_VALUE) {
                result.term.value = expression.term.value.split(',').filter(function (num) {
                    return num !== '';
                }).map(function (num) {
                    return Number(num);
                });
            } else {
                result.term.value = expression.term.value.split(',');
            }
        };

        _this.formatEqualExpression = function (result, expression) {
            var valueFormat = _this.props.ruleValueFormatMap[expression.term.name].format;
            if (valueFormat === Constants.FORMAT_NUMBER_VALUE) {
                result.term.value = Number(expression.term.value);
            } else if (valueFormat === Constants.FORMAT_BOOL_VALUE) {
                result.term.value = expression.term.value === 'true';
            } else {
                result.term.value = expression.term.value;
            }
        };

        _this.formatInRangeExpression = function (result, expression) {
            result.term.value = Object.assign({}, expression.term.value);
            if (Object.prototype.hasOwnProperty.call(expression.term.value, Constants.RANGE_LOWER_BOUND)) {
                result.term.value[Constants.RANGE_LOWER_BOUND] = Number(expression.term.value[Constants.RANGE_LOWER_BOUND]);
            }
            if (Object.prototype.hasOwnProperty.call(expression.term.value, Constants.RANGE_UPPER_BOUND)) {
                result.term.value[Constants.RANGE_UPPER_BOUND] = Number(expression.term.value[Constants.RANGE_UPPER_BOUND]);
            }
        };

        _this.validateEqualField = function (fieldValue, format) {
            if (fieldValue === '') {
                return {
                    code: 'required',
                    message: 'Required field'
                };
            }
            if (format === Constants.FORMAT_NUMBER_VALUE) {
                if (isNaN(Number(fieldValue))) {
                    return {
                        code: 'invalid_number',
                        message: 'Invalid number'
                    };
                }
            }
            // No validation needed for bool field since its value comes from a select.
            return null;
        };

        _this.validateAmongField = function (fieldValue, format) {
            if (fieldValue === '') {
                return {
                    code: 'required',
                    message: 'Required field'
                };
            }
            var values = fieldValue.split(',');
            for (var i = 0; i < values.length; i++) {
                switch (format) {
                    case Constants.FORMAT_NUMBER_VALUE:
                        if (values[i] === '' || isNaN(Number(values[i]))) {
                            return {
                                code: 'invalid_among',
                                message: 'Some number in the array is invalid'
                            };
                        }
                        break;
                    case Constants.FORMAT_STRING_VALUE:
                        if (values[i] === '') {
                            return {
                                code: 'invalid_among',
                                message: 'Some string in the array is invalid'
                            };
                        }
                        break;
                    default:
                        break;
                }
            }
            return null;
        };

        _this.validateInRangeFields = function (rangeValue) {
            var validationError = {};
            if (!Object.prototype.hasOwnProperty.call(rangeValue, Constants.RANGE_UPPER_BOUND) && !Object.prototype.hasOwnProperty.call(rangeValue, Constants.RANGE_LOWER_BOUND)) {
                var error = {
                    code: 'no_limit',
                    message: 'No limit is set'
                };
                validationError[Constants.RANGE_UPPER_BOUND] = error;
                validationError[Constants.RANGE_LOWER_BOUND] = error;
                return validationError;
            }
            if (Object.prototype.hasOwnProperty.call(rangeValue, Constants.RANGE_LOWER_BOUND) && isNaN(Number(rangeValue[Constants.RANGE_LOWER_BOUND]))) {
                validationError[Constants.RANGE_LOWER_BOUND] = {
                    code: 'invalid_number',
                    message: 'Invalid number'
                };
                return validationError;
            }
            if (Object.prototype.hasOwnProperty.call(rangeValue, Constants.RANGE_UPPER_BOUND) && isNaN(Number(rangeValue[Constants.RANGE_UPPER_BOUND]))) {
                validationError[Constants.RANGE_UPPER_BOUND] = {
                    code: 'invalid_number',
                    message: 'Invalid number'
                };
                return validationError;
            }
            if (Object.prototype.hasOwnProperty.call(rangeValue, Constants.RANGE_UPPER_BOUND) && Object.prototype.hasOwnProperty.call(rangeValue, Constants.RANGE_LOWER_BOUND) && Number(rangeValue[Constants.RANGE_UPPER_BOUND]) < Number(rangeValue[Constants.RANGE_LOWER_BOUND])) {
                validationError[Constants.RANGE_UPPER_BOUND] = {
                    code: 'invalid_range',
                    message: 'Too small'
                };
                validationError[Constants.RANGE_LOWER_BOUND] = {
                    code: 'invalid_range',
                    message: 'Too large'
                };
                return validationError;
            }
            return null;
        };

        _this.renderRuleValueInputs = function (expression, valueFormat, valueOptions) {
            switch (expression.type) {
                case Constants.EXPRESSION_TYPE_EQUAL:
                    return React.createElement(RuleValueInputEqual, {
                        onChange: _this.onRuleValueChange,
                        expression: expression,
                        valueOptions: valueOptions,
                        validationError: _this.state.validationError
                    });
                case Constants.EXPRESSION_TYPE_AMONG:
                    return React.createElement(RuleValueInputAmong, {
                        onChange: _this.onRuleValueChange,
                        expression: expression,
                        valueOptions: valueOptions,
                        validationError: _this.state.validationError
                    });
                case Constants.EXPRESSION_TYPE_IN_RANGE:
                    return React.createElement(RuleValueInputsInRange, {
                        onChange: _this.onRuleValueChange,
                        expression: expression,
                        validationError: _this.state.validationError
                    });
                default:
                    break;
            }
            return null;
        };

        if (!props.type) {
            // no expression specified, use default expression.
            var defaultRule = Object.keys(_this.props.ruleValueFormatMap)[0];
            var defaultRuleFormat = _this.props.ruleValueFormatMap[defaultRule].format;
            var defaultRuleType = Constants.defaultRuleTypeForValueFormat[defaultRuleFormat];
            _this.state = _this.getDefaultState(defaultRule, defaultRuleType);
        } else if (props.type === Constants.EXPRESSION_TYPE_LOGIC) {
            // logic expression
            var initialExpression = {
                type: props.type,
                operation: props.operation,
                expressions: props.expressions
            };
            initialExpression.validationError = _this.getUpdatedValidationState(initialExpression);
            _this.state = initialExpression;
        } else {
            // basic expression
            var _initialExpression = {
                type: props.type,
                term: {
                    name: props.term.name,
                    value: props.term.value
                },
                context: props.context
            };
            _initialExpression.validationError = _this.getUpdatedValidationState(_initialExpression);
            _this.state = _initialExpression;
        }
        return _this;
    }

    /**
     * Event handler when user select a new rule.
     * @param {object} event
     * @returns {void}
     */


    /**
     * Event handler when user select a new rule expression type.
     * @param {object} event
     * @returns {void}
     */


    /**
     * Event handler when user changes input value for rule expression value.
     * @param {object} updatedExpression
     * @returns {void}
     */


    /**
     * Event handler when user changes input value for rule expression value.
     * @param {string} updatedContextValue
     * @param {mixed} updatedContextValue
     * @returns {void}
     */


    /**
     * Deep copy expression and transform its value from string to correct format.
     * @param {object} newState
     * @returns {object}
     */


    /**
     * Deep copy expression and transform basic expression value from string to correct format.
     * @param {object} expression
     * @returns {object}
     */


    /**
     * Update state when rule value fields changed.
     * @param {object} updatedExpression
     * @returns {object} updated rule state
     */


    /**
     * Reset state to default when selection of rule name or rule type changed.
     * @param {string} ruleName
     * @param {string} ruleType
     * @returns {object} updated rule state
     */


    /**
     * merge value and format object to obtain rule context object.
     * @param {object} contextValues
     * @param {object} contextFormats
     */


    /**
     * Check if the rule type is for a NOT expression.
     * All negated rule types will start with 'not_'.
     * @param {string} ruleType
     * @returns {bool}
     */


    /**
     * Transform among value from string to array of numbers.
     * @param {object} result
     * @param {object} expression
     * @returns {void}
     */


    /**
     * Transform equal expression value from string to correct format.
     * @param {object} result
     * @param {object} expression
     * @returns {void}
     */


    /**
     * Transform range limits from string to number.
     * @param {object} result
     * @param {object} expression
     * @returns {void}
     */


    /**
     * Validate equal number field on value change.
     * @param {string} fieldValue
     * @param {string} format
     * @returns {object|null} Validation error object, null when valid.
     */


    /**
     * Validate among field on value change.
     * @param {string} fieldValue
     * @param {string} format
     * @returns {object|null} Validation error object, null when valid.
     */


    /**
     * Validate range fields on value change.
     * @param {object} rangeValue
     * @returns {object|null} Validation error object, null when valid.
     */


    /**
     * Render inputs for rule value.
     * @param {object} expression
     * @param {string} valueFormat
     * @param {array} valueOptions optional
     */


    _createClass(TargetingRule, [{
        key: 'render',
        value: function render() {
            var isNotExpression = this.state.type === Constants.EXPRESSION_TYPE_LOGIC;
            var expression = isNotExpression ? this.state.expressions[0] : this.state;
            var valueFormat = this.props.ruleValueFormatMap[expression.term.name].format;
            var valueOptions = this.props.ruleValueFormatMap[expression.term.name].options;
            var contextFormat = this.props.ruleValueFormatMap[expression.term.name].context;

            return React.createElement(
                'div',
                { className: this.props.className },
                React.createElement(RuleSelect, {
                    name: expression.term.name,
                    onChange: this.onRuleChange,
                    ruleValueFormatMap: this.props.ruleValueFormatMap
                }),
                React.createElement(RuleTypeSelect, {
                    onChange: this.onRuleTypeChange,
                    valueFormat: valueFormat,
                    value: isNotExpression ? Constants.NOT_EXPRESSION_PREFIX + expression.type : expression.type
                }),
                this.renderRuleValueInputs(expression, valueFormat, valueOptions),
                (typeof contextFormat === 'undefined' ? 'undefined' : _typeof(contextFormat)) === 'object' ? React.createElement(RuleContextInputs, {
                    onChange: this.onRuleContextValueChange,
                    ruleContext: this.getRuleContextObject(expression.context, contextFormat)
                }) : null
            );
        }
    }]);

    return TargetingRule;
}(Component);

TargetingRule.propTypes = {
    className: PropTypes.string,
    onChange: PropTypes.func.isRequired,
    ruleValueFormatMap: PropTypes.objectOf(PropTypes.shape({
        format: PropTypes.string.isRequired,
        optionUIstr: PropTypes.string.isRequired,
        // When 'options' array is provided, rule value are constrainted to be one of the values in the array.
        options: PropTypes.array
    })).isRequired,
    operation: PropTypes.oneOf([Constants.LOGIC_OPERATION_NOT]),
    expressions: PropTypes.arrayOf(PropTypes.shape({
        type: PropTypes.oneOf([Constants.EXPRESSION_TYPE_EQUAL, Constants.EXPRESSION_TYPE_AMONG, Constants.EXPRESSION_TYPE_IN_RANGE]),
        term: PropTypes.shape({
            name: PropTypes.string.isRequired,
            value: PropTypes.oneOfType([PropTypes.arrayOf(PropTypes.number), PropTypes.arrayOf(PropTypes.string), PropTypes.number, PropTypes.string, PropTypes.bool, PropTypes.shape({
                key: PropTypes.string.isRequired,
                value: PropTypes.oneOfType([PropTypes.number, PropTypes.bool, PropTypes.string]).isRequired
            }), PropTypes.shape({
                lower: PropTypes.number,
                upper: PropTypes.number
            })]).isRequired
        }),
        context: PropTypes.object
    })),
    type: PropTypes.oneOf([Constants.EXPRESSION_TYPE_LOGIC, Constants.EXPRESSION_TYPE_EQUAL, Constants.EXPRESSION_TYPE_AMONG, Constants.EXPRESSION_TYPE_IN_RANGE]),
    term: PropTypes.shape({
        name: PropTypes.string.isRequired,
        value: PropTypes.oneOfType([PropTypes.arrayOf(PropTypes.number), PropTypes.arrayOf(PropTypes.string), PropTypes.number, PropTypes.string, PropTypes.bool, PropTypes.shape({
            key: PropTypes.string.isRequired,
            value: PropTypes.oneOfType([PropTypes.number, PropTypes.bool, PropTypes.string]).isRequired
        }), PropTypes.shape({
            lower: PropTypes.number,
            upper: PropTypes.number
        })]).isRequired
    }),
    context: PropTypes.object
};


export default TargetingRule;