var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } else { return Array.from(arr); } }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import PropTypes from 'prop-types';
import React, { Component } from 'react';
import omit from 'lodash/omit';
import throttle from 'lodash/throttle';
import { FormattedMessage, injectIntl, intlShape } from 'react-intl';

import { UpgradeBadge } from '../../components/badge';
import Button from '../../components/button';
import InlineNotice from '../../components/inline-notice';
import PrimaryButton from '../../components/primary-button';
import Select from '../../components/select';
import TextArea from '../../components/text-area';
import { Link } from '../../components/link';
import { Modal, ModalActions } from '../../components/modal';
import ContactDatalistItem from '../../components/contact-datalist-item';
import PillSelectorDropdown from '../../components/pill-selector-dropdown';
import { RESIN_TAG_TARGET } from '../../common/variables';

import PermissionFlyout from './PermissionFlyout';
import ReferAFriendAd from './ReferAFriendAd';
import messages from './messages';
import commonMessages from '../../common/messages';
import parseEmails from '../../utils/parseEmails';

import './InviteCollaboratorsModal.scss';

var COLLAB_ROLE_FOR_FILE = 'Editor';
var INPUT_DELAY = 250;

/**
 * Returns true if the given value is a substring of the searchString
 * @param {String} value
 * @param {String} searchString
 * @return {boolean}
 */
var isSubstring = function isSubstring(value, searchString) {
    return value && value.toLowerCase().indexOf(searchString.toLowerCase()) !== -1;
};

var InviteCollaboratorsModal = function (_Component) {
    _inherits(InviteCollaboratorsModal, _Component);

    function InviteCollaboratorsModal(props) {
        _classCallCheck(this, InviteCollaboratorsModal);

        var _this = _possibleConstructorReturn(this, (InviteCollaboratorsModal.__proto__ || Object.getPrototypeOf(InviteCollaboratorsModal)).call(this, props));

        _this.getSelectorOptions = function () {
            var contacts = _this.props.contacts;
            var _this$state = _this.state,
                pillSelectorInputValue = _this$state.pillSelectorInputValue,
                selectedOptions = _this$state.selectedOptions;


            if (pillSelectorInputValue !== '') {
                return contacts.filter(
                // filter contacts whose name or email don't match input value
                function (_ref) {
                    var name = _ref.name,
                        email = _ref.email;
                    return isSubstring(name, pillSelectorInputValue) || isSubstring(email, pillSelectorInputValue);
                }).filter(
                // filter contacts who have already been selected
                function (_ref2) {
                    var email = _ref2.email,
                        id = _ref2.id;
                    return !selectedOptions.find(function (_ref3) {
                        var value = _ref3.value;
                        return value === email || value === id;
                    });
                }).map(function (_ref4) {
                    var email = _ref4.email,
                        id = _ref4.id,
                        name = _ref4.name,
                        type = _ref4.type;
                    return {
                        // map to standardized DatalistItem format
                        email: email,
                        id: id,
                        text: name,
                        type: type,
                        value: email || id // if email doesn't exist, contact is a group, use id
                    };
                });
            }

            // return empty selector options if input value is empty
            return [];
        };

        _this.closeModal = function () {
            _this.setState({
                pillSelectorError: '',
                pillSelectorInputValue: '',
                selectedOptions: []
            });
            _this.props.onRequestClose();
        };

        _this.sendInvites = function () {
            var _this$props = _this.props,
                intl = _this$props.intl,
                sendInvites = _this$props.sendInvites;
            var _this$state2 = _this.state,
                message = _this$state2.message,
                permission = _this$state2.permission,
                pillSelectorError = _this$state2.pillSelectorError,
                selectedOptions = _this$state2.selectedOptions;


            if (pillSelectorError) {
                // Block submission if there's a validation error
                return;
            }

            if (selectedOptions.length === 0) {
                // Block submission if no pills are selected
                _this.setState({
                    pillSelectorError: intl.formatMessage(commonMessages.requiredFieldError)
                });
                return;
            }

            var emails = [];
            var groupIDs = [];
            selectedOptions.forEach(function (_ref5) {
                var type = _ref5.type,
                    value = _ref5.value;

                if (type === 'group') {
                    groupIDs.push(value);
                } else {
                    emails.push(value);
                }
            });

            var params = {
                emails: emails.join(','),
                groupIDs: groupIDs.join(','),
                emailMessage: message,
                permission: permission || COLLAB_ROLE_FOR_FILE,
                numsOfInvitees: emails.length,
                numOfInviteeGroups: groupIDs.length
            };
            sendInvites(params).catch(function (error) {
                // Remove invited emails from selected pills
                var invitedEmails = error.invitedEmails || [];
                _this.filterInvitedEmails(invitedEmails);
            });
        };

        _this.filterInvitedEmails = function (invitedEmails) {
            _this.setState({
                selectedOptions: _this.state.selectedOptions.filter(function (_ref6) {
                    var value = _ref6.value;
                    return !invitedEmails.includes(value);
                })
            });
        };

        _this.handlePillSelectorInput = throttle(function (value) {
            var onUserInput = _this.props.onUserInput;

            if (onUserInput) {
                onUserInput(value);
            }

            // As user is typing, reset error
            _this.setState({ pillSelectorError: '', pillSelectorInputValue: value });
        }, INPUT_DELAY);

        _this.handlePillSelect = function (pills) {
            _this.setState({
                selectedOptions: [].concat(_toConsumableArray(_this.state.selectedOptions), _toConsumableArray(pills))
            });
        };

        _this.handlePillRemove = function (option, index) {
            var selectedOptions = _this.state.selectedOptions.slice();
            selectedOptions.splice(index, 1);
            _this.setState({ selectedOptions: selectedOptions });
        };

        _this.validateForError = function (text) {
            var intl = _this.props.intl;

            var pillSelectorError = '';

            if (text && !_this.validator(text)) {
                pillSelectorError = intl.formatMessage(commonMessages.invalidEmailError);
            }

            _this.setState({ pillSelectorError: pillSelectorError });
        };

        _this.validator = function (text) {
            // email input validation
            var pattern = /^[^\s<>@,]+@[^\s<>@,/\\]+\.[^\s<>@,]+$/i;
            return pattern.test(text);
        };

        _this.handlePermissionChange = function (_ref7) {
            var target = _ref7.target;
            var value = target.value;

            _this.setState({ permission: value });
        };

        _this.handleMessageChange = function (_ref8) {
            var target = _ref8.target;
            var value = target.value;

            _this.setState({ message: value });
        };

        var defaultPersonalMessage = props.defaultPersonalMessage,
            inviteePermissions = props.inviteePermissions;

        _this.state = {
            message: defaultPersonalMessage || '',
            permission: inviteePermissions ? inviteePermissions[0].value : COLLAB_ROLE_FOR_FILE,
            pillSelectorError: '',
            pillSelectorInputValue: '',
            selectedOptions: []
        };
        return _this;
    }

    _createClass(InviteCollaboratorsModal, [{
        key: 'renderFileCollabComponents',
        value: function renderFileCollabComponents() {
            return React.createElement(
                'div',
                { className: 'invite-file-editors' },
                React.createElement(FormattedMessage, messages.inviteFileEditorsLabel)
            );
        }
    }, {
        key: 'renderPermissionsSection',
        value: function renderPermissionsSection() {
            var inviteePermissions = this.props.inviteePermissions;

            return React.createElement(
                'div',
                { className: 'invite-permissions-container' },
                React.createElement(
                    Select,
                    {
                        className: 'select-container-medium',
                        label: React.createElement(FormattedMessage, messages.inviteePermissionsFieldLabel),
                        onChange: this.handlePermissionChange,
                        name: 'invite-permission',
                        'data-resin-target': 'selectpermission'
                    },
                    inviteePermissions.map(function (_ref9) {
                        var value = _ref9.value,
                            _ref9$disabled = _ref9.disabled,
                            disabled = _ref9$disabled === undefined ? false : _ref9$disabled,
                            text = _ref9.text;
                        return React.createElement(
                            'option',
                            {
                                'data-resin-option': value,
                                disabled: disabled,
                                key: value,
                                value: value
                            },
                            text
                        );
                    })
                ),
                React.createElement(PermissionFlyout, null)
            );
        }
    }, {
        key: 'renderFolderCollabComponents',
        value: function renderFolderCollabComponents() {
            var _props = this.props,
                defaultPersonalMessage = _props.defaultPersonalMessage,
                inviteePermissions = _props.inviteePermissions,
                showUpgradeOptions = _props.showUpgradeOptions;

            return React.createElement(
                'div',
                null,
                inviteePermissions && this.renderPermissionsSection(),
                showUpgradeOptions && React.createElement(
                    Link,
                    { className: 'upgrade-link', href: '/upgrade' },
                    React.createElement(UpgradeBadge, null),
                    React.createElement(FormattedMessage, messages.upgradeGetMoreAccessControls)
                ),
                defaultPersonalMessage && React.createElement(TextArea, {
                    label: React.createElement(FormattedMessage, messages.personalMessageLabel),
                    defaultValue: defaultPersonalMessage,
                    onChange: this.handleMessageChange,
                    name: 'collab-message',
                    cols: '30',
                    rows: '4',
                    'data-resin-feature': 'personalmessage',
                    'data-resin-target': 'message'
                })
            );
        }
    }, {
        key: 'render',
        value: function render() {
            var _props2 = this.props,
                collaborationRestrictionWarning = _props2.collaborationRestrictionWarning,
                intl = _props2.intl,
                inviteButtonProps = _props2.inviteButtonProps,
                isEligibleForReferAFriendProgram = _props2.isEligibleForReferAFriendProgram,
                itemName = _props2.itemName,
                itemType = _props2.itemType,
                submissionError = _props2.submissionError,
                submitting = _props2.submitting,
                rest = _objectWithoutProperties(_props2, ['collaborationRestrictionWarning', 'intl', 'inviteButtonProps', 'isEligibleForReferAFriendProgram', 'itemName', 'itemType', 'submissionError', 'submitting']);

            var _state = this.state,
                pillSelectorError = _state.pillSelectorError,
                selectedOptions = _state.selectedOptions;

            var modalProps = omit(rest, ['contacts', 'defaultPersonalMessage', 'inviteePermissions', 'itemTypedID', 'onRequestClose', 'onUserInput', 'sendInvites', 'showUpgradeOptions']);

            var selectorOptions = this.getSelectorOptions();

            var title = React.createElement(FormattedMessage, _extends({}, messages.inviteCollaboratorsModalTitle, {
                values: {
                    itemName: itemName
                }
            }));

            var groupLabel = React.createElement(FormattedMessage, messages.groupLabel);

            return React.createElement(
                Modal,
                _extends({
                    className: 'invite-collaborators-modal',
                    title: title,
                    onRequestClose: this.closeModal,
                    'data-resin-component': 'modal',
                    'data-resin-feature': 'invitecollaborators',
                    closeButtonProps: _defineProperty({}, RESIN_TAG_TARGET, 'close')
                }, modalProps),
                submissionError && React.createElement(
                    InlineNotice,
                    { type: 'error' },
                    submissionError
                ),
                collaborationRestrictionWarning && React.createElement(
                    InlineNotice,
                    { type: 'warning' },
                    collaborationRestrictionWarning
                ),
                React.createElement(
                    PillSelectorDropdown,
                    {
                        allowCustomPills: true,
                        error: pillSelectorError,
                        label: React.createElement(FormattedMessage, messages.inviteFieldLabel),
                        onInput: this.handlePillSelectorInput,
                        onRemove: this.handlePillRemove,
                        onSelect: this.handlePillSelect,
                        parseItems: parseEmails,
                        placeholder: intl.formatMessage(commonMessages.pillSelectorPlaceholder),
                        selectedOptions: selectedOptions,
                        selectorOptions: selectorOptions,
                        validateForError: this.validateForError,
                        validator: this.validator
                    },
                    selectorOptions.map(function (_ref11) {
                        var email = _ref11.email,
                            text = _ref11.text,
                            value = _ref11.value;
                        return React.createElement(ContactDatalistItem, {
                            key: value,
                            name: text,
                            subtitle: email || groupLabel
                        });
                    })
                ),
                itemType === 'file' ? this.renderFileCollabComponents() : this.renderFolderCollabComponents(),
                isEligibleForReferAFriendProgram && React.createElement(ReferAFriendAd, null),
                React.createElement(
                    ModalActions,
                    null,
                    React.createElement(
                        Button,
                        {
                            'data-resin-target': 'cancel',
                            isDisabled: submitting,
                            onClick: this.closeModal,
                            type: 'button'
                        },
                        React.createElement(FormattedMessage, messages.inviteCollaboratorsModalCancelButton)
                    ),
                    React.createElement(
                        PrimaryButton,
                        _extends({}, inviteButtonProps, {
                            isDisabled: submitting,
                            isLoading: submitting,
                            onClick: this.sendInvites
                        }),
                        React.createElement(FormattedMessage, messages.inviteCollaboratorsModalSendInvitesButton)
                    )
                )
            );
        }
    }]);

    return InviteCollaboratorsModal;
}(Component);

InviteCollaboratorsModal.propTypes = {
    /** Message warning about restrictions regarding inviting collaborators to the item */
    collaborationRestrictionWarning: PropTypes.node,
    /** An array of contacts for the pill selector dropdown */
    contacts: PropTypes.arrayOf(PropTypes.shape({
        email: PropTypes.string,
        id: PropTypes.oneOfType([PropTypes.number, PropTypes.string]).isrequired,
        name: PropTypes.string.isRequired,
        type: PropTypes.string.isRequired
    })).isRequired,
    /**
     * Default personal message for inviting collaborators to the item.
     * Do not include if no personal message textarea should show up.
     * Only applicable to non-file item types.
     * */
    defaultPersonalMessage: PropTypes.node,
    intl: intlShape.isRequired,
    /** Props for the invite button */
    inviteButtonProps: PropTypes.object,
    /** An array of invitee permissions */
    inviteePermissions: PropTypes.arrayOf(PropTypes.shape({
        disabled: PropTypes.bool,
        text: PropTypes.string.isRequired,
        value: PropTypes.string.isRequired
    })),
    /** If true, will render a link to the refer-a-friend reward center */
    isEligibleForReferAFriendProgram: PropTypes.bool,
    /** The name of the item to invite collaborators for */
    itemName: PropTypes.string.isRequired,
    /** The type of the item to invite collaborators for (e.g. "file", "folder") */
    itemType: PropTypes.string.isRequired,
    /** The typed id of the item to invite collaborators for */
    itemTypedID: PropTypes.string.isRequired,
    /** Handler function for closing the modal */
    onRequestClose: PropTypes.func.isRequired,
    /** Handler function whenever the user types, e.g. to fetch contacts. */
    onUserInput: PropTypes.func,
    /**
     * Function to send collab invitations based on the given parameters object.
     * This function should return a Promise.
     */
    sendInvites: PropTypes.func.isRequired,
    /**
     * Flag to show link to upgrade and get more access controls.
     * Only applicable to non-file item types.
     */
    showUpgradeOptions: PropTypes.bool,
    /** Message indicating an error occurred while sending the invites. */
    submissionError: PropTypes.node,
    /**
     * Flag indicating whether the send invites request is submitting.
     */
    submitting: PropTypes.bool
};
InviteCollaboratorsModal.defaultProps = {
    inviteButtonProps: {}
};


export { InviteCollaboratorsModal as InviteCollaboratorsModalBase };
export default injectIntl(InviteCollaboratorsModal);