var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import * as React from 'react';
import { FormattedMessage } from 'react-intl';
import classNames from 'classnames';
import isEqual from 'lodash/isEqual';
import cloneDeep from 'lodash/cloneDeep';
import scrollIntoViewIfNeeded from 'scroll-into-view-if-needed';

import Collapsible from '../../components/collapsible/Collapsible';
import IconMetadataColored from '../../icons/general/IconMetadataColored';
import IconAlertCircle from '../../icons/general/IconAlertCircle';
import IconEdit from '../../icons/general/IconEdit';
import LoadingIndicatorWrapper from '../../components/loading-indicator/LoadingIndicatorWrapper';
import PlainButton from '../../components/plain-button/PlainButton';
import Tooltip from '../../components/tooltip';
import { kingCrimson } from '../../styles/variables';

import CascadePolicy from './CascadePolicy';
import TemplatedInstance from './TemplatedInstance';
import CustomInstance from './CustomInstance';
import MetadataInstanceConfirmDialog from './MetadataInstanceConfirmDialog';
import Footer from './Footer';
import messages from './messages';
import { FIELD_TYPE_FLOAT, FIELD_TYPE_INTEGER, TEMPLATE_CUSTOM_PROPERTIES, JSON_PATCH_OP_REMOVE, JSON_PATCH_OP_ADD, JSON_PATCH_OP_REPLACE, JSON_PATCH_OP_TEST } from './constants';
import { isValidValue } from './fields/validateField';
import isHidden from './metadataUtil';
import { RESIN_TAG_TARGET } from '../../common/variables';

import './Instance.scss';

var createFieldKeyToTypeMap = function createFieldKeyToTypeMap() {
    var fields = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : [];
    return fields.reduce(function (prev, _ref) {
        var key = _ref.key,
            type = _ref.type;

        prev[key] = type;
        return prev;
    }, {});
};

var getValue = function getValue(data, key, type) {
    var value = data[key];

    switch (type) {
        case FIELD_TYPE_FLOAT:
            return parseFloat(value);

        case FIELD_TYPE_INTEGER:
            return parseInt(value, 10);

        default:
            return value;
    }
};

var Instance = function (_React$PureComponent) {
    _inherits(Instance, _React$PureComponent);

    function Instance(props) {
        _classCallCheck(this, Instance);

        var _this = _possibleConstructorReturn(this, (Instance.__proto__ || Object.getPrototypeOf(Instance)).call(this, props));

        _this.onCancel = function () {
            var _this$props = _this.props,
                id = _this$props.id,
                onModification = _this$props.onModification;

            _this.setState(_this.getState(_this.props));

            // Callback to parent to tell that something is dirty
            if (onModification) {
                onModification(id, false);
            }
        };

        _this.onConfirmRemove = function () {
            _this.setState({ shouldConfirmRemove: true });
        };

        _this.onConfirmCancel = function () {
            _this.setState({ shouldConfirmRemove: false });
        };

        _this.onRemove = function () {
            if (!_this.isEditing()) {
                return;
            }

            var _this$props2 = _this.props,
                id = _this$props2.id,
                onRemove = _this$props2.onRemove;

            if (onRemove) {
                onRemove(id);
                _this.setState({ isBusy: true });
            }
        };

        _this.onSave = function () {
            var _this$props3 = _this.props,
                cascadePolicy = _this$props3.cascadePolicy,
                originalData = _this$props3.data,
                id = _this$props3.id,
                isDirty = _this$props3.isDirty,
                isCascadingPolicyApplicable = _this$props3.isCascadingPolicyApplicable,
                onSave = _this$props3.onSave;
            var _this$state = _this.state,
                currentData = _this$state.data,
                errors = _this$state.errors,
                isCascadingEnabled = _this$state.isCascadingEnabled,
                isCascadingOverwritten = _this$state.isCascadingOverwritten;


            if (!_this.isEditing() || !isDirty || !onSave || Object.keys(errors).length) {
                return;
            }

            _this.setState({
                isBusy: true,
                isEditing: false,
                shouldShowCascadeOptions: false
            });
            onSave(id, _this.createJSONPatch(currentData, originalData), isCascadingPolicyApplicable ? {
                canEdit: cascadePolicy ? cascadePolicy.canEdit : false,
                id: cascadePolicy ? cascadePolicy.id : undefined,
                isEnabled: isCascadingEnabled,
                overwrite: isCascadingOverwritten
            } : undefined, cloneDeep(currentData));
        };

        _this.onFieldChange = function (key, value, type) {
            var _this$state2 = _this.state,
                data = _this$state2.data,
                errors = _this$state2.errors;

            // Don't do anything if data is the same or not in edit mode

            if (!_this.isEditing() || isEqual(data[key], value)) {
                return;
            }

            var isValid = isValidValue(type, value);
            var finalErrors = _extends({}, errors);
            var finalData = cloneDeep(data);
            finalData[key] = value;

            if (isValid) {
                delete finalErrors[key];
            } else {
                finalErrors[key] = React.createElement(FormattedMessage, messages.invalidInput);
            }

            _this.setState({ data: finalData, errors: finalErrors }, function () {
                _this.setDirty(type);
            });
        };

        _this.onFieldRemove = function (key) {
            if (!_this.isEditing()) {
                return;
            }

            var _this$state3 = _this.state,
                data = _this$state3.data,
                errors = _this$state3.errors;

            var finalData = cloneDeep(data);
            var finalErrors = _extends({}, errors);
            delete finalData[key];
            delete finalErrors[key];
            _this.setState({ data: finalData, errors: finalErrors }, _this.setDirty);
        };

        _this.onCascadeToggle = function (value) {
            var isCascadingPolicyApplicable = _this.props.isCascadingPolicyApplicable;

            if (!isCascadingPolicyApplicable) {
                return;
            }

            _this.setState({
                isCascadingEnabled: value,
                shouldShowCascadeOptions: value
            }, _this.setDirty);
        };

        _this.onCascadeModeChange = function (value) {
            var isCascadingPolicyApplicable = _this.props.isCascadingPolicyApplicable;

            if (!isCascadingPolicyApplicable) {
                return;
            }

            _this.setState({
                isCascadingOverwritten: value
            }, _this.setDirty);
        };

        _this.renderDeleteMessage = function (isFile, template) {
            var message = void 0;
            var isProperties = template.templateKey === TEMPLATE_CUSTOM_PROPERTIES;

            if (isProperties) {
                message = isFile ? 'fileMetadataRemoveCustomTemplateConfirm' : 'folderMetadataRemoveCustomTemplateConfirm';
            } else {
                message = isFile ? 'fileMetadataRemoveTemplateConfirm' : 'folderMetadataRemoveTemplateConfirm';
            }

            return React.createElement(FormattedMessage, _extends({}, messages[message], {
                values: {
                    metadataName: template.displayName
                }
            }));
        };

        _this.setDirty = function (type) {
            var _this$props4 = _this.props,
                id = _this$props4.id,
                isCascadingPolicyApplicable = _this$props4.isCascadingPolicyApplicable,
                onModification = _this$props4.onModification;
            var _this$state4 = _this.state,
                data = _this$state4.data,
                isCascadingEnabled = _this$state4.isCascadingEnabled,
                isCascadingOverwritten = _this$state4.isCascadingOverwritten;

            var hasDataChanged = !isEqual(data, _this.props.data);
            var hasCascadingChanged = false;

            if (isCascadingPolicyApplicable) {
                // isCascadingOverwritten always starts out as false, so true signifies a change
                hasCascadingChanged = isCascadingOverwritten || isCascadingEnabled !== _this.isCascadingEnabled(_this.props);
            }

            // Callback to parent to tell that something is dirty
            if (onModification) {
                onModification(id, hasDataChanged || hasCascadingChanged, type);
            }
        };

        _this.collapsibleRef = React.createRef();

        _this.toggleIsEditing = function () {
            _this.setState(function (prevState) {
                return {
                    isEditing: !prevState.isEditing
                };
            });
        };

        _this.renderEditButton = function () {
            var isDirty = _this.props.isDirty;
            var isBusy = _this.state.isBusy;

            var canEdit = _this.canEdit();
            var isEditing = _this.isEditing();
            var editClassName = classNames('metadata-instance-editor-instance-edit', {
                'metadata-instance-editor-instance-is-editing': isEditing
            });

            if (canEdit && !isDirty && !isBusy) {
                return React.createElement(
                    Tooltip,
                    {
                        text: React.createElement(FormattedMessage, messages.metadataEditTooltip),
                        position: 'top-left'
                    },
                    React.createElement(
                        PlainButton,
                        {
                            'data-resin-target': 'metadata-instanceedit',
                            type: 'button',
                            className: editClassName,
                            onClick: _this.toggleIsEditing
                        },
                        React.createElement(IconEdit, null)
                    )
                );
            }
            return null;
        };

        _this.state = _this.getState(props);
        _this.fieldKeyToTypeMap = createFieldKeyToTypeMap(props.template.fields);
        return _this;
    }

    Instance.propTypes = {
        canEdit: PropTypes.bool.isRequired,
        cascadePolicy: function cascadePolicy() {
            return (typeof bpfrpt_proptype_CascadePolicyType === 'function' ? bpfrpt_proptype_CascadePolicyType : PropTypes.shape(bpfrpt_proptype_CascadePolicyType)).apply(this, arguments);
        },
        // eslint-disable-line
        data: function data() {
            return (typeof bpfrpt_proptype_Fields === 'function' ? bpfrpt_proptype_Fields.isRequired ? bpfrpt_proptype_Fields.isRequired : bpfrpt_proptype_Fields : PropTypes.shape(bpfrpt_proptype_Fields).isRequired).apply(this, arguments);
        },
        hasError: PropTypes.bool.isRequired,
        id: PropTypes.string.isRequired,
        isCascadingPolicyApplicable: PropTypes.bool,
        isDirty: PropTypes.bool.isRequired,
        onModification: PropTypes.func,
        onSave: PropTypes.func,
        onRemove: PropTypes.func,
        isOpen: PropTypes.bool.isRequired,
        template: function template() {
            return (typeof bpfrpt_proptype_Template === 'function' ? bpfrpt_proptype_Template.isRequired ? bpfrpt_proptype_Template.isRequired : bpfrpt_proptype_Template : PropTypes.shape(bpfrpt_proptype_Template).isRequired).apply(this, arguments);
        }
    };

    _createClass(Instance, [{
        key: 'componentWillReceiveProps',
        value: function componentWillReceiveProps(nextProps) {
            var hasError = nextProps.hasError,
                isDirty = nextProps.isDirty;
            var isEditing = this.state.isEditing;

            // This only handles cases when an error occurred
            // or when the dirty state of the instance has changed.
            // The dirty state can change when either
            // the metadata was saved OR when the metadata manually
            // reverted to its original state.

            if (hasError) {
                // If hasError is true, which means an error occurred while
                // doing a network operation and hence hide the busy indicator
                // Saving also disables isEditing, so need to enable that back.
                // isDirty remains as it was before.
                this.setState({ isBusy: false, isEditing: true });
            } else if (this.props.isDirty && !isDirty) {
                // If the form was dirty and now its not dirty
                // we know a successful save may have happened.
                // We don't modify isEditing here because we maintain the
                // prior state for that. If we came here from a save
                // success then save already disabled isEditing.
                if (isEditing) {
                    // We are still editing so don't reset it
                    this.setState({ isBusy: false });
                } else {
                    // For a successfull save we reset cascading overwrite radio
                    this.setState({ isBusy: false, isCascadingOverwritten: false });
                }
            }
        }
    }, {
        key: 'componentDidUpdate',
        value: function componentDidUpdate() {
            var element = this.collapsibleRef.current;
            if (element && this.state.shouldConfirmRemove) {
                scrollIntoViewIfNeeded(element, false, {
                    centerIfNeeded: false,
                    duration: 320,
                    easing: 'easeInOut'
                });
            }
        }

        /**
         * Undo any changes made
         *
         * @return {void}
         */


        /**
         * Allows a user to confirm metadata instance removal
         *
         * @return {void}
         */


        /**
         * Cancel the remove instance attempt
         *
         * @return {void}
         */


        /**
         * Removes an instance
         *
         * @return {void}
         */


        /**
         * Saves instance data
         *
         * @return {void}
         */


        /**
         * Updates a key value in the instance data
         *
         * @param {string} key - key to update
         * @param {FieldValue} value - value to update
         * @param {string} type - type of field
         * @return {void}
         */


        /**
         * Removes a key from instance data
         *
         * @param {string} key - key to remove
         * @return {void}
         */


        /**
         * Toggle cascading policy
         *
         * @param {boolean} value - true when turned on
         * @return {void}
         */


        /**
         * Changes the cascade mode.
         * isCascadingOverwritten is slways false to start off.
         *
         * @param {boolean} value - true when overwrite policy is chosen
         * @return {void}
         */

    }, {
        key: 'getState',


        /**
         * Returns the state from props
         *
         * @return {Object} - react state
         */
        value: function getState(props) {
            return {
                data: cloneDeep(props.data),
                errors: {},
                isBusy: false,
                isCascadingEnabled: this.isCascadingEnabled(props),
                isCascadingOverwritten: false,
                isEditing: false,
                shouldConfirmRemove: false,
                shouldShowCascadeOptions: false
            };
        }

        /**
         * Returns the card title with possible error mark
         *
         * @return {Object} - react title element
         */

    }, {
        key: 'getTitle',
        value: function getTitle() {
            var _props = this.props,
                _props$cascadePolicy = _props.cascadePolicy,
                cascadePolicy = _props$cascadePolicy === undefined ? {} : _props$cascadePolicy,
                hasError = _props.hasError,
                isCascadingPolicyApplicable = _props.isCascadingPolicyApplicable,
                template = _props.template;

            var isProperties = template.templateKey === TEMPLATE_CUSTOM_PROPERTIES;

            var type = isCascadingPolicyApplicable && cascadePolicy.id ? 'cascade' : 'default';

            return React.createElement(
                'span',
                { className: 'metadata-instance-editor-instance-title' },
                React.createElement(IconMetadataColored, { type: type }),
                React.createElement(
                    'span',
                    {
                        className: classNames('metadata-instance-editor-instance-title-text', {
                            'metadata-instance-editor-instance-has-error': hasError
                        })
                    },
                    isProperties ? React.createElement(FormattedMessage, messages.customTitle) : template.displayName
                ),
                hasError && React.createElement(IconAlertCircle, { color: kingCrimson })
            );
        }

        /**
         * Render the correct delete message to show based on custom metadata and file/folder metadata
         */

    }, {
        key: 'getConfirmationMessage',


        /**
         * Get the delete confirmation message base on the template key
         */
        value: function getConfirmationMessage() {
            var _props2 = this.props,
                template = _props2.template,
                isCascadingPolicyApplicable = _props2.isCascadingPolicyApplicable;

            var isFile = !isCascadingPolicyApplicable;
            return this.renderDeleteMessage(isFile, template);
        }

        /**
         * Evaluates if the metadata was changed or cascading policy
         * altered or enabled.
         *
         * @return {void}
         */

    }, {
        key: 'isCascadingEnabled',


        /**
         * Determines if cascading policy is enabled based on
         * whether it has an id or not.
         *
         * @param {Object} props - component props
         * @return {boolean} true if cascading policy is enabled
         */
        value: function isCascadingEnabled(props) {
            if (props.cascadePolicy) {
                return !!props.cascadePolicy.id;
            }
            return false;
        }

        /**
         * Toggles the edit mode
         *
         * @private
         * @return {void}
         */

    }, {
        key: 'createJSONPatch',


        /**
         * Creates JSON Patch operations from the passed in
         * data while comparing it to the original data from props.
         *
         * Only diffs at the root level and primitives.
         *
         * @param {*} currentData - the latest changes by the user
         * @param {*} originalData - the original values
         * @return {Array} - JSON patch operations
         */
        value: function createJSONPatch(currentData, originalData) {
            var _this2 = this;

            var ops = [];
            var data = cloneDeep(currentData); // clone the data for mutation

            // Iterate over the original data and find keys that have changed.
            // Also remove them from the data object to only leave new keys.
            Object.keys(originalData).forEach(function (key) {
                var type = _this2.fieldKeyToTypeMap[key];
                var originalValue = getValue(originalData, key, type);
                var path = '/' + key;

                if (Object.prototype.hasOwnProperty.call(data, key)) {
                    var value = getValue(data, key, type);

                    // Only register changed data
                    if (!isEqual(value, originalValue)) {
                        // Add a test OP for each replaces
                        ops.push({
                            op: JSON_PATCH_OP_TEST,
                            path: path,
                            value: originalValue
                        });
                        ops.push({
                            op: JSON_PATCH_OP_REPLACE,
                            path: path,
                            value: value
                        });
                    }
                } else {
                    // Key was removed
                    // Add a test OP for removes
                    ops.push({
                        op: JSON_PATCH_OP_TEST,
                        path: path,
                        value: originalValue
                    });
                    ops.push({ op: JSON_PATCH_OP_REMOVE, path: path });
                }
                delete data[key];
            });

            // Iterate over the remaining keys that are new.
            Object.keys(data).forEach(function (key) {
                var type = _this2.fieldKeyToTypeMap[key];
                var value = getValue(data, key, type);

                ops.push({
                    op: JSON_PATCH_OP_ADD,
                    path: '/' + key,
                    value: value
                });
            });

            return ops;
        }

        /**
         * Utility function to determine if instance is editable
         *
         * @return {boolean} true if editable
         */

    }, {
        key: 'canEdit',
        value: function canEdit() {
            var _props3 = this.props,
                canEdit = _props3.canEdit,
                onModification = _props3.onModification,
                onRemove = _props3.onRemove,
                onSave = _props3.onSave;

            return canEdit && typeof onRemove === 'function' && typeof onSave === 'function' && typeof onModification === 'function';
        }

        /**
         * Utility function to determine if instance is in edit mode
         *
         * @return {boolean} true if editing
         */

    }, {
        key: 'isEditing',
        value: function isEditing() {
            var isEditing = this.state.isEditing;

            return this.canEdit() && isEditing;
        }
    }, {
        key: 'render',
        value: function render() {
            var _props4 = this.props,
                _props4$cascadePolicy = _props4.cascadePolicy,
                cascadePolicy = _props4$cascadePolicy === undefined ? {} : _props4$cascadePolicy,
                isDirty = _props4.isDirty,
                isCascadingPolicyApplicable = _props4.isCascadingPolicyApplicable,
                isOpen = _props4.isOpen,
                template = _props4.template;
            var _template$fields = template.fields,
                fields = _template$fields === undefined ? [] : _template$fields;
            var _state = this.state,
                data = _state.data,
                errors = _state.errors,
                isBusy = _state.isBusy,
                isCascadingEnabled = _state.isCascadingEnabled,
                shouldConfirmRemove = _state.shouldConfirmRemove,
                shouldShowCascadeOptions = _state.shouldShowCascadeOptions,
                isCascadingOverwritten = _state.isCascadingOverwritten;

            var isProperties = template.templateKey === TEMPLATE_CUSTOM_PROPERTIES;
            var isEditing = this.isEditing();

            if (!template || isHidden(template)) {
                return null;
            }

            // Animate short and tall cards at consistent speeds.
            var animationDuration = (fields.length + 1) * 50;

            return React.createElement(
                'div',
                { ref: this.collapsibleRef },
                React.createElement(
                    Collapsible,
                    {
                        animationDuration: animationDuration,
                        buttonProps: _defineProperty({}, RESIN_TAG_TARGET, 'metadata-card'),
                        isBordered: true,
                        hasStickyHeader: true,
                        headerActionItems: this.renderEditButton(),
                        isOpen: isOpen,
                        title: this.getTitle()
                    },
                    shouldConfirmRemove && React.createElement(
                        LoadingIndicatorWrapper,
                        { isLoading: isBusy },
                        React.createElement(MetadataInstanceConfirmDialog, {
                            confirmationMessage: this.getConfirmationMessage(),
                            onConfirm: this.onRemove,
                            onCancel: this.onConfirmCancel
                        })
                    ),
                    !shouldConfirmRemove && React.createElement(
                        LoadingIndicatorWrapper,
                        { isLoading: isBusy },
                        React.createElement(
                            'div',
                            { className: 'metadata-instance-editor-instance' },
                            isCascadingPolicyApplicable && React.createElement(CascadePolicy, {
                                canEdit: isEditing && !!cascadePolicy.canEdit,
                                isCascadingEnabled: isCascadingEnabled,
                                isCascadingOverwritten: isCascadingOverwritten,
                                isCustomMetadata: isProperties,
                                onCascadeToggle: this.onCascadeToggle,
                                onCascadeModeChange: this.onCascadeModeChange,
                                shouldShowCascadeOptions: shouldShowCascadeOptions
                            }),
                            isProperties ? React.createElement(CustomInstance, {
                                canEdit: isEditing,
                                data: data,
                                onFieldChange: this.onFieldChange,
                                onFieldRemove: this.onFieldRemove
                            }) : React.createElement(TemplatedInstance, {
                                canEdit: isEditing,
                                data: data,
                                errors: errors,
                                template: template,
                                onFieldChange: this.onFieldChange,
                                onFieldRemove: this.onFieldRemove
                            })
                        ),
                        isEditing && React.createElement(Footer, {
                            onSave: isDirty ? this.onSave : undefined,
                            onCancel: this.onCancel,
                            onRemove: this.onConfirmRemove
                        })
                    )
                )
            );
        }
    }]);

    return Instance;
}(React.PureComponent);

Instance.defaultProps = {
    data: {},
    isDirty: false
};
Instance.propTypes = {
    canEdit: PropTypes.bool.isRequired,
    cascadePolicy: function cascadePolicy() {
        return (typeof bpfrpt_proptype_CascadePolicyType === 'function' ? bpfrpt_proptype_CascadePolicyType : PropTypes.shape(bpfrpt_proptype_CascadePolicyType)).apply(this, arguments);
    },
    data: function data() {
        return (typeof bpfrpt_proptype_Fields === 'function' ? bpfrpt_proptype_Fields.isRequired ? bpfrpt_proptype_Fields.isRequired : bpfrpt_proptype_Fields : PropTypes.shape(bpfrpt_proptype_Fields).isRequired).apply(this, arguments);
    },
    hasError: PropTypes.bool.isRequired,
    id: PropTypes.string.isRequired,
    isCascadingPolicyApplicable: PropTypes.bool,
    isDirty: PropTypes.bool.isRequired,
    onModification: PropTypes.func,
    onSave: PropTypes.func,
    onRemove: PropTypes.func,
    isOpen: PropTypes.bool.isRequired,
    template: function template() {
        return (typeof bpfrpt_proptype_Template === 'function' ? bpfrpt_proptype_Template.isRequired ? bpfrpt_proptype_Template.isRequired : bpfrpt_proptype_Template : PropTypes.shape(bpfrpt_proptype_Template).isRequired).apply(this, arguments);
    }
};


export default Instance;
import { bpfrpt_proptype_CascadePolicyType } from './flowTypes';
import { bpfrpt_proptype_Fields } from './flowTypes';
import { bpfrpt_proptype_FieldValue } from './flowTypes';
import { bpfrpt_proptype_Template } from './flowTypes';
import { bpfrpt_proptype_TemplateField } from './flowTypes';
import { bpfrpt_proptype_JSONPatchOperations } from './flowTypes';
import { bpfrpt_proptype_CascadingPolicyData } from './flowTypes';
import PropTypes from 'prop-types';