var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

import * as React from 'react';
import classNames from 'classnames';
import { FormattedMessage, injectIntl } from 'react-intl';

import DatalistItem from '../../components/datalist-item';
import SelectorDropdown from '../../components/selector-dropdown';
import SearchForm from '../../components/search-form/SearchForm';
import PlainButton from '../../components/plain-button';
import LoadingIndicator from '../../components/loading-indicator';
import { Flyout, Overlay } from '../../components/flyout';

import MenuToggle from '../../components/dropdown-menu/MenuToggle';
import messages from './messages';
import { TEMPLATE_CUSTOM_PROPERTIES } from './constants';

import './TemplateDropdown.scss';

var InputContainer = function InputContainer(_ref) {
    var _ref$inputProps = _ref.inputProps,
        inputProps = _ref$inputProps === undefined ? {} : _ref$inputProps,
        rest = _objectWithoutProperties(_ref, ['inputProps']);

    return React.createElement(SearchForm, _extends({}, inputProps, rest, {
        shouldPreventClearEventPropagation: true,
        'data-resin-target': 'metadata-templatesearch'
    }));
};

InputContainer.propTypes = {
    inputProps: PropTypes.object
};
var getAvailableTemplates = function getAvailableTemplates(allTemplates, usedTemplates) {
    return allTemplates.filter(function (template) {
        return usedTemplates.findIndex(function (usedTemplate) {
            return usedTemplate.templateKey === template.templateKey && usedTemplate.scope === template.scope;
        }) === -1;
    });
};

var TemplateDropdown = function (_React$PureComponent) {
    _inherits(TemplateDropdown, _React$PureComponent);

    function TemplateDropdown(props) {
        _classCallCheck(this, TemplateDropdown);

        var _this = _possibleConstructorReturn(this, (TemplateDropdown.__proto__ || Object.getPrototypeOf(TemplateDropdown)).call(this, props));

        _initialiseProps.call(_this);

        _this.state = {
            isDropdownOpen: false,
            filterText: '',
            templates: getAvailableTemplates(props.templates, props.usedTemplates)
        };
        return _this;
    }

    /**
     * Updates the state
     *
     * @param {Object} nextProps - next props
     * @return {void}
     */


    _createClass(TemplateDropdown, [{
        key: 'componentWillReceiveProps',
        value: function componentWillReceiveProps(nextProps) {
            this.setState({
                templates: getAvailableTemplates(nextProps.templates, nextProps.usedTemplates)
            });
        }

        /**
         * Returns the input field for the drop down
         *
         * @return {React.Node} - input selector
         */

    }, {
        key: 'getTemplateName',


        /**
         * Returns template display name.
         * For custom metadata we have it on the client.
         *
         * @return {React.Node} - string or formatted name
         */
        value: function getTemplateName(template) {
            return template.templateKey === TEMPLATE_CUSTOM_PROPERTIES ? React.createElement(FormattedMessage, _extends({
                className: 'template-display-name'
            }, messages.customTitle)) : React.createElement(
                'div',
                { className: 'template-display-name' },
                template.displayName
            );
        }

        /**
         * Updates the filter text and filters the results
         *
         * @param {UserInput} userInput - input value returned from onChangeHandler from SearchForm.js
         * @return {void}
         */

    }, {
        key: 'render',
        value: function render() {
            var className = this.props.className;

            var flyoutClassName = classNames('metadata-instance-editor-template-dropdown-flyout', className);

            return React.createElement(
                Flyout,
                {
                    className: flyoutClassName,
                    closeOnClick: true,
                    closeOnClickOutside: true,
                    onClose: this.onClose,
                    onOpen: this.onOpen,
                    position: 'bottom-left',
                    shouldDefaultFocus: true
                },
                this.renderEntryButton(),
                React.createElement(
                    Overlay,
                    null,
                    this.getDropdown()
                )
            );
        }
    }]);

    return TemplateDropdown;
}(React.PureComponent);

TemplateDropdown.propTypes = {
    className: PropTypes.string,
    isDropdownBusy: PropTypes.bool,
    intl: function intl(props, propName, componentName) {
        if (!Object.prototype.hasOwnProperty.call(props, propName)) {
            throw new Error('Prop `' + propName + '` has type \'any\' or \'mixed\', but was not provided to `' + componentName + '`. Pass undefined or any other value.');
        }
    },
    title: PropTypes.node,
    entryButton: PropTypes.node,
    onAdd: PropTypes.func.isRequired,
    activeTemplate: function activeTemplate() {
        return (typeof bpfrpt_proptype_Template === 'function' ? bpfrpt_proptype_Template : PropTypes.shape(bpfrpt_proptype_Template)).apply(this, arguments);
    },
    defaultTemplateIcon: PropTypes.node,
    activeTemplateIcon: PropTypes.node,
    templates: PropTypes.arrayOf(function () {
        return (typeof bpfrpt_proptype_Template === 'function' ? bpfrpt_proptype_Template : PropTypes.shape(bpfrpt_proptype_Template)).apply(this, arguments);
    }).isRequired,
    usedTemplates: PropTypes.arrayOf(function () {
        return (typeof bpfrpt_proptype_Template === 'function' ? bpfrpt_proptype_Template : PropTypes.shape(bpfrpt_proptype_Template)).apply(this, arguments);
    }).isRequired
};

var _initialiseProps = function _initialiseProps() {
    var _this2 = this;

    this.getDropdown = function () {
        var _props = _this2.props,
            isDropdownBusy = _props.isDropdownBusy,
            onAdd = _props.onAdd,
            activeTemplate = _props.activeTemplate,
            defaultTemplateIcon = _props.defaultTemplateIcon,
            activeTemplateIcon = _props.activeTemplateIcon,
            allTemplates = _props.templates,
            title = _props.title,
            usedTemplates = _props.usedTemplates;
        var templates = _this2.state.templates;

        var hasUnusedTemplates = getAvailableTemplates(allTemplates, usedTemplates).length > 0;
        var hasTemplates = allTemplates.length > 0;
        var hasResults = templates.length > 0;

        var indicatorOrMessage = null;

        if (isDropdownBusy) {
            indicatorOrMessage = React.createElement(LoadingIndicator, { className: 'metadata-instance-editor-template-message template-dropdown-loading-indicator' });
        } else if (!hasTemplates || !hasUnusedTemplates || !hasResults) {
            var message = { id: '' };

            if (!hasTemplates) {
                message = messages.metadataTemplatesServerHasNoTemplates;
            } else if (!hasUnusedTemplates) {
                message = messages.metadataTemplatesNoRemainingTemplates;
            } else if (!hasResults) {
                message = messages.metadataTemplatesNoResults;
            }

            indicatorOrMessage = React.createElement(
                'i',
                { className: 'metadata-instance-editor-template-message' },
                React.createElement(FormattedMessage, message)
            );
        }

        var renderedTemplates = templates.map(function (template) {
            var isTemplateSelected = activeTemplate && activeTemplate.id === template.id;

            var buttonClassName = classNames('metadata-template-dropdown-select-template', {
                'metadata-template-dropdown-is-selected': isTemplateSelected
            });

            return React.createElement(
                DatalistItem,
                { key: template.id },
                React.createElement(
                    PlainButton,
                    {
                        className: buttonClassName,
                        tabIndex: '-1',
                        type: 'button'
                    },
                    isTemplateSelected ? activeTemplateIcon : defaultTemplateIcon,
                    _this2.getTemplateName(template)
                )
            );
        });

        return React.createElement(
            React.Fragment,
            null,
            React.createElement(
                SelectorDropdown,
                {
                    className: 'metadata-instance-editor-template-dropdown-menu',
                    title: title,
                    isAlwaysOpen: true,
                    onSelect: function onSelect(index) {
                        onAdd(templates[index]);
                    },
                    selector: _this2.getSelector(),
                    shouldScroll: true
                },
                indicatorOrMessage ? null : renderedTemplates
            ),
            indicatorOrMessage
        );
    };

    this.getSelector = function () {
        var intl = _this2.props.intl;
        var filterText = _this2.state.filterText;

        return React.createElement(InputContainer, {
            label: '',
            onChange: _this2.handleUserInput,
            placeholder: intl.formatMessage(messages.metadataTemplateSearchPlaceholder),
            type: 'text',
            useClearButton: true,
            value: filterText
        });
    };

    this.handleUserInput = function (userInput) {
        var _props2 = _this2.props,
            allTemplates = _props2.templates,
            usedTemplates = _props2.usedTemplates;

        var filterText = userInput;
        var templates = getAvailableTemplates(allTemplates, usedTemplates);

        _this2.setState({
            filterText: filterText,
            templates: templates.filter(function (template) {
                var label = template.templateKey === TEMPLATE_CUSTOM_PROPERTIES ? messages.customTitle.defaultMessage : template.displayName;
                return label.toLowerCase().includes(filterText.toLowerCase());
            })
        });
    };

    this.onOpen = function () {
        var _props3 = _this2.props,
            templates = _props3.templates,
            usedTemplates = _props3.usedTemplates;


        _this2.setState({
            isDropdownOpen: true,
            filterText: '',
            templates: getAvailableTemplates(templates, usedTemplates)
        });
    };

    this.onClose = function () {
        _this2.setState({ isDropdownOpen: false });
    };

    this.renderEntryButton = function () {
        var entryButton = _this2.props.entryButton;
        var isDropdownOpen = _this2.state.isDropdownOpen;

        var buttonToggleClassName = classNames('lnk', {
            'is-toggled': isDropdownOpen
        });
        if (entryButton) {
            return entryButton;
        } else {
            return React.createElement(
                PlainButton,
                {
                    'data-resin-target': 'metadata-templateaddmenu',
                    className: buttonToggleClassName,
                    type: 'button'
                },
                React.createElement(
                    MenuToggle,
                    null,
                    React.createElement(FormattedMessage, messages.metadataTemplateAdd)
                )
            );
        }
    };
};

export { TemplateDropdown as TemplateDropdownBase };
export default injectIntl(TemplateDropdown);
import { bpfrpt_proptype_Template } from './flowTypes';
import PropTypes from 'prop-types';