import * as React from 'react';
import { injectIntl } from 'react-intl';

import DatePicker from '../../../components/date-picker';
import { convertISOStringToUTCDate } from '../../../utils/datetime';

import messages from '../messages';
import './DateField.scss';

var DateField = function DateField(_ref) {
    var dataKey = _ref.dataKey,
        dataValue = _ref.dataValue,
        displayName = _ref.displayName,
        description = _ref.description,
        intl = _ref.intl,
        onChange = _ref.onChange,
        onRemove = _ref.onRemove;
    return React.createElement(DatePicker, {
        className: 'metadata-instance-editor-field-date',
        dateFormat: 'utcISOString',
        displayFormat: {
            day: 'numeric',
            month: 'long',
            year: 'numeric'
        },
        description: description,
        hideOptionalLabel: true,
        label: displayName,
        onChange: function (_onChange) {
            function onChange(_x, _x2) {
                return _onChange.apply(this, arguments);
            }

            onChange.toString = function () {
                return _onChange.toString();
            };

            return onChange;
        }(function (date, isoDate) {
            if (isoDate) {
                onChange(dataKey, isoDate);
            } else {
                onRemove(dataKey);
            }
        }),
        placeholder: intl.formatMessage(messages.metadataFieldSetDate),
        value: typeof dataValue === 'string' ? convertISOStringToUTCDate(dataValue) : undefined
    });
};

DateField.propTypes = {
    dataKey: PropTypes.string.isRequired,
    dataValue: function dataValue() {
        return (typeof bpfrpt_proptype_FieldValue === 'function' ? bpfrpt_proptype_FieldValue : PropTypes.shape(bpfrpt_proptype_FieldValue)).apply(this, arguments);
    },
    description: PropTypes.string,
    displayName: PropTypes.string.isRequired,
    intl: function intl(props, propName, componentName) {
        if (!Object.prototype.hasOwnProperty.call(props, propName)) {
            throw new Error('Prop `' + propName + '` has type \'any\' or \'mixed\', but was not provided to `' + componentName + '`. Pass undefined or any other value.');
        }
    },
    onChange: PropTypes.func.isRequired,
    onRemove: PropTypes.func.isRequired
};
export { DateField as DateFieldBase };
export default injectIntl(DateField);
import { bpfrpt_proptype_FieldValue } from '../flowTypes';
import PropTypes from 'prop-types';