var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import * as React from 'react';
import PropTypes from 'prop-types';
import { FormattedMessage, FormattedRelative } from 'react-intl';
import throttle from 'lodash/throttle';
import isEmpty from 'lodash/isEmpty';
import classnames from 'classnames';

import Button from '../../components/button';
import Link from '../../components/link/LinkBase';

import PresenceAvatar from './PresenceAvatar';
import { determineInteractionMessage } from './utils/presenceUtils';
import messages from './messages';

var PresenceDropdown = function (_React$Component) {
    _inherits(PresenceDropdown, _React$Component);

    function PresenceDropdown() {
        var _ref;

        var _temp, _this, _ret;

        _classCallCheck(this, PresenceDropdown);

        for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
            args[_key] = arguments[_key];
        }

        return _ret = (_temp = (_this = _possibleConstructorReturn(this, (_ref = PresenceDropdown.__proto__ || Object.getPrototypeOf(PresenceDropdown)).call.apply(_ref, [this].concat(args))), _this), _this.state = {
            isScrollableAbove: false,
            isScrollableBelow: false
        }, _this.calculateOverflow = function (elem) {
            var isScrollableAbove = elem.scrollTop > 0;
            var isScrollableBelow = elem.scrollTop < elem.scrollHeight - elem.clientHeight;
            return {
                isScrollableAbove: isScrollableAbove,
                isScrollableBelow: isScrollableBelow
            };
        }, _this.handleScroll = function (event) {
            var onScroll = _this.props.onScroll;

            if (_this.elDropdownList) {
                _this.setState(_this.calculateOverflow(_this.elDropdownList));
                if (onScroll) {
                    onScroll(event);
                }
            }
        }, _this.throttledHandleScroll = throttle(_this.handleScroll, 50, {
            leading: true,
            trailing: true
        }), _this.renderTitle = function () {
            return React.createElement(
                'div',
                { className: 'presence-dropdown-title' },
                React.createElement(FormattedMessage, messages.recentActivity)
            );
        }, _this.renderTimestampMessage = function (interactedAt, interactionType) {
            var lastActionMessage = determineInteractionMessage(interactionType, interactedAt);
            if (lastActionMessage) {
                return React.createElement(FormattedMessage, _extends({}, lastActionMessage, {
                    values: {
                        timeAgo: React.createElement(FormattedRelative, { value: interactedAt })
                    }
                }));
            }
            return null;
        }, _this.renderCollabList = function () {
            var collaborators = _this.props.collaborators;

            return collaborators.map(function (collaborator) {
                var avatarUrl = collaborator.avatarUrl,
                    id = collaborator.id,
                    isActive = collaborator.isActive,
                    interactedAt = collaborator.interactedAt,
                    interactionType = collaborator.interactionType,
                    name = collaborator.name,
                    profileUrl = collaborator.profileUrl;


                return React.createElement(
                    'div',
                    { className: 'presence-dropdown-item', key: id },
                    React.createElement(PresenceAvatar, {
                        avatarUrl: avatarUrl,
                        id: id,
                        name: name,
                        isActive: isActive,
                        isDropDownAvatar: true
                    }),
                    React.createElement(
                        'div',
                        { className: 'presence-dropdown-item-info-container' },
                        React.createElement(
                            'div',
                            { className: 'presence-dropdown-item-info-name' },
                            isEmpty(profileUrl) ? React.createElement(
                                'span',
                                null,
                                name
                            ) : React.createElement(
                                Link,
                                { target: '_blank', href: profileUrl },
                                name
                            )
                        ),
                        React.createElement(
                            'div',
                            { className: 'presence-dropdown-item-info-time' },
                            isActive ? React.createElement(FormattedMessage, messages.activeNowText) : _this.renderTimestampMessage(interactedAt, interactionType)
                        )
                    )
                );
            });
        }, _this.renderActions = function () {
            var _this$props = _this.props,
                getLinkCallback = _this$props.getLinkCallback,
                inviteCallback = _this$props.inviteCallback;


            return (getLinkCallback || inviteCallback) && React.createElement(
                'div',
                { className: 'presence-dropdown-actions' },
                React.createElement(
                    'div',
                    null,
                    getLinkCallback && React.createElement(
                        Button,
                        { onClick: getLinkCallback },
                        React.createElement(FormattedMessage, messages.getLinkButtonText)
                    ),
                    inviteCallback && React.createElement(
                        Button,
                        { onClick: inviteCallback },
                        React.createElement(FormattedMessage, messages.inviteButtonText)
                    )
                )
            );
        }, _temp), _possibleConstructorReturn(_this, _ret);
    }

    _createClass(PresenceDropdown, [{
        key: 'componentDidMount',
        value: function componentDidMount() {
            var overflow = this.calculateOverflow(this.elDropdownList);
            // eslint-disable-next-line react/no-did-mount-set-state
            this.setState(overflow);
        }
    }, {
        key: 'componentDidUpdate',
        value: function componentDidUpdate() {
            var overflow = this.calculateOverflow(this.elDropdownList);
            /**
             * recalculate overflow when dropdown is visible and new collabs are added
             * This will not go into an infinite loop because we check for changes in local component state
             */
            if (overflow.isScrollableAbove !== this.state.isScrollableAbove || overflow.isScrollableBelow !== this.state.isScrollableBelow) {
                // eslint-disable-next-line react/no-did-update-set-state
                this.setState(overflow);
            }
        }
    }, {
        key: 'render',
        value: function render() {
            var _this2 = this;

            var _state = this.state,
                isScrollableAbove = _state.isScrollableAbove,
                isScrollableBelow = _state.isScrollableBelow;
            var _props = this.props,
                getLinkCallback = _props.getLinkCallback,
                inviteCallback = _props.inviteCallback;

            var buttonsPresent = getLinkCallback || inviteCallback;

            var dropdownListClasses = classnames('presence-dropdown-list', {
                'dropshadow-list': !buttonsPresent,
                'dropshadow-list-with-buttons': buttonsPresent,
                'is-scrollable-above': isScrollableAbove,
                'is-scrollable-below': isScrollableBelow
            });

            var title = this.renderTitle();
            var collabList = this.renderCollabList();
            var actions = this.renderActions();

            return React.createElement(
                'div',
                { className: 'presence-dropdown' },
                title,
                React.createElement(
                    'div',
                    {
                        className: dropdownListClasses,
                        onScroll: this.throttledHandleScroll,
                        ref: function ref(list) {
                            _this2.elDropdownList = list;
                        }
                    },
                    collabList
                ),
                actions
            );
        }
    }]);

    return PresenceDropdown;
}(React.Component);

PresenceDropdown.propTypes = {
    collaborators: PropTypes.arrayOf(PropTypes.shape({
        /** Url to avatar image. If passed in, component will render the avatar image instead of the initials */
        avatarUrl: PropTypes.string,
        /** Users id */
        id: PropTypes.oneOfType([PropTypes.string, PropTypes.number]),
        isActive: PropTypes.bool,
        /** Unix timestamp of when the user last interacted with the document */
        interactedAt: PropTypes.number,
        /** The type of interaction by the user */
        interactionType: PropTypes.string,
        /** User's full name */
        name: PropTypes.string.isRequired,
        /** Custom Profile URL */
        profileUrl: PropTypes.string
    })).isRequired,
    /* Get Link button callback. also controls visibility of button */
    getLinkCallback: PropTypes.func,
    /* Show Invite button callback. also controls visibility of button */
    inviteCallback: PropTypes.func,
    /* Callback for Dropdown onScroll event */
    onScroll: PropTypes.func
};


export default PresenceDropdown;