import * as React from 'react';

import SingleSelectField from '../../../../components/select-field/SingleSelectField';
import TextInput from '../../../../components/text-input';
import DatePicker from '../../../../components/date-picker';

import messages from '../../messages';
import { VALUE } from '../../constants';

import '../../styles/FilterItem.scss';

var ValueField = function ValueField(_ref) {
    var formatMessage = _ref.formatMessage,
        selectedValue = _ref.selectedValue,
        updateValueField = _ref.updateValueField,
        updateSelectedField = _ref.updateSelectedField,
        valueKey = _ref.valueKey,
        valueOptions = _ref.valueOptions,
        valueType = _ref.valueType;

    switch (valueType) {
        case 'string':
            return React.createElement(
                'div',
                { className: 'filter-dropdown-text-field-container' },
                React.createElement(TextInput, {
                    hideLabel: true,
                    label: 'String input',
                    name: 'string field',
                    onChange: updateValueField,
                    placeholder: 'Enter a string',
                    value: selectedValue || ''
                })
            );
        case 'number':
            return React.createElement(
                'div',
                { className: 'filter-dropdown-text-field-container' },
                React.createElement(TextInput, {
                    hideLabel: true,
                    label: 'Number input',
                    name: 'number field',
                    onChange: updateValueField,
                    placeholder: 'Enter a number',
                    value: selectedValue || ''
                })
            );
        case 'float':
            return React.createElement(
                'div',
                { className: 'filter-dropdown-text-field-container' },
                React.createElement(TextInput, {
                    hideLabel: true,
                    label: 'Float input',
                    name: 'float field',
                    onChange: updateValueField,
                    placeholder: 'Enter a float',
                    value: selectedValue || ''
                })
            );
        case 'date':
            return React.createElement(
                'div',
                { className: 'filter-dropdown-date-field-container' },
                React.createElement(DatePicker, {
                    displayFormat: {
                        day: 'numeric',
                        month: 'long',
                        year: 'numeric'
                    },
                    hideLabel: true,
                    label: 'Date',
                    name: 'datepicker',
                    onChange: updateValueField,
                    placeholder: 'Date',
                    value: valueKey ? new Date(valueKey) : undefined
                })
            );
        case 'enum':
            return React.createElement(SingleSelectField, {
                fieldType: VALUE,
                onChange: updateSelectedField,
                options: valueOptions,
                placeholder: formatMessage(messages.selectValuePlaceholderText),
                selectedValue: selectedValue
            });
        default:
            return null;
    }
};

ValueField.propTypes = {
    formatMessage: PropTypes.func.isRequired,
    selectedValue: PropTypes.oneOfType([PropTypes.string, function () {
        return (typeof Date === 'function' ? PropTypes.instanceOf(Date) : PropTypes.any).apply(this, arguments);
    }, PropTypes.number]),
    updateValueField: PropTypes.func.isRequired,
    updateSelectedField: PropTypes.func.isRequired,
    valueKey: PropTypes.oneOfType([PropTypes.string, function () {
        return (typeof Date === 'function' ? PropTypes.instanceOf(Date) : PropTypes.any).apply(this, arguments);
    }, PropTypes.number]),
    valueOptions: PropTypes.arrayOf(PropTypes.object).isRequired,
    valueType: PropTypes.string.isRequired
};
export default ValueField;
import PropTypes from 'prop-types';