var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import { FormattedMessage } from 'react-intl';

import Tooltip from '../../components/tooltip';
import { Menu, MenuItem } from '../../components/menu';
import IconSharedLink from '../../icons/general/IconSharedLink';
import IconInviteCollaborators from '../../icons/general/IconInviteCollaborators';
import IconCollaboratorsRestricted from '../../icons/general/IconCollaboratorsRestricted';
import IconSharedLinkRestricted from '../../icons/general/IconSharedLinkRestricted';

import messages from './messages';

import './ShareMenu.scss';

var OWNER_COOWNER_ONLY = 'owner_coowner_only';
var INSUFFICIENT_PERMISSIONS = 'insufficient_permissions';

var ShareMenu = function ShareMenu(_ref) {
    var canInvite = _ref.canInvite,
        canShare = _ref.canShare,
        _ref$className = _ref.className,
        className = _ref$className === undefined ? '' : _ref$className,
        _ref$getSharedLinkPro = _ref.getSharedLinkProps,
        getSharedLinkProps = _ref$getSharedLinkPro === undefined ? {} : _ref$getSharedLinkPro,
        _ref$inviteCollabsPro = _ref.inviteCollabsProps,
        inviteCollabsProps = _ref$inviteCollabsPro === undefined ? {} : _ref$inviteCollabsPro,
        inviteRestrictionCode = _ref.inviteRestrictionCode,
        isDownloadAllowed = _ref.isDownloadAllowed,
        isPreviewAllowed = _ref.isPreviewAllowed,
        onGetSharedLinkSelect = _ref.onGetSharedLinkSelect,
        onInviteCollabSelect = _ref.onInviteCollabSelect,
        rest = _objectWithoutProperties(_ref, ['canInvite', 'canShare', 'className', 'getSharedLinkProps', 'inviteCollabsProps', 'inviteRestrictionCode', 'isDownloadAllowed', 'isPreviewAllowed', 'onGetSharedLinkSelect', 'onInviteCollabSelect']);

    var inviteCollabsOption = React.createElement(
        MenuItem,
        _extends({
            className: 'invite-collaborators',
            isDisabled: !canInvite,
            onClick: onInviteCollabSelect
        }, inviteCollabsProps),
        canInvite ? React.createElement(IconInviteCollaborators, null) : React.createElement(IconCollaboratorsRestricted, null),
        React.createElement(
            'div',
            null,
            React.createElement(
                'div',
                null,
                React.createElement(FormattedMessage, messages.inviteCollabs)
            ),
            React.createElement(
                'div',
                { className: 'share-option-description' },
                React.createElement(FormattedMessage, messages.editAndComment)
            )
        )
    );

    var inviteCollabTooltip = inviteRestrictionCode === OWNER_COOWNER_ONLY ? React.createElement(FormattedMessage, messages.ownerCoownerOnlyTooltip) : React.createElement(FormattedMessage, messages.insufficientPermissionsTooltip);

    var sharedLinkPermissions = void 0;

    if (isDownloadAllowed && isPreviewAllowed) {
        sharedLinkPermissions = React.createElement(FormattedMessage, messages.viewAndDownload);
    } else if (isPreviewAllowed) {
        sharedLinkPermissions = React.createElement(FormattedMessage, messages.viewOnly);
    } else if (isDownloadAllowed) {
        sharedLinkPermissions = React.createElement(FormattedMessage, messages.downloadOnly);
    } else {
        sharedLinkPermissions = React.createElement(FormattedMessage, messages.shortcutOnly);
    }

    return React.createElement(
        Menu,
        _extends({ className: 'share-menu ' + className }, rest),
        canInvite ? inviteCollabsOption : React.createElement(
            Tooltip,
            { text: inviteCollabTooltip, position: 'middle-left' },
            inviteCollabsOption
        ),
        React.createElement(
            MenuItem,
            _extends({
                className: 'get-shared-link',
                isDisabled: !canShare,
                onClick: onGetSharedLinkSelect
            }, getSharedLinkProps),
            canShare ? React.createElement(IconSharedLink, null) : React.createElement(IconSharedLinkRestricted, null),
            React.createElement(
                'div',
                null,
                React.createElement(
                    'div',
                    null,
                    React.createElement(FormattedMessage, messages.getSharedLink)
                ),
                React.createElement(
                    'div',
                    { className: 'share-option-description' },
                    sharedLinkPermissions
                )
            )
        )
    );
};

ShareMenu.propTypes = {
    canInvite: PropTypes.bool.isRequired,
    canShare: PropTypes.bool.isRequired,
    className: PropTypes.string,
    getSharedLinkProps: PropTypes.object,
    inviteCollabsProps: PropTypes.object,
    inviteRestrictionCode: PropTypes.oneOf([INSUFFICIENT_PERMISSIONS, OWNER_COOWNER_ONLY]),
    isDownloadAllowed: PropTypes.bool.isRequired,
    isPreviewAllowed: PropTypes.bool.isRequired,
    onGetSharedLinkSelect: PropTypes.func.isRequired,
    onInviteCollabSelect: PropTypes.func.isRequired
};

export { OWNER_COOWNER_ONLY, INSUFFICIENT_PERMISSIONS };
export default ShareMenu;