var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';
import classNames from 'classnames';
import { FormattedMessage } from 'react-intl';

import PlainButton from '../../components/plain-button';
import DropdownMenu, { MenuToggle } from '../../components/dropdown-menu';
import { Menu, MenuSeparator, MenuSectionHeader, SelectMenuItem } from '../../components/menu';

import messages from './messages';
import { PEOPLE_WITH_LINK, PEOPLE_IN_COMPANY, PEOPLE_IN_ITEM } from './constants';
import { accessLevelPropType, allowedAccessLevelsPropType } from './propTypes';
import AccessLabel from './AccessLabel';
import RemoveLinkConfirmModal from './RemoveLinkConfirmModal';

var accessLevels = [PEOPLE_WITH_LINK, PEOPLE_IN_COMPANY, PEOPLE_IN_ITEM];

var AccessMenu = function (_Component) {
    _inherits(AccessMenu, _Component);

    function AccessMenu() {
        var _ref;

        var _temp, _this, _ret;

        _classCallCheck(this, AccessMenu);

        for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
            args[_key] = arguments[_key];
        }

        return _ret = (_temp = (_this = _possibleConstructorReturn(this, (_ref = AccessMenu.__proto__ || Object.getPrototypeOf(AccessMenu)).call.apply(_ref, [this].concat(args))), _this), _this.state = {
            isConfirmModalOpen: false
        }, _this.openConfirmModal = function () {
            _this.setState({ isConfirmModalOpen: true });
        }, _this.closeConfirmModal = function () {
            _this.setState({ isConfirmModalOpen: false });
        }, _temp), _possibleConstructorReturn(_this, _ret);
    }

    _createClass(AccessMenu, [{
        key: 'renderMenu',
        value: function renderMenu() {
            var _props = this.props,
                accessLevel = _props.accessLevel,
                allowedAccessLevels = _props.allowedAccessLevels,
                canRemoveLink = _props.canRemoveLink,
                changeAccessLevel = _props.changeAccessLevel,
                enterpriseName = _props.enterpriseName,
                itemType = _props.itemType,
                removeLinkButtonProps = _props.removeLinkButtonProps;


            return React.createElement(
                Menu,
                { className: 'share-access-menu' },
                React.createElement(
                    MenuSectionHeader,
                    null,
                    React.createElement(FormattedMessage, messages.accessTypeTitle)
                ),
                accessLevels.map(function (level) {
                    return allowedAccessLevels[level] ? React.createElement(
                        SelectMenuItem,
                        {
                            onClick: function onClick() {
                                return changeAccessLevel(level);
                            },
                            isSelected: level === accessLevel,
                            key: level
                        },
                        React.createElement(AccessLabel, {
                            accessLevel: level,
                            enterpriseName: enterpriseName,
                            itemType: itemType
                        })
                    ) : null;
                }),
                canRemoveLink && React.createElement(MenuSeparator, null),
                canRemoveLink && React.createElement(
                    SelectMenuItem,
                    _extends({
                        onClick: this.openConfirmModal
                    }, removeLinkButtonProps),
                    React.createElement(FormattedMessage, messages.removeLink)
                )
            );
        }
    }, {
        key: 'render',
        value: function render() {
            var _props2 = this.props,
                accessDropdownMenuProps = _props2.accessDropdownMenuProps,
                accessLevel = _props2.accessLevel,
                accessMenuButtonProps = _props2.accessMenuButtonProps,
                enterpriseName = _props2.enterpriseName,
                itemType = _props2.itemType,
                removeLink = _props2.removeLink,
                submitting = _props2.submitting;
            var isConfirmModalOpen = this.state.isConfirmModalOpen;


            return React.createElement(
                'span',
                null,
                React.createElement(
                    DropdownMenu,
                    accessDropdownMenuProps,
                    React.createElement(
                        PlainButton,
                        _extends({
                            className: classNames('lnk', {
                                'is-disabled': submitting
                            }),
                            disabled: submitting
                        }, accessMenuButtonProps),
                        React.createElement(
                            MenuToggle,
                            null,
                            React.createElement(AccessLabel, {
                                accessLevel: accessLevel,
                                enterpriseName: enterpriseName,
                                itemType: itemType
                            })
                        )
                    ),
                    this.renderMenu()
                ),
                React.createElement(RemoveLinkConfirmModal, {
                    isOpen: isConfirmModalOpen,
                    onRequestClose: this.closeConfirmModal,
                    removeLink: removeLink,
                    submitting: submitting
                })
            );
        }
    }]);

    return AccessMenu;
}(Component);

AccessMenu.defaultProps = {
    accessDropdownMenuProps: {},
    accessMenuButtonProps: {},
    removeLinkButtonProps: {}
};
AccessMenu.propTypes = {
    accessDropdownMenuProps: PropTypes.object,
    accessLevel: function accessLevel() {
        return (typeof accessLevelPropType === 'function' ? PropTypes.instanceOf(accessLevelPropType).isRequired : PropTypes.any.isRequired).apply(this, arguments);
    },
    accessMenuButtonProps: PropTypes.object,
    allowedAccessLevels: function allowedAccessLevels() {
        return (typeof allowedAccessLevelsPropType === 'function' ? PropTypes.instanceOf(allowedAccessLevelsPropType).isRequired : PropTypes.any.isRequired).apply(this, arguments);
    },
    canRemoveLink: PropTypes.bool,
    changeAccessLevel: PropTypes.func.isRequired,
    enterpriseName: PropTypes.string,
    itemType: PropTypes.string.isRequired,
    removeLink: PropTypes.func.isRequired,
    removeLinkButtonProps: PropTypes.object,
    submitting: PropTypes.bool
};


export default AccessMenu;
import PropTypes from 'prop-types';