var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } else { return Array.from(arr); } }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import classNames from 'classnames';
import { FormattedMessage, injectIntl, intlShape } from 'react-intl';

import PillSelectorDropdown from '../../components/pill-selector-dropdown';
import ContactDatalistItem from '../../components/contact-datalist-item';
import TextArea from '../../components/text-area';
import PrimaryButton from '../../components/primary-button';
import { ModalActions } from '../../components/modal';
import Button from '../../components/button';
import commonMessages from '../../common/messages';
import parseEmails from '../../utils/parseEmails';

import messages from './messages';

import './EmailSharedLink.scss';

var EmailSharedLink = function (_Component) {
    _inherits(EmailSharedLink, _Component);

    function EmailSharedLink(props) {
        _classCallCheck(this, EmailSharedLink);

        var _this = _possibleConstructorReturn(this, (EmailSharedLink.__proto__ || Object.getPrototypeOf(EmailSharedLink)).call(this, props));

        _this.getSelectorOptions = function () {
            var contacts = _this.props.contacts;
            var _this$state = _this.state,
                pillSelectorInputValue = _this$state.pillSelectorInputValue,
                selectedOptions = _this$state.selectedOptions;


            if (pillSelectorInputValue !== '') {
                return contacts.filter(
                // filter contacts who have already been selected
                function (_ref) {
                    var email = _ref.email,
                        id = _ref.id;
                    return !selectedOptions.find(function (_ref2) {
                        var value = _ref2.value;
                        return value === email || value === id;
                    });
                }).map(function (_ref3) {
                    var email = _ref3.email,
                        id = _ref3.id,
                        name = _ref3.name,
                        type = _ref3.type;
                    return {
                        // map to standardized DatalistItem format
                        email: email,
                        id: id,
                        text: name,
                        type: type,
                        value: email
                    };
                });
            }

            // return empty selector options if input value is empty
            return [];
        };

        _this.handlePillSelectorInput = function (value) {
            var getContacts = _this.props.getContacts;


            var trimmedValue = value.trim();

            getContacts(trimmedValue);

            // As user is typing, reset error
            _this.setState({
                pillSelectorError: '',
                pillSelectorInputValue: trimmedValue
            });
        };

        _this.handlePillSelect = function (pills) {
            _this.setState({
                selectedOptions: [].concat(_toConsumableArray(_this.state.selectedOptions), _toConsumableArray(pills))
            });
        };

        _this.handlePillRemove = function (option, index) {
            var selectedOptions = _this.state.selectedOptions.slice();
            selectedOptions.splice(index, 1);
            _this.setState({ selectedOptions: selectedOptions });
        };

        _this.validateForError = function (text) {
            var formatMessage = _this.props.intl.formatMessage;

            var pillSelectorError = '';

            if (text && !_this.validator(text)) {
                pillSelectorError = formatMessage(commonMessages.invalidEmailError);
            }

            _this.setState({ pillSelectorError: pillSelectorError });
        };

        _this.validator = function (text) {
            // email input validation
            var pattern = /^[^\s<>@,]+@[^\s<>@,/\\]+\.[^\s<>@,]+$/i;
            return pattern.test(text);
        };

        _this.sendEmail = function (event) {
            event.preventDefault();

            var _this$props = _this.props,
                formatMessage = _this$props.intl.formatMessage,
                sendEmail = _this$props.sendEmail;
            var _this$state2 = _this.state,
                selectedOptions = _this$state2.selectedOptions,
                emailMessage = _this$state2.emailMessage,
                pillSelectorError = _this$state2.pillSelectorError;


            if (pillSelectorError !== '') {
                return;
            }

            if (selectedOptions.length === 0) {
                // Block submission if no pills are selected
                _this.setState({
                    pillSelectorError: formatMessage(messages.enterAtLeastOneEmailError)
                });
                return;
            }

            sendEmail({
                emails: selectedOptions.map(function (_ref4) {
                    var value = _ref4.value;
                    return value;
                }),
                emailMessage: emailMessage
            });
        };

        _this.handleMessageChange = function (event) {
            _this.setState({ emailMessage: event.target.value });
        };

        var defaultEmailMessage = props.defaultEmailMessage;


        _this.state = {
            pillSelectorError: '',
            pillSelectorInputValue: '',
            emailMessage: defaultEmailMessage || '',
            selectedOptions: []
        };
        return _this;
    }

    _createClass(EmailSharedLink, [{
        key: 'render',
        value: function render() {
            var _state = this.state,
                pillSelectorError = _state.pillSelectorError,
                selectedOptions = _state.selectedOptions,
                emailMessage = _state.emailMessage;
            var _props = this.props,
                emailMessageProps = _props.emailMessageProps,
                formatMessage = _props.intl.formatMessage,
                isExpanded = _props.isExpanded,
                onExpand = _props.onExpand,
                onRequestClose = _props.onRequestClose,
                submitting = _props.submitting;


            var selectorOptions = this.getSelectorOptions();

            return React.createElement(
                'form',
                {
                    onSubmit: this.sendEmail,
                    className: classNames('email-shared-link', {
                        'is-expanded': isExpanded
                    })
                },
                React.createElement(
                    PillSelectorDropdown,
                    {
                        allowCustomPills: true,
                        error: pillSelectorError,
                        label: React.createElement(FormattedMessage, messages.emailSharedLink),
                        inputProps: _extends({ onFocus: onExpand }, emailMessageProps),
                        onInput: this.handlePillSelectorInput,
                        onRemove: this.handlePillRemove,
                        onSelect: this.handlePillSelect,
                        parseItems: parseEmails,
                        placeholder: formatMessage(commonMessages.pillSelectorPlaceholder),
                        selectedOptions: selectedOptions,
                        selectorOptions: selectorOptions,
                        validateForError: this.validateForError,
                        validator: this.validator
                    },
                    selectorOptions.map(function (_ref5) {
                        var email = _ref5.email,
                            text = _ref5.text,
                            value = _ref5.value;
                        return React.createElement(ContactDatalistItem, {
                            key: value,
                            name: text,
                            subtitle: email
                        });
                    })
                ),
                React.createElement(TextArea, {
                    isRequired: true,
                    label: React.createElement(FormattedMessage, messages.messageTitle),
                    onChange: this.handleMessageChange,
                    rows: 3,
                    value: emailMessage
                }),
                isExpanded && React.createElement(
                    ModalActions,
                    null,
                    React.createElement(
                        Button,
                        {
                            isDisabled: submitting,
                            onClick: onRequestClose,
                            type: 'button'
                        },
                        React.createElement(FormattedMessage, commonMessages.cancel)
                    ),
                    React.createElement(
                        PrimaryButton,
                        {
                            isDisabled: submitting,
                            isLoading: submitting,
                            type: 'submit'
                        },
                        React.createElement(FormattedMessage, commonMessages.send)
                    )
                )
            );
        }
    }]);

    return EmailSharedLink;
}(Component);

EmailSharedLink.propTypes = {
    contacts: PropTypes.arrayOf(PropTypes.shape({
        email: PropTypes.string,
        id: PropTypes.oneOfType([PropTypes.number, PropTypes.string]).isrequired,
        name: PropTypes.string.isRequired,
        type: PropTypes.string.isRequired
    })).isRequired,
    defaultEmailMessage: PropTypes.string,
    emailMessageProps: PropTypes.object,
    intl: intlShape.isRequired,
    getContacts: PropTypes.func.isRequired,
    isExpanded: PropTypes.bool,
    onExpand: PropTypes.func.isRequired,
    onRequestClose: PropTypes.func.isRequired,
    sendEmail: PropTypes.func.isRequired,
    submitting: PropTypes.bool
};
EmailSharedLink.defaultProps = {
    emailMessageProps: {}
};


export { EmailSharedLink as EmailSharedLinkBase };
export default injectIntl(EmailSharedLink);