import React from 'react';

import AccessDescription from './AccessDescription';
import AccessMenu from './AccessMenu';
import PermissionMenu from './PermissionMenu';

import { accessLevelPropType, allowedAccessLevelsPropType, permissionLevelPropType } from './propTypes';

var SharedLinkAccess = function SharedLinkAccess(props) {
    var accessDropdownMenuProps = props.accessDropdownMenuProps,
        accessLevel = props.accessLevel,
        accessMenuButtonProps = props.accessMenuButtonProps,
        allowedAccessLevels = props.allowedAccessLevels,
        canRemoveLink = props.canRemoveLink,
        changeAccessLevel = props.changeAccessLevel,
        changePermissionLevel = props.changePermissionLevel,
        enterpriseName = props.enterpriseName,
        isDownloadAllowed = props.isDownloadAllowed,
        isEditAllowed = props.isEditAllowed,
        isPreviewAllowed = props.isPreviewAllowed,
        itemType = props.itemType,
        permissionLevel = props.permissionLevel,
        removeLink = props.removeLink,
        removeLinkButtonProps = props.removeLinkButtonProps,
        submitting = props.submitting;


    return React.createElement(
        'div',
        { className: 'shared-link-access' },
        React.createElement(AccessDescription, {
            accessLevel: accessLevel,
            enterpriseName: enterpriseName,
            isDownloadAllowed: isDownloadAllowed,
            isEditAllowed: isEditAllowed,
            isPreviewAllowed: isPreviewAllowed,
            itemType: itemType
        }),
        React.createElement(AccessMenu, {
            accessDropdownMenuProps: accessDropdownMenuProps,
            accessLevel: accessLevel,
            accessMenuButtonProps: accessMenuButtonProps,
            allowedAccessLevels: allowedAccessLevels,
            canRemoveLink: canRemoveLink,
            changeAccessLevel: changeAccessLevel,
            enterpriseName: enterpriseName,
            isDownloadAllowed: isDownloadAllowed,
            isEditAllowed: isEditAllowed,
            isPreviewAllowed: isPreviewAllowed,
            itemType: itemType,
            removeLink: removeLink,
            removeLinkButtonProps: removeLinkButtonProps,
            submitting: submitting
        }),
        React.createElement(PermissionMenu, {
            changePermissionLevel: changePermissionLevel,
            permissionLevel: permissionLevel,
            submitting: submitting
        })
    );
};

SharedLinkAccess.propTypes = {
    accessDropdownMenuProps: PropTypes.object,
    accessLevel: function accessLevel() {
        return (typeof accessLevelPropType === 'function' ? PropTypes.instanceOf(accessLevelPropType) : PropTypes.any).apply(this, arguments);
    },
    accessMenuButtonProps: PropTypes.object,
    allowedAccessLevels: function allowedAccessLevels() {
        return (typeof allowedAccessLevelsPropType === 'function' ? PropTypes.instanceOf(allowedAccessLevelsPropType) : PropTypes.any).apply(this, arguments);
    },
    canRemoveLink: PropTypes.bool,
    changeAccessLevel: PropTypes.func.isRequired,
    changePermissionLevel: PropTypes.func,
    enterpriseName: PropTypes.string,
    isDownloadAllowed: PropTypes.bool,
    isEditAllowed: PropTypes.bool,
    isPreviewAllowed: PropTypes.bool,
    itemType: PropTypes.string.isRequired,
    permissionLevel: function permissionLevel() {
        return (typeof permissionLevelPropType === 'function' ? PropTypes.instanceOf(permissionLevelPropType) : PropTypes.any).apply(this, arguments);
    },
    removeLink: PropTypes.func.isRequired,
    removeLinkButtonProps: PropTypes.object,
    submitting: PropTypes.bool
};
export default SharedLinkAccess;
import PropTypes from 'prop-types';