var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

import React from 'react';
import PropTypes from 'prop-types';
import { FormattedMessage } from 'react-intl';

import Checkbox from '../../components/checkbox';
import TextInputWithCopyButton from '../../components/text-input-with-copy-button';
import Fieldset from '../../components/fieldset';

import messages from './messages';

var AllowDownloadSection = function AllowDownloadSection(_ref) {
    var canChangeDownload = _ref.canChangeDownload,
        directLink = _ref.directLink,
        _ref$directLinkInputP = _ref.directLinkInputProps,
        directLinkInputProps = _ref$directLinkInputP === undefined ? {} : _ref$directLinkInputP,
        _ref$downloadCheckbox = _ref.downloadCheckboxProps,
        downloadCheckboxProps = _ref$downloadCheckbox === undefined ? {} : _ref$downloadCheckbox,
        isDirectLinkAvailable = _ref.isDirectLinkAvailable,
        isDirectLinkUnavailableDueToDownloadSettings = _ref.isDirectLinkUnavailableDueToDownloadSettings,
        isDownloadAvailable = _ref.isDownloadAvailable,
        isDownloadEnabled = _ref.isDownloadEnabled,
        onChange = _ref.onChange;

    if (!isDownloadAvailable && !isDirectLinkAvailable) {
        return null;
    }

    var directLinkSection = React.createElement(
        'div',
        null,
        React.createElement(TextInputWithCopyButton, _extends({
            className: 'direct-link-input',
            label: React.createElement(FormattedMessage, messages.directLinkLabel),
            type: 'url',
            value: directLink
        }, directLinkInputProps))
    );

    if (isDownloadAvailable) {
        return React.createElement(
            'div',
            null,
            React.createElement('hr', null),
            React.createElement(
                Fieldset,
                {
                    title: React.createElement(FormattedMessage, messages.allowDownloadTitle)
                },
                React.createElement(Checkbox, _extends({
                    isChecked: isDownloadEnabled,
                    isDisabled: !canChangeDownload,
                    label: React.createElement(FormattedMessage, messages.allowDownloadLabel),
                    name: 'isDownloadEnabled',
                    onChange: onChange
                }, downloadCheckboxProps)),
                (isDirectLinkAvailable || isDirectLinkUnavailableDueToDownloadSettings) && isDownloadEnabled ? directLinkSection : null
            )
        );
    }

    // When download section not available but direct link is available
    return React.createElement(
        'div',
        null,
        React.createElement('hr', null),
        directLinkSection
    );
};

AllowDownloadSection.propTypes = {
    canChangeDownload: PropTypes.bool.isRequired,
    directLink: PropTypes.string.isRequired,
    directLinkInputProps: PropTypes.object,
    downloadCheckboxProps: PropTypes.object,
    isDirectLinkAvailable: PropTypes.bool.isRequired,
    isDirectLinkUnavailableDueToDownloadSettings: PropTypes.bool.isRequired,
    isDownloadAvailable: PropTypes.bool.isRequired,
    isDownloadEnabled: PropTypes.bool.isRequired,
    onChange: PropTypes.func.isRequired
};

export default AllowDownloadSection;