'no babel-plugin-flow-react-proptypes'; // turn off this plugin because it breaks the IntlShape flow type

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import * as React from 'react';
import { FormattedMessage, injectIntl } from 'react-intl';

import debounce from 'lodash/debounce';
import noop from 'lodash/noop';
import classNames from 'classnames';

import PillSelectorDropdown from '../../components/pill-selector-dropdown';
import ContactDatalistItem from '../../components/contact-datalist-item';
import commonMessages from '../../common/messages';
import parseEmails from '../../utils/parseEmails';

import messages from './messages';


var isSubstring = function isSubstring(value, searchString) {
    return value && value.toLowerCase().indexOf(searchString.toLowerCase()) !== -1;
};

var ContactsField = function (_React$Component) {
    _inherits(ContactsField, _React$Component);

    function ContactsField(props) {
        _classCallCheck(this, ContactsField);

        var _this = _possibleConstructorReturn(this, (ContactsField.__proto__ || Object.getPrototypeOf(ContactsField)).call(this, props));

        _this.filterContacts = function (contacts) {
            var pillSelectorInputValue = _this.state.pillSelectorInputValue;
            var selectedContacts = _this.props.selectedContacts;


            if (pillSelectorInputValue && contacts) {
                return contacts.filter(
                // filter contacts whose name or email don't match input value
                function (_ref) {
                    var name = _ref.name,
                        email = _ref.email;
                    return isSubstring(name, pillSelectorInputValue) || isSubstring(email, pillSelectorInputValue);
                }).filter(
                // filter contacts who have already been selected
                function (_ref2) {
                    var email = _ref2.email,
                        id = _ref2.id;
                    return !selectedContacts.find(function (_ref3) {
                        var value = _ref3.value;
                        return value === email || value === id;
                    });
                }).map(function (_ref4) {
                    var email = _ref4.email,
                        id = _ref4.id,
                        name = _ref4.name,
                        type = _ref4.type;
                    return {
                        // map to standardized DatalistItem format
                        email: email,
                        id: id,
                        text: name,
                        type: type,
                        value: email || id // if email doesn't exist, contact is a group, use id
                    };
                });
            }

            // return empty selector options if input value is empty
            return [];
        };

        _this.getContactsPromise = function (query) {
            return _this.props.getContacts(query).then(function (contacts) {
                var filteredContacts = _this.filterContacts(contacts);
                _this.setState({ contacts: filteredContacts });
            }).catch(function (error) {
                if (error.isCanceled) {
                    // silently fail - this happens often when requests get cancelled
                    // due to overlapping requests
                    return;
                }
                throw error;
            });
        };

        _this.debouncedGetContacts = debounce(_this.getContactsPromise, 200);

        _this.handlePillSelectorInput = function (value) {
            var onInput = _this.props.onInput;

            var trimmedValue = value.trim();

            _this.setState({
                pillSelectorInputValue: trimmedValue
            });

            if (onInput) {
                onInput(value);
            }

            if (!trimmedValue) {
                _this.setState({ contacts: [] });
                return;
            }

            _this.debouncedGetContacts(trimmedValue);
        };

        _this.state = {
            contacts: [],
            pillSelectorInputValue: ''
        };
        return _this;
    }

    _createClass(ContactsField, [{
        key: 'render',
        value: function render() {
            var _props = this.props,
                intl = _props.intl,
                disabled = _props.disabled,
                error = _props.error,
                fieldRef = _props.fieldRef,
                label = _props.label,
                selectedContacts = _props.selectedContacts,
                onContactAdd = _props.onContactAdd,
                onContactRemove = _props.onContactRemove,
                validateForError = _props.validateForError,
                validator = _props.validator;
            var contacts = this.state.contacts;

            var groupLabel = React.createElement(FormattedMessage, messages.groupLabel);
            var pillSelectorOverlayClasses = classNames({
                scrollable: contacts.length > 5
            });

            return React.createElement(
                PillSelectorDropdown,
                {
                    allowCustomPills: true,
                    className: pillSelectorOverlayClasses,
                    disabled: disabled,
                    error: error,
                    inputProps: {
                        autoFocus: true,
                        onChange: noop
                    },
                    label: label,
                    onInput: this.handlePillSelectorInput,
                    onRemove: onContactRemove,
                    onSelect: onContactAdd,
                    parseItems: parseEmails,
                    placeholder: intl.formatMessage(commonMessages.pillSelectorPlaceholder),
                    ref: fieldRef,
                    selectedOptions: selectedContacts,
                    selectorOptions: contacts,
                    validateForError: validateForError,
                    validator: validator
                },
                contacts.map(function (_ref5) {
                    var email = _ref5.email,
                        text = _ref5.text,
                        id = _ref5.id;
                    return React.createElement(ContactDatalistItem, {
                        key: id,
                        name: text,
                        subtitle: email || groupLabel
                    });
                })
            );
        }
    }]);

    return ContactsField;
}(React.Component);

export { ContactsField as ContactsFieldBase };
export default injectIntl(ContactsField);