'no babel-plugin-flow-react-proptypes'; // this plugin breaks the IntlShape type

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } else { return Array.from(arr); } }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import * as React from 'react';
import classNames from 'classnames';
import { FormattedMessage, injectIntl } from 'react-intl';


import TextArea from '../../components/text-area';
import PrimaryButton from '../../components/primary-button';
import { ModalActions } from '../../components/modal';
import Button from '../../components/button';
import Tooltip from '../../components/tooltip';
import InlineNotice from '../../components/inline-notice';
import commonMessages from '../../common/messages';
import PillSelectorDropdown from '../../components/pill-selector-dropdown';


import ContactsField from './ContactsField';
import messages from './messages';

var EmailForm = function (_React$Component) {
    _inherits(EmailForm, _React$Component);

    function EmailForm(props) {
        _classCallCheck(this, EmailForm);

        var _this = _possibleConstructorReturn(this, (EmailForm.__proto__ || Object.getPrototypeOf(EmailForm)).call(this, props));

        _this.contactsFieldRef = React.createRef();

        _this.handleContactAdd = function (contacts) {
            var _this$props = _this.props,
                onContactAdd = _this$props.onContactAdd,
                updateSelectedContacts = _this$props.updateSelectedContacts;


            updateSelectedContacts([].concat(_toConsumableArray(_this.props.selectedContacts), _toConsumableArray(contacts)));

            if (onContactAdd) {
                onContactAdd(contacts);
            }
        };

        _this.handleContactRemove = function (option, index) {
            var _this$props2 = _this.props,
                onContactRemove = _this$props2.onContactRemove,
                updateSelectedContacts = _this$props2.updateSelectedContacts;

            var selectedContacts = _this.props.selectedContacts.slice();
            var removed = selectedContacts.splice(index, 1);
            updateSelectedContacts(selectedContacts);

            if (onContactRemove) {
                onContactRemove(removed);
            }
        };

        _this.handleContactInput = function (value) {
            var onContactInput = _this.props.onContactInput;

            // As user is typing, reset error

            _this.setState({ contactsFieldError: '' });
            if (onContactInput) {
                onContactInput(value);
            }
        };

        _this.handleMessageChange = function (event) {
            var target = event.target;


            if (target instanceof HTMLTextAreaElement) {
                _this.setState({ message: target.value });
            }
        };

        _this.handleClose = function () {
            _this.setState({
                message: '',
                contactsFieldError: ''
            });

            _this.props.updateSelectedContacts([]);

            /* Need to reset text in contacts field upon cancelling
               because the field still shows if the field isn't unmounted
               but only collapsed (like in invite collabs usage).
               inputValue doesn't get passed down through props but is
               internal state in pill selector. */
            if (_this.contactsFieldRef.current) {
                _this.contactsFieldRef.current.setState({ inputValue: '' });
            }

            _this.props.onRequestClose();
        };

        _this.handleSubmit = function (event) {
            event.preventDefault();

            var _this$props3 = _this.props,
                formatMessage = _this$props3.intl.formatMessage,
                onSubmit = _this$props3.onSubmit,
                selectedContacts = _this$props3.selectedContacts;
            var _this$state = _this.state,
                message = _this$state.message,
                contactsFieldError = _this$state.contactsFieldError;


            if (contactsFieldError !== '') {
                // Block submission if there's a validation error
                return;
            }

            if (selectedContacts.length === 0) {
                // Block submission if no pills are selected
                _this.setState({
                    contactsFieldError: formatMessage(messages.enterAtLeastOneEmailError)
                });
                return;
            }

            var emails = [];
            var groupIDs = [];

            selectedContacts.forEach(function (_ref) {
                var type = _ref.type,
                    value = _ref.value;

                if (type === 'group') {
                    groupIDs.push(value);
                } else {
                    emails.push(value);
                }
            });
            onSubmit({
                emails: emails,
                groupIDs: groupIDs,
                message: message
            }).catch(function (error) {
                // Remove sent emails from selected pills
                var invitedEmails = error.invitedEmails || [];
                _this.filterSentEmails(invitedEmails);
            });
        };

        _this.filterSentEmails = function (sentEmails) {
            _this.props.updateSelectedContacts(_this.props.selectedContacts.filter(function (_ref2) {
                var value = _ref2.value;
                return !sentEmails.includes(value);
            }));
        };

        _this.validateContactField = function (text) {
            var intl = _this.props.intl;

            var contactsFieldError = '';

            if (text && !_this.isValidEmail(text)) {
                contactsFieldError = intl.formatMessage(commonMessages.invalidEmailError);
            }
            _this.setState({ contactsFieldError: contactsFieldError });
        };

        _this.isValidEmail = function (text) {
            // TODO-AH: make this a constant somewhere
            var emailValidation = /^[^\s<>@,]+@[^\s<>@,/\\]+\.[^\s<>@,]+$/i;
            return emailValidation.test(text);
        };

        _this.state = {
            contactsFieldError: '',
            message: ''
        };
        return _this;
    }

    _createClass(EmailForm, [{
        key: 'render',
        value: function render() {
            var _state = this.state,
                contactsFieldError = _state.contactsFieldError,
                message = _state.message;
            var _props = this.props,
                cancelButtonProps = _props.cancelButtonProps,
                children = _props.children,
                contactsFieldAvatars = _props.contactsFieldAvatars,
                contactsFieldDisabledTooltip = _props.contactsFieldDisabledTooltip,
                contactsFieldLabel = _props.contactsFieldLabel,
                inlineNotice = _props.inlineNotice,
                isContactsFieldEnabled = _props.isContactsFieldEnabled,
                getContacts = _props.getContacts,
                intl = _props.intl,
                isExpanded = _props.isExpanded,
                messageProps = _props.messageProps,
                sendButtonProps = _props.sendButtonProps,
                showEnterEmailsCallout = _props.showEnterEmailsCallout,
                selectedContacts = _props.selectedContacts,
                submitting = _props.submitting;


            var contactsField = React.createElement(
                'div',
                { className: 'tooltip-target' },
                React.createElement(
                    Tooltip,
                    {
                        isShown: showEnterEmailsCallout,
                        position: 'middle-right',
                        showCloseButton: true,
                        text: React.createElement(FormattedMessage, messages.enterEmailAddressesCalloutText),
                        theme: 'callout'
                    },
                    React.createElement(ContactsField, {
                        disabled: !isContactsFieldEnabled,
                        error: contactsFieldError,
                        fieldRef: this.contactsFieldRef,
                        getContacts: getContacts,
                        label: contactsFieldLabel,
                        onContactAdd: this.handleContactAdd,
                        onContactRemove: this.handleContactRemove,
                        onInput: this.handleContactInput,
                        selectedContacts: selectedContacts,
                        validateForError: this.validateContactField,
                        validator: this.isValidEmail
                    })
                )
            );

            var contactsFieldWrap = void 0;
            if (isContactsFieldEnabled) {
                contactsFieldWrap = contactsField;
            } else {
                contactsFieldWrap = React.createElement(
                    Tooltip,
                    {
                        text: contactsFieldDisabledTooltip,
                        position: 'bottom-center'
                    },
                    contactsField
                );
            }

            return React.createElement(
                'form',
                {
                    onSubmit: this.handleSubmit,
                    className: classNames({
                        'is-expanded': isExpanded
                    })
                },
                inlineNotice.content && isExpanded && React.createElement(
                    InlineNotice,
                    { type: inlineNotice.type },
                    inlineNotice.content
                ),
                contactsFieldAvatars,
                contactsFieldWrap,
                children,
                isExpanded && React.createElement(TextArea, _extends({
                    label: React.createElement(FormattedMessage, messages.messageTitle),
                    placeholder: intl.formatMessage(commonMessages.messageSelectorPlaceholder),
                    onChange: this.handleMessageChange,
                    rows: 3,
                    value: message
                }, messageProps)),
                isExpanded && React.createElement(
                    ModalActions,
                    null,
                    React.createElement(
                        Button,
                        _extends({
                            isDisabled: submitting,
                            onClick: this.handleClose,
                            type: 'button'
                        }, cancelButtonProps),
                        React.createElement(FormattedMessage, commonMessages.cancel)
                    ),
                    React.createElement(
                        PrimaryButton,
                        _extends({
                            isDisabled: submitting || selectedContacts.length === 0,
                            isLoading: submitting,
                            type: 'submit'
                        }, sendButtonProps),
                        React.createElement(FormattedMessage, commonMessages.send)
                    )
                )
            );
        }
    }]);

    return EmailForm;
}(React.Component);

EmailForm.defaultProps = {
    messageProps: {}
};


export { EmailForm as EmailFormBase };
export default injectIntl(EmailForm);