var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';
import classNames from 'classnames';
import { FormattedMessage } from 'react-intl';

import DropdownMenu, { MenuToggle } from '../../components/dropdown-menu';
import { Menu, SelectMenuItem } from '../../components/menu';
import PlainButton from '../../components/plain-button';
import Tooltip from '../../components/tooltip';


import SharedLinkAccessLabel from './SharedLinkAccessLabel';
import { ANYONE_WITH_LINK, ANYONE_IN_COMPANY, PEOPLE_IN_ITEM } from './constants';
import messages from './messages';


var accessLevels = [ANYONE_WITH_LINK, ANYONE_IN_COMPANY, PEOPLE_IN_ITEM];

var SharedLinkAccessMenu = function (_Component) {
    _inherits(SharedLinkAccessMenu, _Component);

    function SharedLinkAccessMenu() {
        var _ref;

        var _temp, _this, _ret;

        _classCallCheck(this, SharedLinkAccessMenu);

        for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
            args[_key] = arguments[_key];
        }

        return _ret = (_temp = (_this = _possibleConstructorReturn(this, (_ref = SharedLinkAccessMenu.__proto__ || Object.getPrototypeOf(SharedLinkAccessMenu)).call.apply(_ref, [this].concat(args))), _this), _this.onChangeAccessLevel = function (newAccessLevel) {
            var _this$props = _this.props,
                accessLevel = _this$props.accessLevel,
                changeAccessLevel = _this$props.changeAccessLevel,
                trackingProps = _this$props.trackingProps;
            var onChangeSharedLinkAccessLevel = trackingProps.onChangeSharedLinkAccessLevel;


            if (accessLevel !== newAccessLevel) {
                changeAccessLevel(newAccessLevel);

                if (onChangeSharedLinkAccessLevel) {
                    onChangeSharedLinkAccessLevel(newAccessLevel);
                }
            }
        }, _temp), _possibleConstructorReturn(_this, _ret);
    }

    _createClass(SharedLinkAccessMenu, [{
        key: 'renderMenu',
        value: function renderMenu() {
            var _this2 = this;

            var _props = this.props,
                accessLevel = _props.accessLevel,
                allowedAccessLevels = _props.allowedAccessLevels,
                classificationName = _props.classificationName,
                enterpriseName = _props.enterpriseName,
                itemType = _props.itemType;


            return React.createElement(
                Menu,
                { className: 'usm-share-access-menu' },
                accessLevels.map(function (level) {
                    var isDisabled = !allowedAccessLevels[level];
                    var isDisabledByClassification = isDisabled && classificationName;
                    var menuItem = null;
                    if (!isDisabled || isDisabledByClassification) {
                        menuItem = React.createElement(
                            SelectMenuItem,
                            {
                                onClick: function onClick() {
                                    return _this2.onChangeAccessLevel(level);
                                },
                                isSelected: level === accessLevel,
                                key: level,
                                isDisabled: isDisabled
                            },
                            React.createElement(SharedLinkAccessLabel, {
                                accessLevel: level,
                                enterpriseName: enterpriseName,
                                hasDescription: true,
                                itemType: itemType
                            })
                        );
                    }
                    if (menuItem && isDisabledByClassification) {
                        return React.createElement(
                            Tooltip,
                            {
                                key: 'tooltip-' + level,
                                text: React.createElement(FormattedMessage, _extends({}, messages.disabledShareLinkPermission, {
                                    values: {
                                        classification: classificationName
                                    }
                                })),
                                position: 'top-center'
                            },
                            menuItem
                        );
                    }
                    return menuItem;
                })
            );
        }
    }, {
        key: 'render',
        value: function render() {
            var _props2 = this.props,
                accessLevel = _props2.accessLevel,
                enterpriseName = _props2.enterpriseName,
                itemType = _props2.itemType,
                submitting = _props2.submitting,
                trackingProps = _props2.trackingProps;
            var sharedLinkAccessMenuButtonProps = trackingProps.sharedLinkAccessMenuButtonProps;


            return React.createElement(
                DropdownMenu,
                null,
                React.createElement(
                    PlainButton,
                    _extends({
                        className: classNames('lnk', {
                            'is-disabled': submitting
                        }),
                        disabled: submitting
                    }, sharedLinkAccessMenuButtonProps),
                    React.createElement(
                        MenuToggle,
                        null,
                        React.createElement(SharedLinkAccessLabel, {
                            accessLevel: accessLevel,
                            enterpriseName: enterpriseName,
                            hasDescription: false,
                            itemType: itemType
                        })
                    )
                ),
                this.renderMenu()
            );
        }
    }]);

    return SharedLinkAccessMenu;
}(Component);

SharedLinkAccessMenu.defaultProps = {
    allowedAccessLevels: [],
    trackingProps: {}
};
SharedLinkAccessMenu.propTypes = {
    accessLevel: function accessLevel() {
        return (typeof bpfrpt_proptype_accessLevelType === 'function' ? bpfrpt_proptype_accessLevelType : PropTypes.shape(bpfrpt_proptype_accessLevelType)).apply(this, arguments);
    },
    allowedAccessLevels: function allowedAccessLevels() {
        return (typeof bpfrpt_proptype_allowedAccessLevelsType === 'function' ? bpfrpt_proptype_allowedAccessLevelsType.isRequired ? bpfrpt_proptype_allowedAccessLevelsType.isRequired : bpfrpt_proptype_allowedAccessLevelsType : PropTypes.shape(bpfrpt_proptype_allowedAccessLevelsType).isRequired).apply(this, arguments);
    },
    changeAccessLevel: PropTypes.func.isRequired,
    classificationName: PropTypes.string,
    enterpriseName: PropTypes.string,
    itemType: function itemType() {
        return (typeof bpfrpt_proptype_itemType === 'function' ? bpfrpt_proptype_itemType.isRequired ? bpfrpt_proptype_itemType.isRequired : bpfrpt_proptype_itemType : PropTypes.shape(bpfrpt_proptype_itemType).isRequired).apply(this, arguments);
    },
    submitting: PropTypes.bool.isRequired,
    trackingProps: PropTypes.shape({
        onChangeSharedLinkAccessLevel: PropTypes.func,
        sharedLinkAccessMenuButtonProps: PropTypes.object
    }).isRequired
};


export default SharedLinkAccessMenu;
import { bpfrpt_proptype_itemType } from '../../common/box-types';
import { bpfrpt_proptype_accessLevelType } from './flowTypes';
import { bpfrpt_proptype_allowedAccessLevelsType } from './flowTypes';
import PropTypes from 'prop-types';