var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import PropTypes from 'prop-types';
import React, { Component } from 'react';
import classNames from 'classnames';

import { CellMeasurer, CellMeasurerCache } from 'react-virtualized/dist/commonjs/CellMeasurer';
import List from 'react-virtualized/dist/commonjs/List';

import 'react-virtualized/styles.css';

import FileVersionListItem from './FileVersionListItem';
import { VersionsPropType } from './prop-types';

import './FileVersionList.scss';

var DEFAULT_HEIGHT_PX = 96;
var LIST_HEIGHT_PX = 300;
var LIST_WIDTH_PX = 400;

var FileVersionList = function (_Component) {
    _inherits(FileVersionList, _Component);

    function FileVersionList(props) {
        _classCallCheck(this, FileVersionList);

        var _this = _possibleConstructorReturn(this, (FileVersionList.__proto__ || Object.getPrototypeOf(FileVersionList)).call(this, props));

        _this._cache = null;
        _this._list = null;

        _this.rowRenderer = function (_ref) {
            var index = _ref.index,
                style = _ref.style,
                parent = _ref.parent;
            var _this$props = _this.props,
                canDelete = _this$props.canDelete,
                canUpload = _this$props.canUpload,
                isProcessing = _this$props.isProcessing,
                onDelete = _this$props.onDelete,
                onDownload = _this$props.onDownload,
                onMakeCurrent = _this$props.onMakeCurrent,
                onRestore = _this$props.onRestore,
                versions = _this$props.versions,
                versionLimit = _this$props.versionLimit;


            var version = versions[index];
            var isOverVersionLimit = !!(versionLimit && index >= versionLimit);
            var key = version.id;

            return React.createElement(
                CellMeasurer,
                {
                    cache: _this._cache,
                    columnIndex: 0,
                    key: key,
                    parent: parent,
                    rowIndex: index
                },
                React.createElement(FileVersionListItem, {
                    canDelete: canDelete,
                    canUpload: canUpload,
                    isOverVersionLimit: isOverVersionLimit,
                    isProcessing: isProcessing,
                    onDelete: onDelete,
                    onDownload: onDownload,
                    onMakeCurrent: onMakeCurrent,
                    onRestore: onRestore,
                    style: style,
                    version: version,
                    versionLimit: versionLimit
                })
            );
        };

        _this._setListRef = function (ref) {
            _this._list = ref;
        };

        _this._cache = new CellMeasurerCache({
            defaultHeight: DEFAULT_HEIGHT_PX,
            fixedWidth: true
        });
        return _this;
    }

    _createClass(FileVersionList, [{
        key: 'componentDidMount',
        value: function componentDidMount() {
            this.recalculateRowHeights();
            this.jumpToVersionNumber();
        }
    }, {
        key: 'componentDidUpdate',
        value: function componentDidUpdate(prevProps) {
            this.recalculateRowHeights();
            if (prevProps.scrollToVersionNumber !== this.props.scrollToVersionNumber) {
                this.jumpToVersionNumber();
            }
        }
    }, {
        key: 'recalculateRowHeights',
        value: function recalculateRowHeights() {
            if (!this._list) {
                return;
            }

            this._cache.clearAll();
            this._list.recomputeRowHeights();
        }
    }, {
        key: 'jumpToVersionNumber',
        value: function jumpToVersionNumber() {
            var _props = this.props,
                scrollToVersionNumber = _props.scrollToVersionNumber,
                versions = _props.versions;


            if (!this._list || !scrollToVersionNumber || !versions) {
                return;
            }

            var scrollToIndex = versions.findIndex(function (version) {
                return version.versionNumber === scrollToVersionNumber;
            });

            if (scrollToIndex >= 0) {
                this._list.scrollToRow(scrollToIndex);
            }
        }
    }, {
        key: 'render',
        value: function render() {
            var _props2 = this.props,
                className = _props2.className,
                versions = _props2.versions;


            return React.createElement(
                'div',
                { className: classNames('file-version-list', className) },
                React.createElement(List, {
                    deferredMeasurementCache: this._cache,
                    height: LIST_HEIGHT_PX,
                    ref: this._setListRef,
                    rowCount: versions.length,
                    rowHeight: this._cache.rowHeight,
                    rowRenderer: this.rowRenderer,
                    width: LIST_WIDTH_PX,
                    scrollToAlignment: 'start'
                })
            );
        }
    }]);

    return FileVersionList;
}(Component);

FileVersionList.propTypes = {
    canDelete: PropTypes.bool,
    canUpload: PropTypes.bool,
    className: PropTypes.string,
    isProcessing: PropTypes.bool,
    onDelete: PropTypes.func.isRequired,
    onDownload: PropTypes.func.isRequired,
    onMakeCurrent: PropTypes.func.isRequired,
    onRestore: PropTypes.func.isRequired,
    scrollToVersionNumber: PropTypes.number,
    versions: VersionsPropType.isRequired,
    versionLimit: PropTypes.number
};


export default FileVersionList;